@@ -13,24 +13,25 @@
  *   (at your option) any later version.                                   *
 ***************************************************************************/
 
+
 #include "card.h"
 
 ////////////////////////////////////////////////////////////////////////////////
 // public members
 ////////////////////////////////////////////////////////////////////////////////
 
-Card::Card()
+Card::Card() :
+  reversed(false)
 {
-  cardFront = QString::null;
-  cardBack = QString::null;
-  reversed = false;
+
 }
 
-Card::Card(const QString &front, const QString &back)
+Card::Card(const QString &front, const QString &back) :
+  cardFront(front),
+  cardBack(back),
+  reversed(false)
 {
-  cardFront = front;
-  cardBack = back;
-  reversed = false;
+
 }
 
 Card::~Card()
@@ -41,17 +42,17 @@ Card::~Card()
 QString Card::front() const
 {
   if(!reversed)
-    return(cardFront);
+    return cardFront;
   else
-    return(cardBack);
+    return cardBack;
 }
 
 QString Card::back() const
 {
   if(!reversed)
-    return(cardBack);
+    return cardBack;
   else
-    return(cardFront);
+    return cardFront;
 }
 
 void Card::setFront(const QString &front)
