@@ -16,9 +16,10 @@
 #ifndef CARD_H
 #define CARD_H
 
-#include <qstring.h>
 #include <qvaluelist.h>
 
+class QString;
+
 class Card 
 {
 public: 
