@@ -13,13 +13,13 @@
  *   (at your option) any later version.                                   *
 ***************************************************************************/
 
-#include <klocale.h>
+#include <kstatusbar.h>
 #include <kpushbutton.h>
-#include <kguiitem.h>
+#include <klocale.h>
 #include <kdebug.h>
 
-#include <qlabel.h>
 #include <qtabwidget.h>
+#include <qstylesheet.h>
 #include <qlayout.h>
 
 #include "flashcardswidget.h"
@@ -28,7 +28,8 @@
 // public members
 ////////////////////////////////////////////////////////////////////////////////
 
-FlashCardsWidget::FlashCardsWidget(KStatusBar *statusBar, QWidget *parent, const char *name) : QuizWidget(statusBar, parent, name)
+FlashCardsWidget::FlashCardsWidget(KStatusBar *statusBar, QWidget *parent, const char *name) :
+  QuizWidget(statusBar, parent, name)
 {
   setupLayout();
 }
@@ -62,12 +63,17 @@ void FlashCardsWidget::setupLayout()
   KPushButton *nextCardButton = new KPushButton(i18n("Next Card"), this);
   layout()->addWidget(nextCardButton);
 
-  connect(nextCardButton, SIGNAL(clicked()), this, SLOT(getCard()));
+  connect(nextCardButton, SIGNAL(clicked()), this, SLOT(nextCard()));
 }
 
 void FlashCardsWidget::showCard(const Card &card)
 {
   tabWidget->setCurrentPage(0);
-  frontLabel->setText("<h2>" + card.front() + "</h2>");
-  backLabel->setText("<h2>" + card.back() + "</h2>");
+
+  QString text;
+
+  text = QStyleSheet::escape(card.front()).replace("\n", "<br/>");
+  frontLabel->setText("<h2>" + text + "</h2>");
+  text = QStyleSheet::escape(card.back()).replace("\n", "<br/>");
+  backLabel->setText("<h2>" + text + "</h2>");
 }
