@@ -16,18 +16,17 @@
 #ifndef FLASHCARDSWIDGET_H
 #define FLASHCARDSWIDGET_H
 
-#include <kstatusbar.h>
-
-#include <qwidget.h>
-
 #include "quizwidget.h"
-#include "card.h"
+
+class KStatusBar;
+
+class Card;
 
 class FlashCardsWidget : public QuizWidget
 {
 public: 
   FlashCardsWidget(KStatusBar *statusBar, QWidget *parent, const char *name = 0);
-  ~FlashCardsWidget();
+  virtual ~FlashCardsWidget();
 
 private:
   void setupLayout();
