@@ -17,27 +17,26 @@
 #include <kmessagebox.h>
 #include <kfiledialog.h>
 #include <kcmdlineargs.h>
+#include <kkeydialog.h>
+#include <kstatusbar.h>
+#include <kaction.h>
 #include <kdebug.h>
 
-#include <qfile.h>
-
 #include <keduvocdata.h>
 
 #include "flashkard.h"
-#include "flashkard.moc"
+#include "datawidget.h"
 #include "guesswidget.h"
 #include "flashcardswidget.h"
-#include "card.h"
 #include "xmlwriter.h"
 
-FlashKard::FlashKard(QWidget *parent, const char *name) : 
-    KMainWindow(parent, name),
-    data(0),
-    quiz(0),
-    randomQuiz(false),
-    changed(false),
-    fileExtension("kvtml"),
-    focusedLineEdit(0)
+FlashKard::FlashKard(QWidget *parent, const char *name) :
+  KMainWindow(parent, name),
+  data(0),
+  quiz(0),
+  randomQuiz(false),
+  changed(false),
+  fileExtension("kvtml")
 {
   fileMask = "*." + fileExtension;
 
@@ -76,6 +75,11 @@ void FlashKard::selectionChanged()
 // private member implementations
 ////////////////////////////////////////////////////////////////////////////////
 
+void FlashKard::slotConfigureKeys()
+{
+  KKeyDialog::configure( actionCollection(), this );
+}
+
 void FlashKard::setupActions()
 {
   // file menu
@@ -84,6 +88,7 @@ void FlashKard::setupActions()
   KStdAction::save(this, SLOT(fileSave()), actionCollection());
   KStdAction::saveAs(this, SLOT(fileSaveAs()), actionCollection());
   KStdAction::quit(this, SLOT(quit()), actionCollection());
+  KStdAction::keyBindings( this, SLOT( slotConfigureKeys() ), actionCollection() );
 
   // edit menu
   cutAction = KStdAction::cut(this, SLOT(cut()), actionCollection());
@@ -124,8 +129,8 @@ void FlashKard::setupLayout()
 
   connect(data, SIGNAL(dataChanged()), this, SLOT(dataChanged()));
   connect(data, SIGNAL(selectionChanged()), this, SLOT(selectionChanged()));
-  connect(data, SIGNAL(lineEditFocusIn(KLineEdit *)), this, SLOT(enablePaste(KLineEdit *)));
-  connect(data, SIGNAL(lineEditFocusOut()), this, SLOT(disablePaste()));
+  connect(data, SIGNAL(editWidgetFocusIn()), this, SLOT(enablePaste()));
+  connect(data, SIGNAL(editWidgetFocusOut()), this, SLOT(disablePaste()));
 
   showData();
 }
@@ -238,7 +243,7 @@ void FlashKard::fileNew()
 void FlashKard::fileOpen()
 {
   if(saveChangesPrompt()) {
-    QStringList files = KFileDialog::getOpenFileNames(QString::null, fileMask, this, i18n("Open Decks"));
+    QStringList files = KFileDialog::getOpenFileNames(":lastdir", fileMask, this, i18n("Open Decks"));
     fileOpen(files);
   }
 }
@@ -255,15 +260,15 @@ void FlashKard::fileOpen(const QStringList &files)
 	cardList.append(card);
       }
     }
-    
+
     data->loadCards(cardList);
     showData();
-    
+
     if(files.count() == 1)
       fileName = files.first();
     else
       fileName = QString::null;
-    
+
     dataCurrent();
   }
 }
@@ -288,7 +293,7 @@ bool FlashKard::fileSave()
       return true;
     }
     else {
-      KMessageBox::sorry(this, i18n("Could not write to ") + fileInfo.fileName(), i18n("FlashKard"));
+      KMessageBox::sorry(this, i18n("Could not write to %1").arg(fileInfo.fileName()), i18n("FlashKard"));
       return false;
     }
   }
@@ -298,7 +303,7 @@ bool FlashKard::fileSave()
 
 bool FlashKard::fileSaveAs()
 {
-  fileName = KFileDialog::getSaveFileName(QString::null, fileMask, this, QString::null).simplifyWhiteSpace();
+  fileName = KFileDialog::getSaveFileName(":lastdir", fileMask, this, QString::null).simplifyWhiteSpace();
   if(!fileName.isEmpty()) {
     if(!fileName.endsWith(fileExtension))
       fileName.append("." + fileExtension);
@@ -334,8 +339,10 @@ void FlashKard::copy()
 
 void FlashKard::paste()
 {
-  if(focusedLineEdit)
-    focusedLineEdit->paste();
+  if(data && data->isVisible())
+    data->paste();
+  else if(quiz && quiz->isVisible())
+    quiz->paste();
 }
 
 void FlashKard::enableCutCopy()
@@ -354,20 +361,16 @@ void FlashKard::disableCutCopy()
   }
 }
 
-void FlashKard::enablePaste(KLineEdit *lineEdit)
+void FlashKard::enablePaste()
 {
-  if(lineEdit && pasteAction) {
-    focusedLineEdit = lineEdit;
+  if(pasteAction)
     pasteAction->setEnabled(true);
-  }
 }
 
 void FlashKard::disablePaste()
 {
-  if(pasteAction) {
-    focusedLineEdit = 0;
+  if(pasteAction)
     pasteAction->setEnabled(false);
-  }
 }
 
 void FlashKard::showData()
@@ -403,7 +406,7 @@ void FlashKard::showQuiz()
       data->hide();
       quiz->show();
       setCentralWidget(quiz);
-      quiz->getCard(randomQuiz);
+      quiz->nextCard(randomQuiz);
     }
   }
   else
@@ -417,7 +420,7 @@ void FlashKard::changeQuizMode(int id)
   if(quiz) {
     if(quiz->isVisible())
       visible = true;
-    delete(quiz);
+    delete quiz;
   }
 
   switch(id) {
@@ -440,7 +443,8 @@ void FlashKard::changeQuizMode(int id)
   }
 
   connect(quiz, SIGNAL(selectionChanged()), this, SLOT(selectionChanged()));
-  connect(quiz, SIGNAL(lineEditFocusIn(KLineEdit *)), this, SLOT(enablePaste(KLineEdit *)));
+  connect(quiz, SIGNAL(editWidgetFocusIn()), this, SLOT(enablePaste()));
+  connect(quiz, SIGNAL(editWidgetFocusOut()), this, SLOT(disablePaste()));
 
   quiz->setFrontBackReversed(reverseFrontBackAction->isChecked());
   connect(reverseFrontBackAction, SIGNAL(toggled(bool)), quiz, SLOT(setFrontBackReversed(bool)));
@@ -456,3 +460,7 @@ void FlashKard::changeShowAnswerLength(int id)
   if(quiz)
     quiz->setShowAnswerLength(id + 1);
 }
+
+#include "flashkard.moc"
+
+// vim: sw=2 sts=2 et
