@@ -15,37 +15,39 @@
  *                                                                         *
 ***************************************************************************/
 
+#include <kapplication.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
-#include <klocale.h>
 #include <kdebug.h>
 
 #include "flashkard.h"
 
-static const char *description = I18N_NOOP("FlashKard");
-	
-	
+static const char description[] = I18N_NOOP("FlashKard");
+
+
 static KCmdLineOptions options[] =
 {
   { "+[file(s)]", I18N_NOOP("File(s) to open"), 0 },
-  { 0, 0, 0 }
+  KCmdLineLastOption
 };
 
 int main(int argc, char *argv[])
 {
-  
+
   KAboutData aboutData( "flashkard", I18N_NOOP("FlashKard"),
 			"1.0", description, KAboutData::License_GPL,
 			"(c) 2002, Scott Wheeler", 0, "http://edu.kde.org/flashkard/");
 
   aboutData.addAuthor("Scott Wheeler", 0, "wheeler@kde.org");
+  aboutData.addCredit("David Vignoni", I18N_NOOP("SVG icon"), "david80v@tin.it");
   KCmdLineArgs::init(argc, argv, &aboutData);
   KCmdLineArgs::addCmdLineOptions(options);
+  
 
   KApplication a;
   FlashKard *flashkard = new FlashKard();
   a.setMainWidget(flashkard);
-  flashkard->show();  
+  flashkard->show();
 
   return a.exec();
 }
