@@ -16,38 +16,25 @@
 #include <stdlib.h>
 #include <time.h>
 
-#include <kmainwindow.h>
-#include <kpushbutton.h>
 #include <kmessagebox.h>
+#include <kprogress.h>
+#include <kstatusbar.h>
+#include <klineedit.h>
 #include <klocale.h>
 #include <kdebug.h>
 
+#include <qlayout.h>
 #include <qtimer.h>
-#include <qfont.h>
 
 #include "quizwidget.h"
-#include "quizwidget.moc"
 
 ////////////////////////////////////////////////////////////////////////////////
 // public members
 ////////////////////////////////////////////////////////////////////////////////
 
-QuizWidget::QuizWidget(KStatusBar *statusBar, QWidget *parent, const char *name) : 
-  QWidget(parent, name),
-  mainStatusBar(statusBar),
-  feedbackLabel(0),
-  progressBar(0),
-  reversed(false),
-  showAnswer(2)
-{
-  srand(time(0));
-  setupLayout();
-}
-
 QuizWidget::~QuizWidget()
 {
-  if(mainStatusBar)
-    delete(mainStatusBar);
+    delete mainStatusBar;
 }
 
 void QuizWidget::setCardList(const CardList &list)
@@ -65,20 +52,20 @@ bool QuizWidget::frontBackReversed() const
 // public slots
 ////////////////////////////////////////////////////////////////////////////////
 
-Card QuizWidget::getCard(bool random)
+Card QuizWidget::nextCard(bool random)
 {
   if(!completeCardList.isEmpty()) {
     if(remainingCardList.isEmpty()) {
-      KMessageBox::information( this, completeMessage(), i18n("FlashKard"));
+      KMessageBox::information(this, completeMessage(), i18n("FlashKard"));
       remainingCardList = completeCardList;
     }
-    
+
     int cardNumber;
     if(random)
       cardNumber = rand() % remainingCardList.count();
     else
       cardNumber = 0;
-    
+
     currentCard = remainingCardList[cardNumber];
     remainingCardList.remove(remainingCardList.at(cardNumber));
 
@@ -115,7 +102,19 @@ void QuizWidget::setShowAnswerLength(int length)
 // protected members
 ////////////////////////////////////////////////////////////////////////////////
 
-QBoxLayout *QuizWidget::layout()
+QuizWidget::QuizWidget(KStatusBar *statusBar, QWidget *parent, const char *name) :
+  QWidget(parent, name),
+  mainStatusBar(statusBar),
+  feedbackLabel(0),
+  progressBar(0),
+  reversed(false),
+  showAnswer(2)
+{
+  srand(time(0));
+  setupLayout();
+}
+
+QBoxLayout *QuizWidget::layout() const
 {
   return mainLayout;
 }
@@ -133,29 +132,29 @@ void QuizWidget::showFeedbackLabel(bool show)
   if(feedbackLabel) {
     if(show)
       feedbackLabel->show();
-    else 
+    else
       feedbackLabel->hide();
   }
 }
 
-// This should be the same as DataWidget::eventFilter() -- I'm just too lazy at the 
+// This should be the same as DataWidget::eventFilter() -- I'm just too lazy at the
 // moment to create a base class for QuizWidget and DataWidget that has just this.
 
 bool QuizWidget::eventFilter(QObject *object, QEvent *event)
 {
   if(event && event->type() == QEvent::FocusIn) {
-    if(KLineEdit *lineEdit = dynamic_cast<KLineEdit *>(object))
-      emit(lineEditFocusIn(lineEdit));
+    if(dynamic_cast<KLineEdit *>(object))
+      emit editWidgetFocusIn();
   }
   if(event && event->type() == QEvent::FocusOut) {
     QFocusEvent *focusEvent = static_cast<QFocusEvent *>(event);
     if(dynamic_cast<KLineEdit *>(object) && focusEvent->reason() != QFocusEvent::Popup)
-      emit(lineEditFocusOut());
+      emit editWidgetFocusOut();
   }
   return QWidget::eventFilter(object, event);
 }
 
-QString QuizWidget::completeMessage()
+QString QuizWidget::completeMessage() const
 {
   return i18n("Restarting the deck.");
 }
@@ -165,28 +164,33 @@ int QuizWidget::numberOfCards() const
   return completeCardList.size();
 }
 
+int QuizWidget::showAnswerLength() const
+{
+  return showAnswer;
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // private members
 ////////////////////////////////////////////////////////////////////////////////
 
 void QuizWidget::setupLayout()
-{ 
+{
   // setup statusbar
   if(mainStatusBar) {
-    //    QBoxLayout *layout = new QHBoxLayout(mainStatusBar);
-    //    layout->setAutoAdd(true); 
-    
+
     feedbackLabel = new QLabel(mainStatusBar);
     feedbackLabel->setAlignment(AlignHCenter | AlignAuto | AlignVCenter | ExpandTabs);
     feedbackLabel->setFixedWidth(100);
     mainStatusBar->addWidget(feedbackLabel, 1);
     showFeedbackLabel(false);
-    
+
     progressBar = new KProgress(mainStatusBar);
     progressBar->setMaximumHeight(mainStatusBar->height() - 12);
     mainStatusBar->addWidget(progressBar, 3);
   }
-  
-  // main layout 
+
+  // main layout
   mainLayout = new QVBoxLayout(this, 3, 2 , "mainLayout");
 }
+
+#include "quizwidget.moc"
