@@ -16,22 +16,21 @@
 #ifndef QUIZWIDGET_H
 #define QUIZWIDGET_H
 
-#include <kprogress.h>
-#include <kstatusbar.h>
-#include <klineedit.h>
-
 #include <qwidget.h>
-#include <qlayout.h>
 
 #include "card.h"
 
+class KStatusBar;
+class KProgress;
+class QBoxLayout;
+class QVBoxLayout;
+class QLabel;
+
 class QuizWidget : public QWidget
 {
   Q_OBJECT
 
 public: 
-
-  QuizWidget(KStatusBar *statusBar, QWidget *parent, const char *name = 0);
   virtual ~QuizWidget();
 
   void setCardList(const CardList &list);
@@ -44,25 +43,28 @@ public:
    */
   virtual void cut() {};
   virtual void copy() {};
-  virtual bool hasSelectedText() { return false; }
+  virtual void paste() {};
+  virtual bool hasSelectedText() const { return false; }
 
 public slots:
-  Card getCard(bool random = true);
+  Card nextCard(bool random = true);
   void setFrontBackReversed(bool reverse);
   void setShowAnswerLength(int length);
 
 protected:
+  QuizWidget(KStatusBar *statusBar, QWidget *parent, const char *name = 0);
+
   void setFeedbackMessage(const QString &message);
   void showFeedbackLabel(bool show = true);
-  QBoxLayout *layout();
+  QBoxLayout *layout() const;
   virtual bool eventFilter(QObject *object, QEvent *event);
   int numberOfCards() const;
-  int showAnswerLength() const { return showAnswer; }
+  int showAnswerLength() const;
 
 private:
   void setupLayout();
   virtual void showCard(const Card &card) = 0;
-  virtual QString completeMessage();
+  virtual QString completeMessage() const;
 
   KStatusBar *mainStatusBar;
   QVBoxLayout *mainLayout;
@@ -78,8 +80,8 @@ private:
   
 signals:
   void selectionChanged(); 
-  void lineEditFocusIn(KLineEdit *);
-  void lineEditFocusOut();
+  void editWidgetFocusIn();
+  void editWidgetFocusOut();
 };
 
 #endif
