@@ -1,4 +1,4 @@
-/* 
+/*
  * kmolcalc.cpp
  *
  * Copyright (C) 2000 Tomislav Gountchev <tomi@idiom.com>
@@ -7,16 +7,12 @@
 /**
  * KMOLCALC is the calculation engine. It knows about a hashtable of user defined atomic
  * weights and group definitions ELSTABLE, and the currently processed formula, stored
- * as a list of elements and their coefficients, ELEMENTS. 
+ * as a list of elements and their coefficients, ELEMENTS.
  */
 
-#include <kapplication.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
 #include "kmolcalc.h"
-#include <qdict.h>
-#include <qdir.h>
-#include <iostream.h>
 
 
 /**
@@ -34,15 +30,15 @@ KMolCalc::~KMolCalc() {
 
 void KMolCalc::readElstable() {
   weight = -1; // not calculated yet
-  if (elstable) delete elstable;
+  delete elstable;
   elstable = new QDict<SubUnit> (197, TRUE);
   elstable->setAutoDelete(TRUE);
   QStringList files = KGlobal::dirs()->findAllResources("appdata", "kmolweights");
   mwfile = locateLocal("data", "kmol")+"/kmolweights";
   QFile f(mwfile);
   QString* latest_f = &mwfile;
-  for (int i=0; i<files.count(); i++) {
-  	if (QFileInfo(QFile(files[i])).lastModified() > QFileInfo(QFile(*latest_f)).lastModified()) {
+  for (uint i=0; i<files.count(); i++) {
+  	if (QFileInfo(files[i]).lastModified() > QFileInfo(*latest_f).lastModified()) {
 		latest_f = &files[i];
     }
   }
@@ -53,39 +49,39 @@ void KMolCalc::readElstable() {
   	writeElstable();
   } else if (QFileInfo(f).lastModified() < QFileInfo(lf).lastModified()) {
     // announce
-    QMessageBox::information 
-      (0, i18n("Warning:"), i18n("Found new global Mw file.\nLocal definitions will be updated."), QMessageBox::Ok);
+    QMessageBox::information
+      (0, i18n("Warning"), i18n("Found new global Mw file.\nLocal definitions will be updated."), QMessageBox::Ok);
     readMwfile(lf);
     writeElstable();
   }
-  
+
 }
 
 
-/** 
- * Parse a string S and construct the ElementList this->ELEMENTS, representing the 
- * composition of S. Returns 0 if successful, or an error code (currently -1) if 
+/**
+ * Parse a string S and construct the ElementList this->ELEMENTS, representing the
+ * composition of S. Returns 0 if successful, or an error code (currently -1) if
  * parsing failed.
  * The elements is S must be valid element or group symbols, as stored in this->ELSTABLE.
  * See help files for correct formula syntax.
  */
 QString KMolCalc::readFormula(const QString& s) {
   weight = -1;
-  if (elements) delete elements;
+  delete elements;
   elements = new ElementList;
   return KMolCalc::readGroup(s, elements);
 }
 
 // read a formula group recursively. Called by readFormula.
 QString KMolCalc::readGroup(const QString& s, ElementList* els) {
-  if (s.isEmpty()) return QString (i18n("Enter a formula.")); //ERROR
+  if (s.isEmpty()) return i18n("Enter a formula."); //ERROR
   int sl = s.length();
   int i = 0;
   QString errors ("OK");
   bool ok = TRUE;
   while (i < sl && ((s[i] <= '9' && s[i] >= '0') || s[i] == '.')) i++;
-  double prefix = (i == 0 ? 1 : s.left(i).toDouble(&ok)); 
-  if (! ok || i == sl || prefix == 0) return QString (i18n("Bad formula.")); // ERROR
+  double prefix = (i == 0 ? 1 : s.left(i).toDouble(&ok));
+  if (! ok || i == sl || prefix == 0) return i18n("Bad formula."); // ERROR
   ElementList* elstemp = new ElementList;
   while (i < sl) {
     int j = i;
@@ -96,7 +92,7 @@ QString KMolCalc::readGroup(const QString& s, ElementList* els) {
 	if (i++ == sl) {
 	  delete inner;
 	  delete elstemp;
-	  return QString (i18n("Bad formula.")); //ERROR
+	  return i18n("Bad formula."); //ERROR
 	}
 	if (s[i] == '(') level++;
 	if (s[i] == ')') level--;
@@ -105,36 +101,36 @@ QString KMolCalc::readGroup(const QString& s, ElementList* els) {
       errors = KMolCalc::readGroup(s.mid(j+1, i-j-1), inner);
       j = ++i;
       while (i < sl && ((s[i] <= '9' && s[i] >= '0') || s[i] == '.')) i++;
-      double suffix = (i == j ? 1 : s.mid(j, i-j).toDouble(&ok)); 
+      double suffix = (i == j ? 1 : s.mid(j, i-j).toDouble(&ok));
       if (! ok || suffix == 0) {
 	delete inner;
 	delete elstemp;
-	return QString (i18n("Bad formula.")); // ERROR
-      }      
+	return i18n("Bad formula."); // ERROR
+      }
       inner->addTo(*elstemp, suffix);
       delete inner;
       inner = NULL;
     } else if ((s[i] >= 'A' && s[i] <= 'Z') || (s[i] >= 'a' && s[i] <= 'z')) {
-      while (++i < sl && ((s[i] >= 'a' && s[i] <= 'z') || s[i] == '*' || 
+      while (++i < sl && ((s[i] >= 'a' && s[i] <= 'z') || s[i] == '*' ||
 			  s[i] == '\''));
       QString elname = s.mid(j, i-j);
       j = i;
       while (i < sl && ((s[i] <= '9' && s[i] >= '0') || s[i] == '.')) i++;
-      double suffix = (i == j ? 1 : s.mid(j, i-j).toDouble(&ok)); 
+      double suffix = (i == j ? 1 : s.mid(j, i-j).toDouble(&ok));
       if (! ok || suffix == 0) {
 	delete elstemp;
-	return QString (i18n("Bad formula.")); // ERROR
+	return i18n("Bad formula."); // ERROR
       }
       SubUnit* group = elstable->find(elname);
       if (group == 0) {
 	delete elstemp;
-	return QString (i18n("Undefined symbol: ") + elname); //ERROR
+	return i18n("Undefined symbol: ") + elname; //ERROR
       }
       group->addTo(*elstemp, suffix);
     } else if (s[i] == '+') {
       if (elstemp->isEmpty()) {
 	delete elstemp;
-	return QString (i18n("Bad formula.")); //ERROR
+	return i18n("Bad formula."); //ERROR
       }
       elstemp->addTo(*els, prefix);
       delete elstemp;
@@ -142,7 +138,7 @@ QString KMolCalc::readGroup(const QString& s, ElementList* els) {
       return errors;
     } else {
       delete elstemp;
-      return QString (i18n("Bad formula.")); //ERROR
+      return i18n("Bad formula."); //ERROR
     }
   }
   elstemp->addTo(*els, prefix);
@@ -164,7 +160,7 @@ double KMolCalc::getWeight() {
  */
 QString KMolCalc::getEA() {
   if (weight == -1) weight = elements->getWeight(elstable);
-  if (weight == -1) return QString(i18n("ERROR: Couldn't get Mw...")); // ERROR
+  if (weight == -1) return i18n("ERROR: Couldn't get Mw..."); // ERROR
   return elements->getEA(elstable, weight);
 }
 
@@ -213,7 +209,7 @@ void KMolCalc::undefineGroup (const QString& name) {
 }
 
 /**
- * Add a new element name - atomic weight record to the ELSTABLE hashtable. Assumes 
+ * Add a new element name - atomic weight record to the ELSTABLE hashtable. Assumes
  * NAME has valid syntax.
 
  */
