@@ -3,7 +3,7 @@
         kalzium.cpp  -  description
                              -------------------
     begin                : Die Dez  4 17:59:34 CET 2001
-    copyright            : (C) 2001, 2002 by Carsten Niehaus
+    copyright            : (C) 2001, 2002, 2003 by Carsten Niehaus
     email                : cniehaus@kde.org
  ***************************************************************************/
 
@@ -16,48 +16,44 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "kalzium.h"
-#include "kalzium.moc"
-#include "../calculations/kmoledit.h"
-#include "../calculations/kmolcalc.h"
-#include "calcdialog.h"
-#include "eleminfo.h"
-#include "elementkp.h"
-#include "settingsdialog.h"
-
 //KDE-Includes
+#include <kapplication.h>
+#include <kdebug.h>
 #include <kaction.h>
-#include <kconfig.h>
+#include <kedittoolbar.h>
+#include <kkeydialog.h>
 #include <kglobalsettings.h>
 #include <kiconloader.h>
 #include <klocale.h>
-#include <kpushbutton.h>
 #include <ksimpleconfig.h>
 #include <kstandarddirs.h>
-#include <kstdaction.h>
-#include <kcolorbutton.h>
 
 //QT-Includes
 #include <qinputdialog.h>
-#include <qlabel.h>
 #include <qlayout.h>
 #include <qlcdnumber.h>
 #include <qslider.h>
 #include <qtooltip.h>
-#include <qstring.h>
 #include <qwhatsthis.h>
-#include <qbutton.h>
 
 // Table includes
 #include "quizdlg.h"
-#include "calcdlg.h"
 #include "stateofmatterdlg.h"
+#include "kalzium.h"
+#include "kalzium.moc"
+#include "../calculations/kmoledit.h"
+#include "calcdialog.h"
+#include "eleminfo.h"
+#include "settingsdialog.h"
+#include "legend.h"
+#include "searchdlg.h"
 
+#include "kalziumplotdialogimpl.h"
 
 Kalzium::Kalzium() : KMainWindow( 0 ), setDlg(0L)
 {
-    connect(kapp, SIGNAL(kdisplayFontChanged()), this,SLOT(updateElementKPSize()));
-    
+    connect (kapp, SIGNAL(kdisplayFontChanged()), this, SLOT (setFont()));
+    setFont();
     main_config=KGlobal::config();
 
     calculationdialog=NULL;
@@ -68,53 +64,38 @@ Kalzium::Kalzium() : KMainWindow( 0 ), setDlg(0L)
     setupConfig();
     setupActions();
 
-    main_window = new QWidget(this);
+    main_window = new QWidget(this, "main_window");
+
     mainlayout = new QVBoxLayout( main_window, 0, -1, "mainlayout" );
 
     setupAllElementKPButtons();
-    
+    dtab->hide();
     setupTimeline();
 
     setupCaption();
-    
+
     setCentralWidget(main_window);
-    
+
     updateMainWindow();
-    updateElementKPSize();
-    createhelpArray();
+
+    connect( &mLeaveTimer, SIGNAL( timeout() ), this, SLOT( leaveTimeout() ) );
 }
 
 Kalzium::~Kalzium()
 {
-    for (int n=0; n<118; n++)
+    for (int n=0; n<110; n++)
         delete element[n];
 }
 
-void Kalzium::createhelpArray()
-{
-		for(int i=0;i<9;i++)
-		{
-				for(int e=0;e<18;e++)
-				{
-						helpArray[i][e]="leer";
-				}
-		}
-
-		int ze=0,sp=0;
-		for(int as=1;as<118;as++)
-		{
-				position(as,ze,sp);
-				helpArray[sp/40][ze/40]=element[as-1]->Data.Symbol;
-		}
-}
-
 bool Kalzium::queryClose()
 {
     main_config->setGroup("Menu Settings");
-    main_config->writeEntry("psestylemenu",psestylemenu->currentItem()); 
+    main_config->writeEntry("psestylemenu",psestylemenu->currentItem());
     main_config->writeEntry("colorschememenu", colorschememenu->currentItem());
     main_config->writeEntry("numerationmenu", numerationmenu->currentItem());
     main_config->writeEntry("timelineshow", timelineToggleAction->isChecked());
+    main_config->writeEntry("quickinfo",quickinfoToggleAction->isChecked());
+    main_config->writeEntry("legend",legendToggleAction->isChecked());
   	main_config->sync();
     return true;
 }
@@ -122,7 +103,7 @@ bool Kalzium::queryClose()
 void Kalzium::setupAllElementKPButtons()
 {
     //////////////////////////////////////
-    //creation of the 118 buttons
+    //creation of the 110 buttons
     //
     maingrid = new QGridLayout( mainlayout, 18, 10, -1, "maingridlayout" );
     maingrid->setOrigin(QGridLayout::TopLeft);
@@ -130,79 +111,69 @@ void Kalzium::setupAllElementKPButtons()
     // Loop over all elements
     int h=0; int v=0;
     QString elementName;
+
     KSimpleConfig config (locate("data", "kalzium/kalziumrc"));
+
     ElementInfo eleminfo;
-    for ( int n=0 ;n<118 ;n++ )
-    {
-        if (config.hasGroup(QString::number(n+1)))
-        {
-            config.setGroup(QString::number(n+1));
-            eleminfo.Name=config.readEntry("Name", "Unknown");
-            eleminfo.Symbol=config.readEntry("Symbol", "Unknown");
+    for ( int n=0 ;n<110 ;n++ )
+	{
+		if (config.hasGroup(QString::number(n+1)))
+		{
+			config.setGroup(QString::number(n+1));
+			eleminfo.Name=config.readEntry("Name", "Unknown");
+			eleminfo.Symbol=config.readEntry("Symbol", "Unknown");
 
-            eleminfo.Weight=config.readEntry("Weight","0.0");
-            eleminfo.acidbeh=config.readEntry("acidbeh","0");
-            eleminfo.Block=config.readEntry("Block","s");
-            eleminfo.EN=config.readDoubleNumEntry("EN", -1);
-            eleminfo.MP=config.readDoubleNumEntry("MP", -1);
-            eleminfo.IE=config.readDoubleNumEntry("IE", -1);
-            eleminfo.AR=config.readDoubleNumEntry("AR", -1);
-            eleminfo.BP=config.readDoubleNumEntry("BP", -1);
-            eleminfo.Density=config.readDoubleNumEntry("Density", -1);
-            eleminfo.az=config.readEntry("az","0");
-            eleminfo.date=config.readEntry("date","0");
-            eleminfo.Group=config.readEntry("Group","1");
-            eleminfo.number=(n+1);
+			eleminfo.oxstage=config.readEntry("Ox","0");
+			eleminfo.Weight=config.readEntry("Weight","0.0");
+			eleminfo.acidbeh=config.readEntry("acidbeh","0");
+			eleminfo.Block=config.readEntry("Block","s");
+			eleminfo.EN=config.readDoubleNumEntry("EN", -1);
+			eleminfo.MP=config.readDoubleNumEntry("MP", -1);
+			eleminfo.IE=config.readDoubleNumEntry("IE", -1);
+			eleminfo.IE2=config.readDoubleNumEntry("IE2", -1);
+			eleminfo.AR=config.readDoubleNumEntry("AR", -1);
+			eleminfo.BP=config.readDoubleNumEntry("BP", -1);
+			eleminfo.Density=config.readDoubleNumEntry("Density", -1);
+			eleminfo.az=config.readEntry("az","0");
+			eleminfo.date=config.readEntry("date","0");
+			eleminfo.Group=config.readEntry("Group","1");
+			eleminfo.orbits=config.readEntry("Orbits","0");
+			eleminfo.biological=config.readNumEntry( "biological" , -1 );
+			eleminfo.number=(n+1);
 
-        } else elementName="Unknown";
-        position( n+1,h,v ); //get position
-        element[n] =  new ElementKP ( main_window, eleminfo, elementName.latin1(), n+1, statusBar(),this );
-        
+		} else elementName="Unknown";
+		position( n+1,h,v ); //get position
+		element[n] =  new ElementKP ( main_window, eleminfo, elementName.latin1(), n+1, statusBar(),this );
 
-        maingrid->addWidget( element[n], v/40+1, h/40 );
-        element[n]->show();
 
-        //Now we add the WhatsThis-help for each button
-        QWhatsThis::add( element[n], i18n("Click here to get information about %1.").arg(eleminfo.Symbol) );
-		QToolTip::add( element[n], eleminfo.Name.utf8() );
-    }
+		maingrid->addWidget( element[n], v/40+1, h/40 );
+		element[n]->show();
+
+		//Now we add the WhatsThis-help for each button
+		QWhatsThis::add( element[n], i18n("Click here to get information about %1.").arg(eleminfo.Symbol) );
+		QToolTip::add( element[n], i18n( eleminfo.Name.utf8() ) );
+	}
 
     //////////////////
-    // feste minimal breite und hhe der gridelemente
+    // fixed minimal wide and high of the gridelements
     //////////////////
     for( int n=0; n<18; n++ ) maingrid->addColSpacing( n, 40 );
     for( int n=0; n<10; n++ ) maingrid->addRowSpacing( n, 40 );
 
     mainlayout->addStretch();
+
+	//////////////////
+	QWidget *SmallWidget = new QWidget( this );
+	QVBoxLayout *dtabLayout = new QVBoxLayout( SmallWidget , 5 );
+	dtab = new DetailedTab( SmallWidget );
+	dtabLayout->addWidget( dtab );
+	maingrid->addMultiCellWidget( SmallWidget ,2,3,3,6 );
 }
 
 void Kalzium::setupCaption()
 {
-    QHBoxLayout *legend_layout = new QHBoxLayout( mainlayout, -1, "legendlayout" );
-    legend_layout->setDirection(QBoxLayout::LeftToRight);
-    legend_layout->addStretch();
-
-	main_config->setGroup( "Colors" );
-
-	one = new KPushButton( main_window );
-	two = new KPushButton( main_window );
-	three = new KPushButton( main_window );
-	four = new KPushButton( main_window );
-	five = new KPushButton( main_window );
-	six = new KPushButton( main_window );
-	seven = new KPushButton( main_window );
-	eight = new KPushButton( main_window );
-	legend_layout->addWidget( one );
-	legend_layout->addWidget( two );
-	legend_layout->addWidget( three );
-	legend_layout->addWidget( four );
-	legend_layout->addWidget( five );
-	legend_layout->addWidget( six );
-	legend_layout->addWidget( seven );
-	legend_layout->addWidget( eight );
-	legend_layout->addStretch();
-	
-    mainlayout->addStretch();
+    legend = new KalziumLegend(main_window);
+    mainlayout->addWidget(legend);
 
     for (int n = 0; n < 18; n++)
     {
@@ -218,8 +189,8 @@ void Kalzium::setupTimeline()
     dateS = new QSlider (QSlider::Horizontal, main_window, "rotateSlider" );
     timeline_layout->addWidget( dateS );
     QWhatsThis::add(dateS, i18n("Use this slider to see what elements were known at a certain date."));
-    dateS->setRange(1669, 2002);
-    dateS->setValue(2002);
+    dateS->setRange(1669, 2003);
+    dateS->setValue(2003);
     dateS->hide();
     connect( dateS, SIGNAL(valueChanged(int)),  SLOT(timeline()));
 
@@ -227,14 +198,15 @@ void Kalzium::setupTimeline()
 
     dateLCD = new QLCDNumber( 4, main_window, "dateLCD");
     timeline_layout->addWidget( dateLCD );
-    QWhatsThis::add(dateLCD, i18n("This is the date which you have chosen with the slider. Currently, you are viewing the elements known in the year %1.").arg(QString::number(dateS->value())));
+
+	QWhatsThis::add(dateLCD, i18n("This is the date you have chosen using the slider." ) );
     dateLCD->hide();
     dateLCD->display("2002");
 
     timeline_layout->addStretch();
 }
 
-void Kalzium::showCAS() const
+void Kalzium::showIUPAC() const
 {
     int h = 0, v = 0;
     for (int n = 0; n < 18; n++)
@@ -246,12 +218,29 @@ void Kalzium::showCAS() const
         labels[n]->setText(name);
         labels[n]->setAlignment( Qt::AlignCenter );
         labels[n]->setAutoMask( true );
-        QWhatsThis::add(labels[n], i18n("This period is called '%1' in the terminology used by the CAS.").arg(name));
+        QWhatsThis::add(labels[n], i18n("This period is called '%1' in the terminology used by the IUPAC.").arg(name));
         labels[n]->show();
     }
 }
 
-void Kalzium::showIUPAC() const
+void Kalzium::showOldIUPAC() const
+{
+    int h = 0, v = 0;
+    for (int n = 0; n < 18; n++)
+    {
+        periodNrpos(n+1, h, v);
+        QString name;
+        periodOldName(n+1, name);
+        maingrid->addWidget(labels[n], v/40, h/40);
+        labels[n]->setText(name);
+        labels[n]->setAlignment( Qt::AlignCenter );
+        labels[n]->setAutoMask( true );
+        QWhatsThis::add(labels[n], i18n("This period is called '%1' in the terminology of the old IUPAC-recommendation.").arg(name));
+        labels[n]->show();
+    }
+}
+
+void Kalzium::showCAS() const
 {
     int h = 0, v = 0;
     for (int n = 0; n < 18; ++n)
@@ -261,14 +250,14 @@ void Kalzium::showIUPAC() const
         labels[n]->setText(QString::number(n+1));
         labels[n]->setAlignment(AlignCenter);
         labels[n]->setAutoMask( true );
-        QWhatsThis::add(labels[n], i18n("This period is called '%1' in the terminology used by the IUPAC.").arg(QString::number(n+1)));
+        QWhatsThis::add(labels[n], i18n("This period is called '%1' in the terminology used by the CAS.").arg(QString::number(n+1)));
         labels[n]->show();
     }
 }
 
 
 //******** Slots *****************************************************
-void Kalzium::changeColorScheme(int id) 
+void Kalzium::changeColorScheme(int id)
 {
     static void (Kalzium::*funcs[])() = {
         &Kalzium::slotShowAcidBeh,
@@ -280,100 +269,25 @@ void Kalzium::changeColorScheme(int id)
     (this->*funcs[id & ~3 ? 3 : id])();
 }
 
-void Kalzium::changeLegend(int id)
-{
-    main_config->setGroup("Colors");
-    if (id == 0) //Acid Behaviours
-    {
-    one->setPaletteBackgroundColor(QColor(main_config->readColorEntry("acidic")));
-    two->setPaletteBackgroundColor(QColor(main_config->readColorEntry("amphoteric")));
-    three->setPaletteBackgroundColor(QColor(main_config->readColorEntry("basic")));
-    four->setPaletteBackgroundColor(QColor(main_config->readColorEntry("neitherofthem")));
-    five->hide();
-    six->hide();
-    seven->hide();
-    eight->hide();
-    one->setText(i18n("Acidic"));
-    two->setText(i18n("Amphoteric"));
-    three->setText(i18n("Basic"));
-    four->setText(i18n("Neutral"));
-    }
-    if (id == 1) //Blocks
-    {
-    one->setPaletteBackgroundColor(QColor(main_config->readColorEntry("s")));
-    two->setPaletteBackgroundColor(QColor(main_config->readColorEntry("p")));
-    three->setPaletteBackgroundColor(QColor(main_config->readColorEntry("d")));
-    four->setPaletteBackgroundColor(QColor(main_config->readColorEntry("f")));
-    five->hide();
-    six->hide();
-    seven->hide();
-    eight->hide();
-    one->setText(i18n("s-Block"));
-    two->setText(i18n("p-Block"));
-    three->setText(i18n("d-Block"));
-    four->setText(i18n("f-Block"));
-    }
-    if (id == 2) //Groups
-    {
-    one->setPaletteBackgroundColor(QColor(main_config->readColorEntry("Group 1")));
-    two->setPaletteBackgroundColor(QColor(main_config->readColorEntry("Group 2")));
-    three->setPaletteBackgroundColor(QColor(main_config->readColorEntry("Group 3")));
-    four->setPaletteBackgroundColor(QColor(main_config->readColorEntry("Group 4")));
-    five->setPaletteBackgroundColor(QColor(main_config->readColorEntry("Group 5")));
-    six->setPaletteBackgroundColor(QColor(main_config->readColorEntry("Group 6")));
-    seven->setPaletteBackgroundColor(QColor(main_config->readColorEntry("Group 7")));
-    eight->setPaletteBackgroundColor(QColor(main_config->readColorEntry("Group 8")));
-    six->show();
-    seven->show();
-    eight->show();
-    one->setText(i18n("Group 1"));
-    two->setText(i18n("Group 2"));
-    three->setText(i18n("Group 3"));
-    four->setText(i18n("Group 4"));
-    five->setText(i18n("Group 5"));
-    six->setText(i18n("Group 6"));
-    seven->setText(i18n("Group 7"));
-    eight->setText(i18n("Group 8"));
-    }
-    if (id == 3) //State of Matter
-    {
-    one->setPaletteBackgroundColor(QColor(main_config->readColorEntry("liquid")));
-    two->setPaletteBackgroundColor(QColor(main_config->readColorEntry("solid")));
-    three->setPaletteBackgroundColor(QColor(main_config->readColorEntry("vapor")));
-    four->setPaletteBackgroundColor(QColor(main_config->readColorEntry("artificial")));
-    five->setPaletteBackgroundColor(QColor(main_config->readColorEntry("radioactive")));
-    five->show();
-    six->hide();
-    seven->hide();
-    eight->hide();
-    one->setText(i18n("Liquid"));
-    two->setText(i18n("Solid"));
-    three->setText(i18n("Vapor"));
-    four->setText(i18n("Artificial"));
-    five->setText(i18n("Radioactive"));
-    }
-}
-void Kalzium::changeNumeration(int id) const 
+void Kalzium::changeNumeration(const int id) const
 {
     switch (id) {
-        case 0:
-            showCAS();
-            break;
-        case 1:
-            showIUPAC();
-            break;
-        case 2:
-            for (int n = 0; n < 18; ++n)
-                labels[n]->hide();
-            break;
+	case 0:
+	    showIUPAC();
+	    break;
+	case 1:
+	    showCAS();
+	    break;
+	case 2:
+	    showOldIUPAC();
+	    break;
+	case 3:
+	    for (int n = 0; n < 18; ++n)
+		labels[n]->hide();
+	    break;
     }
 }
 
-void Kalzium::defineweights() const
-{
-    (new KMolEdit(0, "kmoledit", new KMolCalc))->exec();
-}
-
 void Kalzium::hideSettingsDialog()
 {
     if(setDlg)
@@ -383,7 +297,36 @@ void Kalzium::hideSettingsDialog()
     }
 }
 
-void Kalzium::showPseStyle(int i)
+void Kalzium::newToolbarConfig()
+{
+    createGUI();
+    applyMainWindowSettings( KGlobal::config(), autoSaveGroup() );
+}
+
+void Kalzium::optionsConfigureKeys()
+{
+  KKeyDialog::configure(actionCollection());
+}
+
+void Kalzium::optionsConfigureToolbars( )
+{
+    saveMainWindowSettings( KGlobal::config(), autoSaveGroup() );
+    KEditToolbar dlg(actionCollection());
+    connect(&dlg, SIGNAL(newToolbarConfig()), this, SLOT(newToolbarConfig()));
+    dlg.exec();
+}
+
+void Kalzium::setFont()
+{
+  generalKPFont = KGlobalSettings::generalFont();
+  generalKPBoldFont = generalKPFont;
+
+  generalKPBoldFont.setBold(TRUE);
+  generalKPFont.setPointSize(generalKPFont.pointSize()-2);
+  generalKPBoldFont.setPointSize(generalKPBoldFont.pointSize()+1);
+}
+
+void Kalzium::showPseStyle(const int i)
 {
     if (i==0)
         slotShowMendelejew();
@@ -403,18 +346,9 @@ void Kalzium::showSettingsDialog()
         setDlg->show();
 }
 
-void Kalzium::showToolbar() 
-{
-    if (toolbarToggleAction->isChecked())
-        toolBar()->show();
-    else
-        toolBar()->hide();
-}
-
 void Kalzium::slotCalculations()
 {
-    if (!calculationdialog)
-        calculationdialog = new CalcDialog(this, "Calculationsdialog");
+    calculationdialog = new CalcDialog(this, "Calculationsdialog");
     calculationdialog->show();
 }
 
@@ -426,7 +360,7 @@ void Kalzium::slotKnowledge()
             i18n( "Please enter a number:" ), 10, 0, 20, 1, &ok, this );
     if ( ok )
     {
-        QuizDlg *quiz = new QuizDlg(this, "quizdialog", numofquestions); 
+        QuizDlg *quiz = new QuizDlg(this, "quizdialog", numofquestions);
         quiz->setCaption(i18n("Test Your Knowledge"));
         quiz->show();
     }
@@ -440,7 +374,7 @@ void Kalzium::slotShowAcidBeh() {
 
     main_config->setGroup("Colors");
 
-    for (int i = 0; i < 118; ++i)
+    for (int i = 0; i < 110; ++i)
     {
         PElementKP& b(element[i]);
         QString& s(b->Data.acidbeh);
@@ -460,7 +394,7 @@ void Kalzium::slotShowAll()
     for (int i = 58; i < 71; i++)
         element[i]->show();
 
-    for (int i = 83; i < 118; i++)
+    for (int i = 83; i < 110; i++)
         element[i]->show(); 
     timelineToggleAction->setEnabled(true);
 }
@@ -469,11 +403,11 @@ void Kalzium::slotShowBlocks()
 {
     delete templookup; templookup =NULL;
     main_config->setGroup("Colors");
-    for (int i = 0; i < 118; i++)
+    for (int i = 0; i < 110; i++)
     {
         PElementKP& b(element[i]);
         QString& s(b->Data.Block);
-        
+
         if (s.length() == 1)
             if (const char *p = strchr("spdf", QChar(s[0])))
                 b->setPaletteBackgroundColor(QColor(main_config->readColorEntry(QChar(*p))));
@@ -485,7 +419,7 @@ void Kalzium::slotShowGroups()
     delete templookup; templookup =NULL;
     main_config->setGroup("Colors");
 
-    for (int i = 0; i < 118; ++i)
+    for (int i = 0; i < 110; ++i)
     {
         PElementKP& b(element[i]);
         QString& s(b->Data.Group);
@@ -502,13 +436,13 @@ void Kalzium::slotShowGroups()
 
 void Kalzium::slotShowMendelejew()
 {
-    static int nummer[14] = { 2,10,18,21,28,31,32,36,43,49,54,55,72,75 };
-    static int dochda[4] = { 67,69,90,92 };
+    static const int nummer[14] = { 2,10,18,21,28,31,32,36,43,49,54,55,72,75 };
+    static const int dochda[4] = { 67,69,90,92 };
 
     for (int i=0; i<14 ; ++i)
         element[nummer[i] - 1]->hide();
 
-    for (int i=83; i < 118; ++i)
+    for (int i=83; i < 110; ++i)
         element[i]->hide();
 
     for (int i=58; i < 71; ++i)
@@ -525,79 +459,97 @@ void Kalzium::slotShowStateOfMatter()
     {
            templookup  = new StateOfMatterDlg(this, "stateofmatterdlg", this);
     }
-    
+
     templookup->setButtonsColor();
     templookup->tempbeh();
     templookup->show();
 }
 
-void Kalzium::updateColorMenu(int id) 
+void Kalzium::updateColorMenu(int id)
 {
     colorschememenu->setCurrentItem(id);
 }
 
-void Kalzium::updateNumMenu(int id) 
+void Kalzium::updateNumMenu(int id)
 {
     numerationmenu->setCurrentItem(id);
 }
 
-
-// set fixed size for our element buttons (for KDE 3.1)
-void Kalzium::updateElementKPSize()
+void Kalzium::slotShowTimeline(bool id)
 {
-    QFont general = KGlobalSettings::generalFont();
-    QFont general_bold = general;
+	if (id)
+	{
+		dateS->show();
+		dateLCD->show();
+		timeline();
+		psestylemenu->setEnabled(false);
+	}
+	else
+	{
+		dateS->hide();
+		dateLCD->hide();
+		psestylemenu->setEnabled(true);
+		for (int i =0; i<110; i++)
+			element[i]->show();
 
-    general.setPointSize(general.pointSize()-2);
-
-    general_bold.setPointSize(general_bold.pointSize());
-    general_bold.setBold(TRUE);
-
-    QFontMetrics zahl( general );
-    int zahl_height = zahl.height();
-    int zahl_width= zahl.width("103");
-    QFontMetrics text( general_bold );
-    int text_height = text.height();
-    int text_width = text.width("MD");
-    
-    for ( int n=0 ;n<118 ;n++ )
-    element[n]->setFixedSize(zahl_width + text_width ,
-                             zahl_height + text_height + 5);
+	}
 }
 
-void Kalzium::slotShowTimeline(bool id)
-{    
-    if (id == true)
-    {
-        dateS->show();
-        dateLCD->show();
-        timeline();
-        psestylemenu->setEnabled(false);
-    }
-    else
-    {
-        dateS->hide();
-        dateLCD->hide();
-        psestylemenu->setEnabled(true);
-        for (int i =0; i<118; i++)
-            element[i]->show();
-        
-    } 
+void Kalzium::slotShowQuickinfo( bool id )
+{
+	showFastInfo = id;
+}
+
+void Kalzium::slotSearchData()
+{
+	SearchDlg *searchData = new SearchDlg(this, "SerachDlg");
+	searchData->show();
+}
+
+void Kalzium::slotPlotData()
+{
+	KalziumPlotDialogImpl *PlotDialog = new KalziumPlotDialogImpl( this, "PlotDialog" );
+	PlotDialog->show();
+}
+
+void Kalzium::slotShowLegend( bool id )
+{
+	if ( id == true )
+		legend->show();
+	else legend->hide();
 }
 
 void Kalzium::timeline()
 {
-    dateLCD->display(dateS->value());
-    for (int i = 0; i < 118; ++i)
+    int currentDate = dateS->value();
+	QString currentDateString = QString::number( currentDate );
+	dateLCD->display( currentDate );
+    for (int i = 0; i < 110; ++i)
     {
-        PElementKP& b(element[i]);
-        if (b->Data.date > QString::number(dateS->value()))
+		PElementKP& b(element[i]);
+
+		if (i+1 == 6 ||
+			i+1 == 16 ||
+			i+1 == 26 ||
+			i+1 == 29 ||
+			i+1 == 33 ||
+			i+1 == 47 ||
+			i+1 == 50 ||
+			i+1 == 51 ||
+			i+1 == 79 ||
+			i+1 == 80 ||
+			i+1 == 82 ||
+			i+1 == 83
+			)
+		{
+            b->show();
+			continue;
+		}
+
+        if (b->Data.date > currentDateString)
             b->hide();
         else
             b->show();
-
-        if (b->Data.date == "3333" && QString::number(dateS->value()) < "1996")
-            b->hide();
     }
 }
 
@@ -636,32 +588,38 @@ void Kalzium::setupConfig()
 		main_config->writeEntry("amphoteric",QColor(10,80,180));
 		main_config->writeEntry("neitherofthem",QColor(130,80,255));
 
-	} 
+	}
 	if (!main_config->hasGroup("WLU"))
 	{
 		main_config->setGroup("WLU");
-		main_config->writeEntry("adress", "http://www.ktf-split.hr/periodni/en/");
+		main_config->writeEntry("address", "http://www.ktf-split.hr/periodni/en/");
+	}
+	if (!main_config->hasGroup("Menu Settings"))
+	{
+		main_config->setGroup("Menu Settings");
+		main_config->writeEntry("psestylemenu", 1);
+		main_config->writeEntry("colorschememenu", 1);
+		main_config->writeEntry("numerationmenu", 0);
+		main_config->writeEntry("timelineshow", false);
 	}
-    if (!main_config->hasGroup("Menu Settings"))
-    {
-        main_config->setGroup("Menu Settings");
-        main_config->writeEntry("psestylemenu", 1);
-        main_config->writeEntry("colorschememenu", 1);
-        main_config->writeEntry("numerationmenu", 0);
-        main_config->writeEntry("timelineshow", false);
-    }
 	main_config->sync();
 }
 
 void Kalzium::setupActions()
 {
-    KIconLoader *kil = KGlobal::iconLoader();
-    
+    const KIconLoader *kil = KGlobal::iconLoader();
+
     main_config->setGroup("Menu Settings");
     KStdAction::quit( kapp, SLOT (closeAllWindows()),actionCollection() );
-    KStdAction::preferences(this, SLOT(showSettingsDialog()), actionCollection(), "configure");
-    toolbarToggleAction = KStdAction::showToolbar(this, SLOT(showToolbar()), actionCollection());
-    
+    KStdAction::preferences(this, SLOT(showSettingsDialog()), actionCollection());
+    KStdAction::keyBindings(this, SLOT(optionsConfigureKeys()), actionCollection());
+    KStdAction::configureToolbars(this, SLOT(optionsConfigureToolbars()), actionCollection());
+#if KDE_VERSION_MINOR >1 && KDE_VERSION_MAJOR >= 3
+	createStandardStatusBarAction(); //post-KDE 3.1
+#else
+    setStandardToolBarMenuEnabled(true); //KDE 3.1
+#endif
+
     QStringList psestylelist;
     psestylelist.append( i18n("Mendeleev"));
     psestylelist.append( i18n("Complete"));
@@ -679,13 +637,14 @@ void Kalzium::setupActions()
     colorschememenu->setItems(colorschemelist);
     connect(colorschememenu, SIGNAL(activated(int)), this, SLOT(updateColorMenu(int)));
     connect(colorschememenu, SIGNAL(activated(int)), this, SLOT(changeColorScheme(int)));
-    connect(colorschememenu, SIGNAL(activated(int)), this, SLOT(changeLegend(int)));
+    connect(colorschememenu, SIGNAL(activated(int)), this, SLOT(changeTheLegend(int)));
     colorschememenu->setCurrentItem(main_config->readNumEntry("colorschememenu"));
-    
+
     // BEGIN NUMERATIONMENU
     QStringList numerationlist;
     numerationlist.append( i18n("CAS"));
     numerationlist.append( i18n("IUPAC"));
+    numerationlist.append( i18n("old IUPAC"));
     numerationlist.append( i18n("Off"));
 
     numerationmenu = new KSelectAction (i18n("&Numeration"),0,actionCollection(), "numeration");
@@ -697,25 +656,63 @@ void Kalzium::setupActions()
     // END NUMERATIONMENU
 
     // BEGIN TIMELINE
-    timelineToggleAction = new KToggleAction(i18n("Show Timeline"),kil->iconPath("timeline", KIcon::User),0,actionCollection(), "timeline");
+    timelineToggleAction = new KToggleAction(i18n("Show &Timeline"),kil->iconPath("timeline", KIcon::User),0,actionCollection(), "timeline");
     timelineToggleAction->setChecked(true);
     connect(timelineToggleAction, SIGNAL(toggled(bool)), this, SLOT(slotShowTimeline(bool)));
 
     timelineToggleAction->setChecked(main_config->readBoolEntry("timelineshow"));
     // END TIMELINEMENU
-    
-    (void) new KAction (i18n("Test Your &Knowledge"),0, this, SLOT(slotKnowledge()), actionCollection(), "test_your_knowledge");
-    (void) new KAction (i18n("Calculations"),0, this, SLOT(slotCalculations()), actionCollection(), "calculations");
-    (void) new KAction (i18n("Define Molecular Weights"),0, this, SLOT(defineweights()), actionCollection(), "defineweights");
+
+	//BEGIN QUICKINFO
+	quickinfoToggleAction = new KToggleAction( i18n( "Show &Quickinfo" ),kil->iconPath( "quickinfo",KIcon::User ),0,actionCollection(), "quickinfo" );
+	quickinfoToggleAction->setChecked( true );
+	connect( quickinfoToggleAction, SIGNAL( toggled( bool ) ),this, SLOT( slotShowQuickinfo( bool ) ) );
+	quickinfoToggleAction->setChecked( main_config->readBoolEntry( "quickinfo" ) );
+	//END QUICKINFO
+
+	//BEGIN LEGEND
+	legendToggleAction = new KToggleAction( i18n( "Show &Legend" ),kil->iconPath( "legend",KIcon::User ),0,actionCollection(), "legend" );
+	legendToggleAction->setChecked( true );
+	connect( legendToggleAction, SIGNAL( toggled( bool ) ),this, SLOT( slotShowLegend( bool ) ) );
+	legendToggleAction->setChecked( main_config->readBoolEntry( "legend" ) );
+	//END LEGEND
+
+    (void) new KAction (i18n("Test Your &Knowledge"), "wizard", 0, this, SLOT(slotKnowledge()), actionCollection(), "test_your_knowledge");
+    (void) new KAction (i18n("&Plot..."),0, this, SLOT(slotPlotData()), actionCollection(), "startplotting");
+    (void) new KAction (i18n("&Search Data..."), "find", CTRL+Key_F, this, SLOT(slotSearchData()), actionCollection(), "searchdata");
+    (void) new KAction (i18n("&Calculate..."),0, this, SLOT(slotCalculations()), actionCollection(), "calculations");
 
     createGUI("kalziumui.rc");
 }
 
 void Kalzium::updateMainWindow()
 {
-    changeColorScheme(colorschememenu->currentItem());
-    changeLegend(colorschememenu->currentItem());
-    changeNumeration(numerationmenu->currentItem());
-    showPseStyle(psestylemenu->currentItem());
-    slotShowTimeline(timelineToggleAction->isChecked());
+	changeColorScheme(colorschememenu->currentItem());
+	legend->changeLegend(colorschememenu->currentItem());
+	changeNumeration(numerationmenu->currentItem());
+	showPseStyle(psestylemenu->currentItem());
+	slotShowTimeline(timelineToggleAction->isChecked());
+	slotShowQuickinfo( quickinfoToggleAction->isChecked() );
+	slotShowLegend( legendToggleAction->isChecked() );
+}
+
+void Kalzium::changeTheLegend(int tempId)
+{
+	legend->changeLegend(tempId);
+}
+
+void Kalzium::restartLeaveTimer()
+{
+  mLeaveTimer.start( 100 );
+}
+
+void Kalzium::stopLeaveTimer()
+{
+  mLeaveTimer.stop();
+  dtab->show();
+}
+
+void Kalzium::leaveTimeout()
+{
+  dtab->hide();
 }
