@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Sep 5 2000
     copyright            : (C) 2000 by Javier Campos Morales
-    email                : javi_c@ctv.es
+    email                : javi@asyris.org
 ***************************************************************************/
 
 /***************************************************************************
@@ -19,7 +19,7 @@
 #define KCHECKEDUCA_H
 
 #include <qcheckbox.h>
-#include <kcheckeduca.h>
+#include "kcheckeduca.h"
 
 #include <qsimplerichtext.h>
 
@@ -34,11 +34,10 @@ public:
     KCheckEduca(QWidget *parent=0, const char *name=0);
     ~KCheckEduca();
 
-protected: // Protected methods
-    /**  */
+protected:
     void drawButtonLabel( QPainter *);
 
-private: // Private attributes
+private:
     /** Rich text */
     QSimpleRichText *_doc;
 };
