@@ -3,7 +3,7 @@
                              -------------------
     begin                : mi may 23 20:36:15 CEST 2001
     copyright            : (C) 2001 by Javier Campos
-    email                : javi_cms@terra.es
+    email                : javi@asyris.org
 ***************************************************************************/
 
 /***************************************************************************
@@ -17,7 +17,7 @@
 
 #include "keduca.h"
 #include "keduca.moc"
-
+#include "../libkeduca/kgallerydialog.h"
 #include "keducaprefs.h"
 
 #include <klocale.h>
@@ -53,12 +53,10 @@ void Keduca::init()
     layout_1->addStrut( 0 );
     QLabel *mainLabel = new QLabel(mainview, "mainLabel");
     mainLabel->setGeometry(0, 0, 256, 156);
-    mainLabel->setBackgroundColor(white);
     mainLabel->setAlignment( AlignHCenter|AlignVCenter );
     mainLabel->setPixmap( QPixmap( locate("appdata","pics/keduca_init.png") ) );
     layout_1->addWidget( mainLabel );
     mainview->show();
-
     this->setCentralWidget(mainview);
     this->setCaption( i18n("Main Window") );
 }
@@ -67,14 +65,13 @@ void Keduca::init()
 void Keduca::initMenuBar()
 {
     KStdAction::open(this, SLOT( slotFileOpen() ), actionCollection());
+    (void)new KAction(i18n("Open Gallery..."), 0, 0, this, SLOT( slotGallery() ), actionCollection(), "open_gallery");
     _recentFiles = KStdAction::openRecent(this, SLOT ( slotFileOpenURL(const KURL &)), actionCollection());
 //	KStdAction::print(this, SLOT( slotMenuPrint() ), actionCollection());
     KStdAction::close(this, SLOT( slotFileClose() ), actionCollection());
     KStdAction::quit(this, SLOT( close() ), actionCollection());
 
-    (void)new KAction(i18n("&Create/Modify..."), "control", 0, this, SLOT( slotControlDoc() ), actionCollection(), "control_doc");
-
-    KStdAction::showToolbar(this, SLOT( slotToggleToolBar()), actionCollection());
+    setStandardToolBarMenuEnabled(true);
     KStdAction::keyBindings(this, SLOT( slotConfigureKeys() ), actionCollection());
     KStdAction::configureToolbars(this, SLOT( slotConfigureToolbar() ), actionCollection());
     KStdAction::preferences(this, SLOT( slotConfigure()), actionCollection());
@@ -106,17 +103,6 @@ void Keduca::slotFileClose()
     init();
 }
 
-/** Start control documents */
-void Keduca::slotControlDoc()
-{
-    KControlDoc *pepe = new KControlDoc();
-    pepe->show();
-    if (_mainView != 0)
-        pepe->slotFileOpenURL(_mainView->getKeducaFile()->getCurrentURL());
-    else
-        pepe->startChooser();
-}
-
 /** Close the window */
 bool Keduca::queryClose()
 {
@@ -128,7 +114,6 @@ bool Keduca::queryClose()
 void Keduca::configRead()
 {
     KConfig *config = KGlobal::config();
-
     config->setGroup( "keduca" );
     this->applyMainWindowSettings( config, "keduca" );
     _recentFiles->loadEntries(config);
@@ -145,27 +130,26 @@ void Keduca::configWrite()
     config->sync();
 }
 
-/** Toggle toolbar */
-void Keduca::slotToggleToolBar()
-{
-    if(toolBar()->isVisible())
-        toolBar()->hide();
-    else
-        toolBar()->show();
-}
-
 /** Configure keys */
 void Keduca::slotConfigureKeys()
 {
-    KKeyDialog::configureKeys( actionCollection(), xmlFile() );
+    KKeyDialog::configure( actionCollection() );
 }
 
 /** Configure toolbar */
 void Keduca::slotConfigureToolbar()
 {
-    KEditToolbar edit( guiFactory(), this );
-    if( edit.exec() )
-        createGUI( "keducaui.rc" );
+    this->saveMainWindowSettings( KGlobal::config(), "keduca" );
+    KEditToolbar edit( actionCollection(), "keducaui.rc", this );
+    connect(&edit,SIGNAL(newToolbarConfig()),this,SLOT(slotNewToolbarConfig()));
+    edit.exec();
+}
+
+/** OK/Apply pressed in toolbar editor */
+void Keduca::slotNewToolbarConfig()
+{
+    createGUI( "keducaui.rc" );
+    this->applyMainWindowSettings( KGlobal::config(), "keduca" );
 }
 
 /** Configure keduca */
@@ -174,3 +158,21 @@ void Keduca::slotConfigure()
     KEducaPrefs pref;
     pref.exec();
 }
+
+/** Open gallery dialog */
+void Keduca::slotGallery()
+{
+  initGallery();
+}
+
+/** Open gallery window */
+void Keduca::initGallery(const KURL &urlFile)
+{
+    KGalleryDialog galleries;
+
+    if( !urlFile.url().isEmpty() )
+      galleries.putURL( urlFile );
+
+    if( galleries.exec() == QDialog::Accepted )
+      slotFileOpenURL( galleries.getURL() );
+}
