@@ -3,7 +3,7 @@
                              -------------------
     begin                : mi may 23 20:36:15 CEST 2001
     copyright            : (C) 2001 by Javier Campos
-    email                : javi_cms@terra.es
+    email                : javi@asyris.org
 ***************************************************************************/
 
 /***************************************************************************
@@ -23,7 +23,6 @@
 #endif
 
 #include "keducaview.h"
-#include "kcontroldoc.h"
 
 #include <kapplication.h>
 #include <kmainwindow.h>
@@ -42,8 +41,13 @@ public:
     Keduca(QWidget* parent=0, const char *name=0, WFlags f = WType_TopLevel | WDestructiveClose);
     /** destructor */
     ~Keduca();
+  /** Open gallery window */
+  void initGallery(const KURL &urlFile=0);
+
+private:
+
+    // Private methods
 
-private: // Private methods
     /** Init graphical interface */
     void init();
     /** Init menu bar settings */
@@ -54,30 +58,33 @@ private: // Private methods
     void configRead();
     /** Close the window */
     bool queryClose();
+
+    // Private attributes
+
     /** Recent files */
     KRecentFilesAction *_recentFiles;
     /** A KEDUCA file main view */
     KEducaView *_mainView;
 
-public slots: // Private slots
+public slots:
     /** Open a file */
     void slotFileOpenURL( const KURL &url );
     /** Open new file */
     void slotFileOpen();
 
-private slots: // Private slots
+private slots:
     /** Close actual document */
     void slotFileClose();
-    /** Start control documents */
-    void slotControlDoc();
     /** Configure toolbar */
     void slotConfigureToolbar();
     /** Configure keys */
     void slotConfigureKeys();
-    /** Toggle toolbar */
-    void slotToggleToolBar();
     /** Configure keduca */
     void slotConfigure();
+    /** OK/Apply pressed in toolbar editor */
+    void slotNewToolbarConfig();
+  /** Open gallery dialog */
+  void slotGallery();
 };
 
 #endif
