@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sat Jun 2 2001
     copyright            : (C) 2001 by Javier Campos
-    email                : javi_cms@terra.es
+    email                : javi@asyris.org
 ***************************************************************************/
 
 /***************************************************************************
@@ -41,6 +41,8 @@ void KEducaPrefs::setPageGeneral()
 {
     QVBox *mainFrame = addVBoxPage( i18n("Miscellaneous"), i18n("Various Settings"), DesktopIcon("misc"));
 
+
+    
     QButtonGroup *buttonGroup1 = new QButtonGroup( mainFrame, "ButtonGroup1" );
     buttonGroup1->setTitle( i18n( "General" ) );
     buttonGroup1->setColumnLayout(0, Qt::Vertical );
@@ -59,9 +61,23 @@ void KEducaPrefs::setPageGeneral()
     _resultAfterFinish->setText( i18n( "Show results when finish the test" ) );
     buttonGroup1Layout->addWidget( _resultAfterFinish );
 
-//	mainFrame->addWidget( buttonGroup1 );
-//	QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
-//	spacer->add( mainFrame );
+    QGroupBox *GroupBox1 = new QGroupBox( mainFrame, "GroupBox7" );
+    GroupBox1->setTitle( i18n( "Order" ) );
+    GroupBox1->setColumnLayout(0, Qt::Vertical );
+    GroupBox1->layout()->setSpacing( 0 );
+    GroupBox1->layout()->setMargin( 0 );
+    QVBoxLayout *GroupBox1Layout = new QVBoxLayout( GroupBox1->layout() );
+    GroupBox1Layout->setAlignment( Qt::AlignTop );
+    GroupBox1Layout->setSpacing( 6 );
+    GroupBox1Layout->setMargin( 11 );
+    
+    _randomQuestions = new QCheckBox( GroupBox1, "CheckBox1" );
+    _randomQuestions->setText( i18n( "Show questions in random order" ) );
+    GroupBox1Layout->addWidget( _randomQuestions );
+
+    _randomAnswers = new QCheckBox( GroupBox1, "CheckBox2" );
+    _randomAnswers->setText( i18n( "Show answers in random order" ) );
+    GroupBox1Layout->addWidget( _randomAnswers );
 }
 
 /** Read settings */
@@ -72,6 +88,8 @@ void KEducaPrefs::configRead()
     QSize defaultSize(500,400);
     this->resize( config->readSizeEntry("Geometry", &defaultSize ) );
     config->readBoolEntry("ResultFinish", true ) ? _resultAfterFinish->setChecked(true) : _resultAfterNext->setChecked(true);
+    config->readBoolEntry("RandomQuestions", false ) ? _randomQuestions->setChecked(true) : _randomQuestions->setChecked(false);
+    config->readBoolEntry("RandomAnswers", false ) ? _randomAnswers->setChecked(true) : _randomAnswers->setChecked(false);
 }
 
 /** Write settings */
@@ -81,6 +99,8 @@ void KEducaPrefs::configWrite()
     config->setGroup("Options");
     config->writeEntry("Geometry", this->size() );
     config->writeEntry("ResultFinish", _resultAfterFinish->isChecked() );
+    config->writeEntry("RandomQuestions", _randomQuestions->isChecked() );
+    config->writeEntry("RandomAnswers", _randomAnswers->isChecked() );
     config->sync();
 }
 
