@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sat Jun 2 2001
     copyright            : (C) 2001 by Javier Campos
-    email                : javi_cms@terra.es
+    email                : javi@asyris.org
 ***************************************************************************/
 
 /***************************************************************************
@@ -22,6 +22,7 @@
 #include <kdialogbase.h>
 
 #include <qradiobutton.h>
+#include <qcheckbox.h>
 
 /** Preferences for KEduca TestMaster (class KEduca)
  *@author Javier Campos
@@ -34,7 +35,10 @@ public:
     KEducaPrefs(QWidget *parent=0, const char *name=0, bool modal=true);
     ~KEducaPrefs();
 
-private: // Private methods
+private:
+
+    // Private methods
+
     /** Set page general */
     void setPageGeneral();
     /** Write settings */
@@ -42,13 +46,16 @@ private: // Private methods
     /** Read settings */
     void configRead();
 
-private: // Private attributes
+    // Private attributes
+
     /** Show result after next */
     QRadioButton *_resultAfterNext;
     /** Show results after finish */
     QRadioButton *_resultAfterFinish;
+    QCheckBox *_randomQuestions;
+    QCheckBox *_randomAnswers;
 
-private slots: // Private slots
+private slots:
     /** Push ok button */
     void slotOk();
 };
