@@ -3,7 +3,7 @@
                              -------------------
     begin                : Thu Sep 7 2000
     copyright            : (C) 2000 by Javier Campos Morales
-    email                : javi_c@ctv.es
+    email                : javi@asyris.org
 ***************************************************************************/
 
 /***************************************************************************
@@ -21,7 +21,6 @@
 #include "kradioeduca.h"
 
 #include <klocale.h>
-#include <iostream.h>
 #include <qscrollbar.h>
 
 KGroupEduca::KGroupEduca(QWidget *parent, const char *name ) : QVButtonGroup(i18n("Answers"), parent, name)
@@ -71,7 +70,8 @@ void KGroupEduca::setType(ButtonType type)
 /** Clear all kradio or kcheck answers */
 void KGroupEduca::clearAnswers()
 {
-    for( unsigned int i=0 ; i<10 ; ++i )
+    unsigned int maxButton = this->count();
+    for( unsigned int i=0 ; i<maxButton ; ++i )
     {
         QButton *tmpButton;
         if( (tmpButton = this->find(i)) )
@@ -94,7 +94,7 @@ bool KGroupEduca::isChecked(int id)
     break;
     case Check:
     {
-        KRadioEduca *tmpCheckButton = (KRadioEduca*) this->find(id);
+        KCheckEduca *tmpCheckButton = (KCheckEduca*) this->find(id);
         if(tmpCheckButton != 0) return tmpCheckButton->isChecked();
     }
     break;
