@@ -3,7 +3,7 @@
                              -------------------
     begin                : Thu Sep 7 2000
     copyright            : (C) 2000 by Javier Campos Morales
-    email                : javi_c@ctv.es
+    email                : javi@asyris.org
 ***************************************************************************/
 
 /***************************************************************************
@@ -23,10 +23,10 @@
 #include <qbutton.h>
 #include <qscrollview.h>
 #include <qvbox.h>
+
 /**
  *@author Javier Campos Morales
  */
-
 class KGroupEduca : public QVButtonGroup  {
     Q_OBJECT
 
@@ -47,7 +47,10 @@ public:
 protected:
     QVBox* _vbox2;
 
-private: // Private attributes
+private:
+
+    // Private attributes
+
     QScrollView *_sv;
     /** Type mode */
     ButtonType _typeMode;
