@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue May 22 2001
     copyright            : (C) 2001 by Javier Campos Morales
-    email                : javi_c@ctv.es
+    email                : javi@asyris.org
 ***************************************************************************/
 
 /***************************************************************************
@@ -55,6 +55,9 @@ void KQuestion::initGUI()
     _picture->setPalette( QPalette( QColor(255, 255, 255) ) );
     picLayout->addWidget( _picture );
 
+    QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
+    picLayout->addItem( spacer );
+
     _countdownWidget = new QProgressBar(this);
     _countdownWidget->setSizePolicy(QSizePolicy(QSizePolicy::Preferred,
                                                 QSizePolicy::Preferred));
@@ -75,9 +78,9 @@ void KQuestion::setText( const QString &text)
 }
 
 /** Set pixmap */
-void KQuestion::setPixmap( const QString &pixmap)
+void KQuestion::setPixmap( const QPixmap pixmap)
 {
-    _picture->setPixmap( QPixmap(pixmap) );
+    _picture->setPixmap( pixmap );
 }
 
 void KQuestion::countdown(int starttime)
@@ -118,3 +121,9 @@ void KQuestion::countdownVisible(bool visible)
   else
     _countdownWidget->hide();
 }
+
+/** Get current time */
+int KQuestion::getCurrentTime()
+{
+  return _totalCount - _currentCount;
+}
