@@ -3,7 +3,7 @@
                              -------------------
     begin                : Wed Sep 6 2000
     copyright            : (C) 2000 by Javier Campos Morales
-    email                : javi_c@ctv.es
+    email                : javi@asyris.org
 ***************************************************************************/
 
 /***************************************************************************
