@@ -16,6 +16,7 @@
 #include <kstandarddirs.h>
 #include <kstatusbar.h>
 #include <kstdaction.h>
+#include <kstdguiitem.h>
 
 #include <qcheckbox.h>
 #include <qclipboard.h>
@@ -46,7 +47,7 @@ TopLevel::TopLevel(QWidget *parent, const char *name) : KMainWindow(parent, name
 
 	Accel = new KGlobalAccel(this);
 	(void) Accel->insert("Lookup Kanji (Kanjidic)", i18n("Lookup Kanji (Kanjidic)"), i18n("Gives detailed information about Kanji currently on clipboard."), CTRL + ALT + Key_K, CTRL + ALT + Key_K, this, SLOT(kanjiSearchAccel()));
-	(void) Accel->insert("Lookup English/Japanese word", i18n("Lookup English/Japanese word"), i18n("Looks up current text on clipboard in the same way as if you used Kiten's regular search."), CTRL + ALT + Key_S, CTRL + ALT + Key_S, this, SLOT(searchAccel()));
+	(void) Accel->insert("Lookup English/Japanese word", i18n("Lookup English/Japanese Word"), i18n("Looks up current text on clipboard in the same way as if you used Kiten's regular search."), CTRL + ALT + Key_S, CTRL + ALT + Key_S, this, SLOT(searchAccel()));
 	Accel->readSettings(KGlobal::config());
 	Accel->updateConnections();
 
@@ -61,7 +62,7 @@ TopLevel::TopLevel(QWidget *parent, const char *name) : KMainWindow(parent, name
 	(void) new KAction(i18n("&Dictionary Editor..."), "edit", 0, this, SLOT(createEEdit()), actionCollection(), "dict_editor");
 	(void) new KAction(i18n("Ra&dical Search..."), "gear", CTRL+Key_R, this, SLOT(radicalSearch()), actionCollection(), "search_radical");
 	Edit = new EditAction(i18n("Search Edit"), 0, this, SLOT(search()), actionCollection(), "search_edit");
-	(void) new KAction(i18n("Clear"), BarIcon("locationbar_erase", 16), 0, Edit, SLOT(clear()), actionCollection(), "clear_search");
+	(void) new KAction(KStdGuiItem::clear().text(), BarIcon("locationbar_erase", 16), 0, Edit, SLOT(clear()), actionCollection(), "clear_search");
 	(void) new KAction(i18n("&Search"), "key_enter", 0, this, SLOT(search()), actionCollection(), "search");
 	(void) new KAction(i18n("Search with &Beginning of Word"), 0, this, SLOT(searchBeginning()), actionCollection(), "search_beginning");
 	(void) new KAction(i18n("&Search Anywhere"), 0, this, SLOT(searchAnywhere()), actionCollection(), "search_anywhere");
@@ -101,16 +102,22 @@ TopLevel::TopLevel(QWidget *parent, const char *name) : KMainWindow(parent, name
 	slotUpdateConfiguration();
 	if (autoCreateLearn)
 		createLearn();
-	
+
 	resize(600, 400);
 	applyMainWindowSettings(KGlobal::config(), "TopLevelWindow");
 
 	connect(_ResultView, SIGNAL(linkClicked(const QString &)), SLOT(ressearch(const QString &)));
 	connect(kapp->clipboard(), SIGNAL(selectionChanged()), this, SLOT(autoSearch()));
-	
+
 	QTimer::singleShot(10, this, SLOT(finishInit()));
 }
 
+TopLevel::~TopLevel()
+{
+    delete optionDialog;
+    optionDialog = 0;
+}
+
 void TopLevel::finishInit()
 {
 	if (kanjiCB->isChecked())
@@ -223,7 +230,7 @@ void TopLevel::handleSearchResult(Dict::SearchResult results)
 	_ResultView->clear();
 
 	Dict::Entry first = Dict::firstEntry(results);
-	
+
 	if (results.count > 0)
 		kanjiCB->setChecked(first.extendedKanjiInfo());
 	else
@@ -242,12 +249,12 @@ void TopLevel::handleSearchResult(Dict::SearchResult results)
 			addAction->setEnabled(true);
 
 			_ResultView->append(QString("<p>%1</p>").arg(i18n("HTML Entity: %1").arg(QString("&amp;#x%1;").arg(QString::number(toAddKanji.kanji().at(0).unicode(), 16))))); // show html entity
-	
+
 			// now show some compounds in which this kanji appears
 			QString kanji = toAddKanji.kanji();
-		
+
 			_ResultView->addHeader(i18n("%1 in compounds").arg(kanji));
-		
+
 			Dict::SearchResult compounds = _Index.search(QRegExp(kanji), kanji, true);
 			bool common = true;
 			if (compounds.count <= 0)
@@ -256,7 +263,7 @@ void TopLevel::handleSearchResult(Dict::SearchResult results)
 				_ResultView->addHeader(i18n("(No common compounds)"), 4);
 				common = false;
 			}
-	
+
 			for (QValueListIterator<Dict::Entry> it = compounds.list.begin(); it != compounds.list.end(); ++it)
 			{
 				//kdDebug() << "adding " << (*it).kanji() << endl;
@@ -390,7 +397,7 @@ void TopLevel::search(bool inResults)
 
 					//kdDebug() << "currently on deinflection " << *it << endl;
 					Dict::SearchResult results = _Index.search(QRegExp(QString("^") + (*it) + "\\W"), *it, common);
-					
+
 					if (results.count < 1) // stop if it isn't in the dictionary
 						continue;
 
@@ -467,7 +474,7 @@ void TopLevel::strokeSearch()
 
 		//kdDebug() << "strokesString is " << strokesString << endl;
 		*/
-		
+
 		StatusBar->message(i18n("Unparseable number"));
 		return;
 	}
@@ -525,6 +532,16 @@ QString TopLevel::clipBoardText() // gets text from clipboard for globalaccels
 	return text;
 }
 
+QString TopLevel::filteredClipboardText()
+{
+	QString newText = clipBoardText();
+	QString currentText = Edit->text();
+	if (newText.length() < 80 && newText.find(':') < 0 && newText.find('#') < 0 && newText.find("-") != 0 && newText.find("+") < 0 && currentText.find(newText) < 0)
+		return newText;
+	else
+		return QString::null;
+}
+
 void TopLevel::autoSearch()
 {
 	if (autoSearchToggle->isChecked())
@@ -533,28 +550,36 @@ void TopLevel::autoSearch()
 
 void TopLevel::searchAccel()
 {
-	kanjiCB->setChecked(false);
+	QString newText = filteredClipboardText();
+	if (!newText.isNull())
+	{
+		kanjiCB->setChecked(false);
 
-	raise();
+		raise();
 
-	Edit->setText(clipBoardText());
-	search();
+		Edit->setText(newText);
+		search();
+	}
 }
 
 void TopLevel::kanjiSearchAccel()
 {
-	kanjiCB->setChecked(true);
+	QString newText = filteredClipboardText();
+	if (!newText.isNull())
+	{
+		kanjiCB->setChecked(true);
 
-	raise();
+		raise();
 
-	Edit->setText(clipBoardText());
-	search();
+		Edit->setText(newText);
+		search();
+	}
 }
 
 void TopLevel::setResults(unsigned int results, unsigned int fullNum)
 {
 	QString str = i18n("%n result","%n results",results);
-	
+
 	if (results < fullNum)
 		str += i18n(" out of %1").arg(fullNum);
 
@@ -569,7 +594,7 @@ void TopLevel::slotUpdateConfiguration()
 	QString globaledict = dirs->findResource("appdata", "edict");
 	QString globalkanjidic = dirs->findResource("appdata", "kanjidic");
 	personalDict = KGlobal::dirs()->saveLocation("appdata", "dictionaries/", true).append("personal");
-	
+
 	config->setGroup("edict");
 
 	edictUseGlobal = config->readBoolEntry("__useGlobal", true);
@@ -587,8 +612,8 @@ void TopLevel::slotUpdateConfiguration()
 		DictList.prepend(personalDict);
 		DictNameList.prepend(i18n("Personal"));
 	}
-	
-	if (globaledict != QString::null && edictUseGlobal)
+
+	if (!globaledict.isNull() && edictUseGlobal)
 	{
 		DictList.prepend(globaledict);
 		DictNameList.prepend("Edict");
@@ -606,7 +631,7 @@ void TopLevel::slotUpdateConfiguration()
 	for (it = DictNameList.begin(); it != DictNameList.end(); ++it)
 		DictList.append(config->readEntry(*it));
 
-	if (globalkanjidic != QString::null && kanjidicUseGlobal)
+	if (!globalkanjidic.isNull() && kanjidicUseGlobal)
 	{
 		DictList.prepend(globalkanjidic);
 		DictNameList.prepend("Kanjidic");
@@ -629,7 +654,7 @@ void TopLevel::slotConfigure()
 	if (optionDialog == 0)
 	{
 		optionDialog = new ConfigureDialog(Accel, 0);
-		if (optionDialog == 0) 
+		if (optionDialog == 0)
 			return;
 		connect(optionDialog, SIGNAL(hidden()),this,SLOT(slotConfigureHide()));
 		connect(optionDialog, SIGNAL(valueChanged()), this, SLOT(slotUpdateConfiguration()));
@@ -746,7 +771,7 @@ QRegExp TopLevel::searchItems()
 		regexp = "%1";
 
 	regexp = regexp.arg(text);
-	
+
 	return QRegExp(regexp, caseSensitive);
 }
 
@@ -764,14 +789,12 @@ void TopLevel::configureToolBars()
 	saveMainWindowSettings(KGlobal::config(), "TopLevelWindow");
 	KEditToolbar dlg(actionCollection(), "kitenui.rc");
 	connect(&dlg, SIGNAL(newToolbarConfig()), SLOT(newToolBarConfig()));
-	if (dlg.exec())
-	{
-		createGUI("kitenui.rc");
-	}
+	dlg.exec();
 }
 
 void TopLevel::newToolBarConfig()
 {
+	createGUI("kitenui.rc");
 	applyMainWindowSettings(KGlobal::config(), "TopLevelWindow");
 }
 
