@@ -32,7 +32,7 @@
 const int Learn::numberOfAnswers = 5;
 
 Learn::Learn(Dict::Index *parentDict, QWidget *parent, const char *name)
-	: KMainWindow(parent, name), curItem(0), initialized(false)
+	: KMainWindow(parent, name), initialized(false), isMod(false), prevItem(0), curItem(0)
 {
 	index = parentDict;
 
@@ -156,7 +156,7 @@ void Learn::finishCtor()
 	updateQuizConfiguration(); // first
 
 	config.setGroup("Learn");
-	QString entry = config.readEntry("lastFile", QString(""));
+	QString entry = config.readPathEntry("lastFile");
 	//kdDebug() << "lastFile: " << entry << endl;
 	if (!entry.isEmpty())
 	{
@@ -180,7 +180,7 @@ bool Learn::warnClose()
 {
 	if (isMod)
 	{
-		int result = KMessageBox::warningYesNoCancel(this, i18n("There are unsaved changes to learning list. Save them?"), i18n("Unsaved Changes"), i18n("Save"), i18n("Discard"), "DiscardAsk", true);
+		int result = KMessageBox::warningYesNoCancel(this, i18n("There are unsaved changes to learning list. Save them?"), i18n("Unsaved Changes"), KStdGuiItem::save(), KStdGuiItem::discard(), "DiscardAsk", true);
 		switch (result)
 		{
 		case KMessageBox::Yes:
@@ -244,7 +244,7 @@ void Learn::prev()
 		if (!prevItem)
 			return;
 		curItem = prevItem;
-	
+
 		statusBar()->clear();
 		qupdate();
 		nogood = true;
@@ -271,12 +271,12 @@ void Learn::update()
 	View->addKanjiResult(curKanji);
 
 	// now show some compounds in which this kanji appears
-	
+
 	QString kanji = curKanji.kanji();
 
 	Dict::SearchResult compounds = index->search(QRegExp(kanji), kanji, true);
 	View->addHeader(i18n("%1 in compounds").arg(kanji));
-	
+
 	for (QValueListIterator<Dict::Entry> it = compounds.list.begin(); it != compounds.list.end(); ++it)
 	{
 		kapp->processEvents();
@@ -358,7 +358,7 @@ void Learn::open()
 	//kdDebug() << "saving lastFile\n";
 	KConfig &config = *kapp->config();
 	config.setGroup("Learn");
-	config.writeEntry("lastFile", filename.url());
+	config.writePathEntry("lastFile", filename.url());
 	config.sync();
 
 	// redo quiz, because we deleted the current quiz item
@@ -408,7 +408,7 @@ void Learn::save()
 	KConfig &config = *kapp->config();
 	//kdDebug() << "saving lastFile\n";
 	config.setGroup("Learn");
-	config.writeEntry("lastFile", filename.url());
+	config.writePathEntry("lastFile", filename.url());
 	config.sync();
 }
 
@@ -616,6 +616,9 @@ void Learn::print()
 
 void Learn::answerClicked(int i)
 {
+	if (!curItem)
+		return;
+
 	int newscore = 0;
 	KConfig &config = *kapp->config();
 	config.setGroup("Learn");
@@ -698,7 +701,7 @@ QString Learn::randomMeaning(QStringList &oldMeanings)
 			rand = List->childCount() / rand2;
 
 			int max = (int) rand;
-		
+
 			QListViewItemIterator it(List);
 			it += max;
 
@@ -808,7 +811,12 @@ QString Learn::shortenString(QString thestring)
 
 void Learn::tabChanged(QWidget *widget)
 {
-	bool isQuiz = widget == quizTop;
+	bool isQuiz = (widget == quizTop);
+
+	if (isQuiz)
+		backAct->setEnabled(prevItem != 0);
+	else
+		backAct->setEnabled(true);
 
 	forwardAct->setEnabled(!isQuiz);
 	gradeAct->setEnabled(!isQuiz);
@@ -896,6 +904,9 @@ void Learn::setClean()
 
 void Learn::qKanjiClicked()
 {
+	if (!curItem)
+		return;
+
 	showKanji(curItem);
 	nogood = true;
 }
