@@ -15,7 +15,7 @@ void noMessageOutput(QtMsgType, const char *)
 
 static KCmdLineOptions options[] =
 {
-	{ 0, 0, 0 }
+	KCmdLineLastOption
 	// INSERT YOUR COMMANDLINE OPTIONS HERE
 };
 
@@ -29,6 +29,7 @@ int main(int argc, char *argv[])
 	aboutData.addAuthor("Jason Katz-Brown", I18N_NOOP("Original author"), "jason@katzbrown.com");
 	aboutData.addCredit("Jim Breen", I18N_NOOP("Wrote xjdic, of which Kiten borrows code, and the xjdic index file generator.\nAlso is main author of edict and kanjidic, which Kiten essentially require."), "jwb@csse.monash.edu.au");
 	aboutData.addAuthor("Neil Stevens", I18N_NOOP("Code simplification, UI suggestions."), "neil@qualityassistant.com");
+	aboutData.addCredit("David Vignoni", I18N_NOOP("SVG icon" ), "david80v@tin.it");
 
 	KCmdLineArgs::init(argc, argv, &aboutData);
 	KCmdLineArgs::addCmdLineOptions(options); // Add our own options.
