@@ -6,18 +6,14 @@
 #include <kprocess.h>
 #include <kdebug.h>
 #include <kstandarddirs.h>
-#include <kconfig.h>
 #include <kapplication.h>
 #include <klocale.h>
 
 //Qt...
-#include <qwidget.h>
 #include <qcheckbox.h>
 #include <qlineedit.h>
 #include <qpushbutton.h>
 #include <qcombobox.h>
-#include <qdir.h>
-#include <qfileinfo.h>
 #include <qlabel.h>
 
 //System...
