@@ -3,7 +3,7 @@
                              -------------------
     begin                : Thu Aug 2 2001
     copyright            : (C) 2001 by Primoz Anzur (zer0Kode)
-    email                : zerokode@yahoo.com
+    email                : zerokode@gmx.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,38 +18,40 @@
 #ifndef KWRITEWORDS_H
 #define KWRITEWORDS_H
 
-#include <qwidget.h>
-#include <kmwdict.h>
 #include <qmultilineedit.h>
 #include <qfile.h>
-#include <qpushbutton.h>
-#include <qtextstream.h>
-#include <kmessagebox.h>
-#include <kglobal.h>
 #include <kstandarddirs.h>
 #include <klocale.h>
 
+#include "kmwdict.h"
+
 /**
   *@author Primoz Anzur (zer0Kode)
   */
 
 class KWriteWords : public WordsEditor  {
    Q_OBJECT
-public: 
+public:
 	KWriteWords(QWidget *parent=0, const char *name=0);
 	~KWriteWords();
-	
+
 	void saveStreamToText();
 	void openDataStream();
-	
+
 public slots:
-   virtual void slotSaveWords();
-   virtual void slotCancel();
-   virtual void slotOK();
+	virtual void slotSaveWords();
+	virtual void slotCancel();
+	virtual void slotOK();
 
 protected:
-    QString kMessedDataDir;
-    QString setLocalDictionary;
+	QString kMessedDataDir;
+	QString setLocalDictionary;
+
+protected slots:
+        void closeEvent (QCloseEvent *);
+
+signals:
+	void getClose();
 };
 
 #endif
