@@ -3,7 +3,7 @@
                              -------------------
     begin                : Thu Jul 19 00:06:05 CEST 2001
     copyright            : (C) 2001 by Primoz Anzur (zer0Kode)
-    email                : zerokode@yahoo.com
+    email                : zerokode@gmx.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -17,20 +17,15 @@
 
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
-#include <klocale.h>
 
 #include "mainwindow.h"
-//#include "splashscreen.h"
 
-static const char *description =
+static const char description[] =
 	I18N_NOOP("Letter Order Game");
-// INSERT A DESCRIPTION FOR YOUR APPLICATION HERE
-
 
 static KCmdLineOptions options[] =
 {
-  { 0, 0, 0 }
-  // INSERT YOUR COMMANDLINE OPTIONS HERE
+    KCmdLineLastOption
 };
 
 int main(int argc, char *argv[])
@@ -39,9 +34,10 @@ int main(int argc, char *argv[])
   KAboutData aboutData( "kmessedwords", I18N_NOOP("KMessedWords"),
     LOCAL_VERSION, description, KAboutData::License_GPL,
     "(c) 2001 - 2002, Whitehawk Stormchaser", 0, "http://edu.kde.org/kmessedwords", "submit@bugs.kde.org");
-  aboutData.addAuthor("Whitehawk Stormchaser","Creator, maintainer, graphic design", "zerokode@gmx.net");
-  aboutData.addCredit("Waldo Bastian","Created the core KMW engine / improved syllables engine", "bastian@kde.org");
-  aboutData.addCredit("Chris Howells","Added \"Help\" menu", "howells@kde.org");
+  aboutData.addAuthor("Whitehawk Stormchaser", I18N_NOOP("Creator, maintainer, graphic design"), "zerokode@gmx.net");
+  aboutData.addCredit("Waldo Bastian", I18N_NOOP("Created the core KMW engine / improved syllables engine"), "bastian@kde.org");
+  aboutData.addCredit("Chris Howells", I18N_NOOP("Added \"Help\" menu"), "howells@kde.org");
+  aboutData.addCredit("David Vignoni", I18N_NOOP("SVG icon" ), "david80v@tin.it");
   KCmdLineArgs::init( argc, argv, &aboutData );
   KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
 
