@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sun Oct 21 2001
     copyright            : (C) 2001 by Primoz Anzur (zer0Kode)
-    email                : zerokode@yahoo.com
+    email                : zerokode@gmx.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,28 +18,14 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
-#define LOCAL_VERSION "2.1"
+#define LOCAL_VERSION "2.2"
 //CVS version changes ONLY with major overhaul OR submission of new features...
 
-#include <kapplication.h>
-#include <qwidget.h>
-#include <frontend.h>
-#include <qtimer.h>
-#include <qbutton.h>
-#include <qlabel.h>
-#include <qcombobox.h>
-#include <qlineedit.h>
+#include "frontend.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <kmessagebox.h>
-#include <krandomsequence.h>
-#include <qptrlist.h>
-#include <qpushbutton.h>
 #include <kpopupmenu.h>
-#include <kstandarddirs.h>
-#include <klocale.h>
-#include <kconfig.h>
-#include <qevent.h>
 #include <khelpmenu.h>
 
 #include "kwritewords.h"
@@ -53,44 +39,44 @@ class MainWindow : public FrontEnd
 {
   Q_OBJECT
 public:
-    /** construtor */
-    MainWindow(QWidget* parent=0, const char *name=0);
-    /** destructor */
-    ~MainWindow();
+	/** construtor */
+	MainWindow(QWidget* parent=0, const char *name=0);
+	/** destructor */
+	~MainWindow();
 
 
-    int guesses;
-    int tGuesses; //t stands for total
-    int messups;
-    int solvedWords;
-	 void randomizer(int level);
-    void confuse_words();
-    void reloadStructure();
-    QPushButton *btnInvisible;
-	 KPopupMenu *mainMenu;
-    QString shareLoginName;
-	 KWriteWords showConfig;
-    KWriteWords configInputData;
-    HighScores showScores;
-    QString themeName;
-	 Config *cfg;
-    bool isThemeBtn;
-	 void loadPopupMenu();
-	 bool emitSolved;
-	 KmwConfigurator *newCfg;
-	 	
+	int guesses;
+	int tGuesses; //t stands for total
+	int messups;
+	int solvedWords;
+	void randomizer(int level);
+	void confuse_words();
+	void reloadStructure();
+	QPushButton *btnInvisible;
+	KPopupMenu *mainMenu;
+	QString shareLoginName;
+	KWriteWords showConfig;
+	KWriteWords configInputData;
+	HighScores showScores;
+	QString themeName;
+	Config *cfg;
+	bool isThemeBtn;
+	void loadPopupMenu();
+	bool emitSolved;
+	KmwConfigurator *newCfg;
+
 public slots:
-    virtual void slot_close();
-    virtual void slot_messup();
-    virtual void slot_try();
-    virtual void slot_textAccel();
-    virtual void slot_scores();
-    virtual void slot_changeLevel();
-    void slot_openBook();
-	 void showAppConfig();
-	 void winRefresh();
-	 void theEnd();
-	 void theReply();
+	virtual void slot_close();
+	virtual void slot_messup();
+	virtual void slot_try();
+	virtual void slot_textAccel();
+	virtual void slot_scores();
+	virtual void slot_changeLevel();
+	void slot_openBook();
+	void showAppConfig();
+	void winRefresh();
+	void theEnd();
+	void theReply();
 
 protected:
     QString messedWord;
@@ -107,12 +93,6 @@ protected:
 	 int readRounds[10];
 	 int readTotal[10];
 	 int readGuesses[10];
-	 QString varrounds;
-	 QString varnames;
-	 QString varsolved;
-	 QString vartotal;
-	 QString varguesses;
-    QString justtext;	
     void closeEvent(QCloseEvent *);
 	 KHelpMenu *helpMenu;
 	 MinParser *silly;
