@@ -3,7 +3,7 @@
 *
 * Copyright (C) 1998, 1999  Klaus-Dieter Mller
 *               2000, 2002 kd.moeller@t-online.de
-*               
+*
 * This file is part of the KDE Project.
 * KmPlot is part of the KDE-EDU Project.
 *
@@ -11,15 +11,15 @@
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
-* 
+*
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
-* 
+*
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
-* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
 
@@ -83,8 +83,6 @@ public slots:
 	void print();
 	void bezeichnungen();
 	// void quit();
-	void stbmode();
-	void tbmode();
 	void funktionen();
 	void skalierung();
 	void schrittw();
@@ -111,11 +109,15 @@ private:
 	int tbid,
 	stbid;
 	KStatusBar *stbar;
-	KToggleAction *viewToolBar;
-	KToggleAction *viewStatusBar;
 	FktDlg *fdlg;
 	BezWnd *bez;
 	KToggleAction *view_bezeichnungen;
 	View *view;
+
+private slots:
+  void newToolbarConfig();
+  void optionsConfigureKeys();
+  void optionsConfigureToolbars();
+
 };
 #endif // MainDlg_included
