@@ -28,6 +28,7 @@
 //
 //						KDM  2.5.95
 
+
 #ifndef parser_included
 #define parser_included
 
@@ -63,14 +64,15 @@
 // benutzerdefinierte Funktion
 #define	ENDE	12      // Funktionsende
 
-#define	FANZ	17		// Anzahl der math. Funktionen
+#define	FANZ	19		// Anzahl der math. Funktionen
 // in mfkttab[]
 
 
-double	sqr( double x ),
-arsinh( double x ),
-arcosh( double x ),
-artanh( double x );
+double sign(double x),
+sqr(double x),
+arsinh(double x),
+arcosh(double x),
+artanh(double x);
 
 
 class Parser
@@ -78,100 +80,97 @@ class Parser
 public:
 
 	Parser();
-	Parser( int, int, int );
+	Parser(int, int, int);
 
-	double	eval( QString );
-	double	fkt( QString, double );
-	double	fkt( int ix, double x ) {
-		return ufkt[ ix ].fkt( x );
-	}
-	int	addfkt( QString ),
-	delfkt( QString );
+	double	eval(QString);
+	double	fkt(QString, double);
+	double	fkt(int ix, double x) {return ufkt[ix].fkt(x);}
+	int	addfkt(QString),
+	delfkt(QString);
 
-	int delfkt( int );
-	int	chkfix( int ),
-	getfkt( int, QString&, QString& ),
-	getfix( QString ),
+	int delfkt(int);
+	int	chkfix(int),
+	getfkt(int, QString&, QString&),
+	getfix(QString),
 	errmsg();
 
-	void	setparameter( int ix, double k ) {
-		ufkt[ ix ].k = k;
-	}
+	void setparameter(int ix, double k) {ufkt[ix].k=k;}
 
 	~Parser();
 
 	int	err, 		// Fehlercode:
-	// 	0 => parse erfolgreich
-	//	1 => Syntaxfehler
-	//	2 => fehlende Klammer
-	//	3 => Funktion nicht bekannt
-	//	4 => ungltige Funktionsvariable
-	//	5 => zu viele Funktionen
-	//	6 => Speicherberlauf
-	//	7 => Stackberlauf
-	//  8 => Funktionsname bereits vergeben
+	                // 	0 => parse erfolgreich
+	                //	1 => Syntaxfehler
+	                //	2 => fehlende Klammer
+	                //	3 => Funktion nicht bekannt
+	                //	4 => ungltige Funktionsvariable
+	                //	5 => zu viele Funktionen
+	                //	6 => Speicherberlauf
+	                //	7 => Stackberlauf
+	                //  8 => Funktionsname bereits vergeben
+					//  9 => rekursiver Funktionsaufruf
 	errpos, 		// Fehlerposition
-	ufanz;		// max. Anzahl benutzer-
-	// definierter Funktionen
+	ufanz;		    // max. Anzahl benutzer-
+	                // definierter Funktionen
 
 protected:
-	class Ufkt
+
+    class Ufkt
 	{
 	public:
 
 		Ufkt();
 
-		double	fkt( double );	// benutzerdefinierte Funktion
+		double	fkt(double);	// benutzerdefinierte Funktion
 
 		~Ufkt();
 
 		unsigned
-		char *mem, 		// Zeiger auf Tokenspeicher
-		*mptr;		// Zeiger auf Token
-		QString	fname, 	// Funktionsname
-		fvar, 		// Funktionsvariable
-		fpar, 		// Parameter
-		fstr;		// Funktionsterm
-		int	memsize, 	// Gre des Tokenspeichers
-		stacksize;	// Gre des Stack
-		double	k;		// Funktionsparameter
+		char *mem, 		        // Zeiger auf Tokenspeicher
+		*mptr;		            // Zeiger auf Token
+		QString	fname, 	        // Funktionsname
+		fvar, 		            // Funktionsvariable
+		fpar, 		            // Parameter
+		fstr;		            // Funktionsterm
+		int	memsize, 	        // Gre des Tokenspeichers
+		stacksize;	            // Gre des Stack
+		double	k;		        // Funktionsparameter
 
 	}
 	*ufkt;
 
 	struct Mfkt
-	{
-		const char *mfstr;
-		double ( *mfadr ) ( double );
+	{   const char *mfstr;
+		double (*mfadr)(double);
 	};
-	static Mfkt mfkttab[ FANZ ];
+	static Mfkt mfkttab[FANZ];
 
 private:
 
-	void ps_init( int, int, int ),
+	void ps_init(int, int, int),
 	heir1(),
 	heir2(),
 	heir3(),
 	heir4(),
 	primary(),
-	addtoken( unsigned char ),
-	addwert( double ),
-	addfptr( double( * ) ( double ) ),
-	addfptr( Ufkt* );
-	int match( const char* );
+	addtoken(unsigned char),
+	addwert(double),
+	addfptr(double(*)(double)),
+	addfptr(Ufkt*);
+	int match(const char*);
 
 	unsigned
 	char evalflg, 		// 0 => String wird tokenisiert
-	// 1 => String wird direkt ausgewertet
-	*mem, 			// Zeiger auf Speicher fr Token
-	*mptr;			// Zeiger fr Token
+	                    // 1 => String wird direkt ausgewertet
+	*mem, 			    // Zeiger auf Speicher fr Token
+	*mptr;			    // Zeiger fr Token
 	const
 	char *lptr;			// Zeiger fr Funktions-String
-	int	memsize,         // Gre des Tokenspeichers
-	stacksize,       // Gre des Stack
-	ixa;			// Index der aktuellen Funktion
+	int	memsize,        // Gre des Tokenspeichers
+	stacksize,          // Gre des Stack
+	ixa;			    // Index der aktuellen Funktion
 	double *stack, 		// Zeiger auf Stackanfang
-	*stkptr;		// Stackpointer
+	*stkptr;		    // Stackpointer
 };
 
 #endif	// parser_included
