@@ -35,6 +35,7 @@
 #include <klocale.h>
 #include <kpushbutton.h>
 #include <kstandarddirs.h>
+#include <kstdguiitem.h>
 
 // local includes
 #include "kanimation.h"
@@ -52,7 +53,7 @@ KAnswer::KAnswer( QWidget *parent ): KDialog( parent, "answer", TRUE )
 
     setupSprite();
 
-    ButtonOK = new KPushButton( i18n( "OK" ), this );
+    ButtonOK = new KPushButton( KStdGuiItem::ok(), this );
     // for the bottons edges
     ButtonOK->setBackgroundOrigin( QPushButton::ParentOrigin );
     ButtonOK->setIconSet( QIconSet( DesktopIcon( "button_accept" ) ) );
@@ -169,7 +170,7 @@ void KAnswer::setAnswer( int modus )
         TextLabelAnswer->setText( i18n( "Great!\nYou managed all\nthe exercises!" ) );
         correct = true;
     }
-    
+
     if (correct)
     {
         wrong_animation->hide();
@@ -180,7 +181,7 @@ void KAnswer::setAnswer( int modus )
         wrong_animation->show();
         right_animation->hide();
     }
-    
+
     wrong_animation->setToStart();
     wrong_animation->setAnimated( !correct );
     right_animation->setToStart();
@@ -188,7 +189,7 @@ void KAnswer::setAnswer( int modus )
     canvas->setAllChanged();
     canvas->update();
     canvas->setAdvancePeriod( advPer );
-    
+
 	 // this seems to be needed for proper showing TextLabelAnswer :-(
     resize( width(), height() );
 }
@@ -212,7 +213,7 @@ void KAnswer::setupSprite()
 {
 
     advPer = 80;
-    
+
     canvas = new QCanvas( this );
     canvas->resize( size().width(), size().height() );
     pixs = new QCanvasPixmapArray( locate( "data", "kpercentage/pics/" )+"smily%1.png", 7 );
