@@ -40,6 +40,8 @@
 #include <kicontheme.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
+#include <kstdguiitem.h>
+#include <knumvalidator.h>
 
 // local includes
 #include "kanswer.h"
@@ -57,15 +59,19 @@ KPercentMain::KPercentMain( QWidget *parent, const char *name ) :
     setFixedSize( QSize( 520, 275 ) );
     setBackgroundPixmap( bgp );
     setBackgroundOrigin( QDialog::ParentOrigin );
+    KIntValidator *validLine = new KIntValidator( this );
 
     line_edit_percentage = new QLineEdit( this, "line_edit_percentage" );
     line_edit_percentage->setAlignment( int( QLineEdit::AlignHCenter ) );
+    line_edit_percentage->setValidator( validLine );
 
     line_edit_basevalue = new QLineEdit( this, "line_edit_basevalue" );
     line_edit_basevalue->setAlignment( int( QLineEdit::AlignHCenter ) );
+    line_edit_basevalue->setValidator( validLine );
 
     line_edit_percentvalue = new QLineEdit( this, "line_edit_percentvalue" );
     line_edit_percentvalue->setAlignment( int( QLineEdit::AlignHCenter ) );
+    line_edit_percentvalue->setValidator( validLine );
 
     progress_bar_count = new QProgressBar( this, "progress_bar_count" );
     progress_bar_count->setFrameShape( QProgressBar::Panel );
@@ -87,13 +93,13 @@ KPercentMain::KPercentMain( QWidget *parent, const char *name ) :
     label_wrong->setBackgroundOrigin( QDialog::ParentOrigin );
 
     push_button_apply = new QPushButton( this, "push_button_apply" );
-    push_button_apply->setText( i18n( "&Apply" ) );
+    push_button_apply->setText( KStdGuiItem::apply().text() );
     push_button_apply->setDefault( TRUE );
     push_button_apply->setBackgroundPixmap( bgp);
     push_button_apply->setBackgroundOrigin( QPushButton::ParentOrigin );
 
     push_button_cancel = new QPushButton( this, "push_button_cancel" );
-    push_button_cancel->setText( i18n( "&Cancel" ) );
+    push_button_cancel->setText( KStdGuiItem::cancel().text() );
 
     KIconLoader icon_loader;
     push_button_apply->setIconSet( QIconSet( icon_loader.loadIcon( "button_accept", KIcon::NoGroup, 32 ) ) );
@@ -157,7 +163,7 @@ KPercentMain::KPercentMain( QWidget *parent, const char *name ) :
     right_wrong_layout->addWidget( label_right );
     right_wrong_layout->addWidget( progress_bar_right_wrong );
     right_wrong_layout->addWidget( label_wrong );
-    
+
     bottom_layout->addSpacing( 40 );
 
     QVBoxLayout *button_layout = new QVBoxLayout ( bottom_layout, -1, "button_layout" );
@@ -175,12 +181,12 @@ KPercentMain::KPercentMain( QWidget *parent, const char *name ) :
 
 	///////////
 	// ToolTips
-	
+
 	QToolTip::add( progress_bar_count, i18n( "Number of managed exercises" ) );
 	QToolTip::add( progress_bar_right_wrong, i18n( "Relation of right to wrong inputs" ) );
 	QToolTip::add( push_button_apply, i18n( "Apply your input" ) );
 	QToolTip::add( push_button_cancel, i18n( "Back to the main window" ) );
-	
+
     // signals and slots connections
     connect( push_button_apply, SIGNAL( clicked() ), this, SLOT( slotApplyInput() ) );
     connect( push_button_cancel, SIGNAL( clicked() ), this, SLOT( accept() ) );
@@ -359,8 +365,8 @@ void KPercentMain::initExercise()
             const int values[] = { 1, 10, 25, 50, 75, 100, 10, 25, 50, 75};
             ::memcpy(percentage, values, sizeof(values));
 		}
- 
-		
+
+
 		int num;
         if ( number < 6 )    /* for only few tasks, chose from the first 6 numbers */
         {
