@@ -33,7 +33,7 @@
 
 /* creates the splash window without titlebar and border */
 KSplashScreen::KSplashScreen( KPercentage *percentage, const char *name ) :
-        KDialog( 0L, name, FALSE, QWidget::WStyle_Customize | QWidget::WStyle_NoBorderEx )
+        KDialog( 0L, name, FALSE, QWidget::WStyle_Customize | QWidget::WStyle_NoBorder )
 {
     percentage_window = percentage;
     resize( 400, 300 );
@@ -49,7 +49,7 @@ KSplashScreen::KSplashScreen( KPercentage *percentage, const char *name ) :
     t->show();
     canvas->setAllChanged();
     canvas->update();
-    QCanvasView *view = new QCanvasView( canvas, this, "", QCanvasView::WStyle_Customize | QCanvasView::WStyle_NoBorderEx );
+    QCanvasView *view = new QCanvasView( canvas, this, "", QCanvasView::WStyle_Customize | QCanvasView::WStyle_NoBorder );
     view->resize( 400, 300 );
     view->setVScrollBarMode( QCanvasView::AlwaysOff );
     view->setHScrollBarMode( QCanvasView::AlwaysOff );
