@@ -19,7 +19,6 @@
 #include "astrocalc.moc"
 #include "dms.h"
 #include "dmsbox.h"
-#include "ksutils.h"
 #include "modcalcjd.h"
 #include "modcalcgeodcoord.h"
 #include "geolocation.h"
@@ -28,27 +27,23 @@
 #include "modcalcprec.h"
 #include "modcalcapcoord.h"
 #include "modcalcdaylength.h"
+#include "modcalcazel.h"
 
-#include <qvbox.h>
-#include <qstring.h>
-#include <qsplitter.h>
 #include <qlistview.h>
 #include <qtextview.h>
-#include <klocale.h>
-#include <kmenubar.h>
 
 //#include <kapplication.h> ...already defined in astrocalc.h
 
 AstroCalc::AstroCalc( QWidget* parent ) :
 	KDialogBase( parent, "starscalculator", true,
-	i18n("KStars Calculator"), Close ) {
+	i18n("Calculator"), Close ) {
 
 	split = new QSplitter ( this );
 	setMainWidget(split);
 
 	navigationPanel = new QListView (split,"NavigationPanel");
 	splashScreen = new QTextView (i18n("<H2>KStars Astrocalculator</H2>"),"",split);
-	
+
 	splashScreen->setMaximumWidth(550);
 	splashScreen->setMinimumWidth(400);
 
@@ -61,27 +56,28 @@ AstroCalc::AstroCalc( QWidget* parent ) :
 	QPixmap geodIcon = QPixmap ("geodetic.png");
 	QPixmap sunsetIcon = QPixmap ("sunset.png");
 	QPixmap timeIcon = QPixmap ("sunclock.png");
-			
-	QListViewItem * timeItem = new QListViewItem(navigationPanel,i18n("Time calculator"));
+
+	QListViewItem * timeItem = new QListViewItem(navigationPanel,i18n("Time Calculators"));
 	timeItem->setPixmap(0,timeIcon);
-	
+
 	QListViewItem * jdItem = new QListViewItem(timeItem,i18n("Julian Day"));
 	jdItem->setPixmap(0,jdIcon);
 
 	QListViewItem * stItem = new QListViewItem(timeItem,i18n("Sidereal Time"));
-	QListViewItem * dayItem = new QListViewItem(timeItem,i18n("Day duration"));
-//	QListViewItem * dayItem = new QListViewItem(timeItem,i18n("Day duration"));
+	QListViewItem * dayItem = new QListViewItem(timeItem,i18n("Day Duration"));
+//	QListViewItem * dayItem = new QListViewItem(timeItem,i18n("Day Duration"));
 //	dayItem->setPixmap(0,sunsetIcon);
-	
-	QListViewItem * coordItem = new QListViewItem(navigationPanel,i18n("Coordinates converter"));
+
+	QListViewItem * coordItem = new QListViewItem(navigationPanel,i18n("Coordinate Converters"));
 	QListViewItem * galItem = new QListViewItem(coordItem,i18n("Equatorial/Galactic"));
 	QListViewItem * precItem = new QListViewItem(coordItem,i18n("Precession"));
-	QListViewItem * appItem = new QListViewItem(coordItem,i18n("Apparent coordinates"));
-	
-	QListViewItem * geoItem = new QListViewItem(navigationPanel,i18n("Earth coordinates"));
+	QListViewItem * appItem = new QListViewItem(coordItem,i18n("Apparent Coordinates"));
+	QListViewItem * azelItem = new QListViewItem(coordItem,i18n("Horizontal Coordinates"));
+
+	QListViewItem * geoItem = new QListViewItem(navigationPanel,i18n("Earth Coordinates"));
 	geoItem->setPixmap(0,geodIcon);
 
-	QListViewItem * cartItem = new QListViewItem(geoItem,i18n("Geodetic coordinates"));
+	QListViewItem * cartItem = new QListViewItem(geoItem,i18n("Geodetic Coordinates"));
 
 	connect(navigationPanel, SIGNAL(clicked(QListViewItem *)), this,
 		SLOT(slotItemSelection(QListViewItem *)));
@@ -94,15 +90,15 @@ AstroCalc::~AstroCalc()
 void AstroCalc::slotItemSelection(QListViewItem *item)
 {
 	QString election;
-	
+
 	if (item==0L) return;
-	
+
 	election = item->text(0);
-	if(!(election.compare(i18n("Time calculator"))))
+	if(!(election.compare(i18n("Time Calculators"))))
 		genTimeText();
 	if(!(election.compare(i18n("Sidereal Time"))))
 		genSidFrame();
-	if(!(election.compare(i18n("Coordinates converter"))))
+	if(!(election.compare(i18n("Coordinate Converters"))))
 		genCoordText();
 	if(!(election.compare(i18n("Julian Day"))))
 		genJdFrame();
@@ -110,17 +106,19 @@ void AstroCalc::slotItemSelection(QListViewItem *item)
 		genGalFrame();
 	if(!(election.compare(i18n("Precession"))))
 		genPrecFrame();
-	if(!(election.compare(i18n("Apparent coordinates"))))
+	if(!(election.compare(i18n("Apparent Coordinates"))))
 		genAppFrame();
-	if(!(election.compare(i18n("Earth coordinates"))))
+	if(!(election.compare(i18n("Horizontal Coordinates"))))
+		genAzelFrame();
+	if(!(election.compare(i18n("Earth Coordinates"))))
 		genGeodText();
-	if(!(election.compare(i18n("Geodetic coordinates"))))
+	if(!(election.compare(i18n("Geodetic Coordinates"))))
 		genGeodCoordFrame();
-	if(!(election.compare(i18n("Day duration"))))
+	if(!(election.compare(i18n("Day Duration"))))
 		genDayFrame();
-		
+
 		previousElection = election;
-			
+
 }
 
 void AstroCalc::genTimeText(void)
@@ -215,6 +213,8 @@ void AstroCalc::delRightPanel(void)
 		delete PrecFrame;
 	else if (rightPanel == Apparent)
 		delete AppFrame;
+	else if (rightPanel == Azel)
+		delete AzelFrame;
 
 }
 
@@ -267,6 +267,13 @@ void AstroCalc::genAppFrame(void)
 	rightPanel = Apparent;
 }
 
+void AstroCalc::genAzelFrame(void)
+{
+	delRightPanel();
+	AzelFrame = new modCalcAzel(split,"Horizontal");
+	rightPanel = Azel;
+}
+
 QSize AstroCalc::sizeHint() const
 {
   return QSize(640,430);
