@@ -15,28 +15,18 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <klocale.h>
 #include <kmessagebox.h>
 
-#include <qframe.h>
-#include <qlayout.h>
-#include <qlabel.h>
 #include <qlineedit.h>
-#include <qlistbox.h>
-#include <qcombobox.h>
-#include <qpushbutton.h>
 
 #include "finddialog.h"
 #include "kstars.h"
 
-#include <qglobal.h>
-#if (QT_VERSION > 299)
 #include <qptrlist.h>
-#endif
 
 FindDialog::FindDialog( QWidget* parent )
 	: KDialogBase( KDialogBase::Plain, i18n( "Find Object" ), Ok|Cancel, Ok, parent ) {
-	
+
 	QFrame *page = plainPage();
 
 //Create Layout managers
@@ -45,25 +35,27 @@ FindDialog::FindDialog( QWidget* parent )
 
 //Create Widgets
 	SearchBox = new QLineEdit( page, "SearchBox" );
-	
+
 	filterTypeLabel = new QLabel( page, "filterTypeLabel" );
 	filterTypeLabel->setAlignment( AlignRight );
 	filterTypeLabel->setText( i18n( "Filter by type: " ) );
-	
+
 	filterType = new QComboBox( page, "filterType" );
 	filterType->setEditable( false );
 	filterType->insertItem( i18n ("Any") );
-	filterType->insertItem( i18n ("Constellations") );
 	filterType->insertItem( i18n ("Stars") );
-	filterType->insertItem( i18n ("Double Stars") );
-	filterType->insertItem( i18n ("Planets") );
+	//	filterType->insertItem( i18n ("Double Stars") );
+	filterType->insertItem( i18n ("Solar System") );
 	filterType->insertItem( i18n ("Open Clusters") );
 	filterType->insertItem( i18n ("Glob. Clusters") );
 	filterType->insertItem( i18n ("Gas. Nebulae") );
 	filterType->insertItem( i18n ("Plan. Nebulae") );
-	filterType->insertItem( i18n ("SN Remnants") );
+	//	filterType->insertItem( i18n ("SN Remnants") );
 	filterType->insertItem( i18n ("Galaxies") );
-	
+	filterType->insertItem( i18n ("Comets") );
+	filterType->insertItem( i18n ("Asteroids") );
+	filterType->insertItem( i18n ("Constellations") );
+
 	SearchList = new QListBox( page, "SearchList" );
 	SearchList->setMinimumWidth( 256 );
 	SearchList->setMinimumHeight( 320 );
@@ -73,12 +65,12 @@ FindDialog::FindDialog( QWidget* parent )
 //Pack Widgets into layout manager
 	hlay->addWidget( filterTypeLabel, 0, 0 );
 	hlay->addWidget( filterType, 0, 0 );
-	
+
 	vlay->addWidget( SearchBox, 0, 0 );
 	vlay->addSpacing( 12 );
 	vlay->addWidget( SearchList, 0, 0 );
 	vlay->addLayout( hlay, 0 );
-	
+
 	vlay->activate();
 
 // no item currently set
@@ -86,13 +78,14 @@ FindDialog::FindDialog( QWidget* parent )
 
 // no filters set
 	Filter = 0;
-	
+
 //Connect signals to slots
 //	connect( this, SIGNAL( okClicked() ), this, SLOT( accept() ) ) ;
 	connect( this, SIGNAL( cancelClicked() ), this, SLOT( reject() ) );
 	connect( SearchBox, SIGNAL( textChanged( const QString & ) ), SLOT( filter() ) );
 	connect( filterType, SIGNAL( activated( int ) ), this, SLOT( setFilter( int ) ) );
 	connect (SearchList, SIGNAL (selectionChanged  (QListBoxItem *)), SLOT (updateSelection (QListBoxItem *)));
+        connect( SearchList, SIGNAL( doubleClicked ( QListBoxItem *  ) ), SLOT( slotOk() ) );
 
 	// first create and paint dialog and then load list
 	QTimer::singleShot(0, this, SLOT( init() ));
@@ -110,26 +103,24 @@ void FindDialog::init() {
 
 void FindDialog::filter() {  //Filter the list of names with the string in the SearchBox
 	KStars *p = (KStars *)parent();
-	
+
 	int i=0;
 	SearchList->clear();
-	SearchList->sort (false);		// the Items will faster inserted
 
 	ObjectNameList &ObjNames = p->data()->ObjNames;
 	// check if latin names are used
 	ObjNames.setLanguage( p->options()->useLatinConstellNames );
-	
+
 	QString searchFor = SearchBox->text().lower();
 		for ( SkyObjectName *name = ObjNames.first( searchFor ); name; name = ObjNames.next() ) {
 			if ( name->text().lower().startsWith( searchFor ) ) {
 				new SkyObjectNameListItem ( SearchList, name );
-				if ( i++ >= 5000 ) {              //Every 5000 name insertions,
+/*				if ( i++ >= 5000 ) {              //Every 5000 name insertions,
 					kapp->processEvents ( 50 );		//spend 50 msec processing KApplication events
 					i = 0;
-				}
+				}*/
 			}
 		}
-	SearchList->sort (true);  // sort QListBox
 	setListItemEnabled(); // Automatically highlight first item
 	SearchBox->setFocus();  // set cursor to QLineEdit
 }
@@ -137,28 +128,30 @@ void FindDialog::filter() {  //Filter the list of names with the string in the S
 void FindDialog::filterByType() {
 	KStars *p = (KStars *)parent();
 
-	int i = 0;	
+	int i = 0;
 	SearchList->clear();	// QListBox
-	SearchList->sort (false);		// the Items will faster inserted
 	QString searchFor = SearchBox->text().lower();  // search string
-	
+
 	ObjectNameList &ObjNames = p->data()->ObjNames;
 	// check if latin names are used
 	ObjNames.setLanguage( p->options()->useLatinConstellNames );
 
 	for ( SkyObjectName *name = ObjNames.first( searchFor ); name; name = ObjNames.next() ) {
-		if ( name->skyObject()->type() + 2 == Filter ) {
+	        //Special case: match SkyObject Type 0 with Filter==1 (stars)
+		if ( name->skyObject()->type() == Filter || (name->skyObject()->type() == 0 && Filter == 1 ) ) {
 			if ( name->text().lower().startsWith( searchFor ) ) {
-				new SkyObjectNameListItem ( SearchList, name );
+				// for stars, don't show the ones below the faint limit
+				if (Filter!=1 || name->skyObject()->mag() <= p->options()->currentMagLimitDrawStar()) {
+					new SkyObjectNameListItem ( SearchList, name );
+				}
 			}
 		}
-		if (i++ >= 5000) {            //Every 5000 name insertions,
+/*		if (i++ >= 5000) {            //Every 5000 name insertions,
 			kapp->processEvents (50);   //spend 50 msec processing KApplication events
 			i = 0;
-		}
+		}*/
 	}
 
-	SearchList->sort (true);  // sort QListBox
 	setListItemEnabled();    // Automatically highlight first item
 	SearchBox->setFocus();  // set cursor to QLineEdit
 }
@@ -175,9 +168,13 @@ void FindDialog::updateSelection (QListBoxItem *it) {
 }
 
 void FindDialog::setFilter( int f ) {
-	// check if filter was changed or if filter is still the same
-	if ( Filter != f ) {
-		Filter = f;
+        // Translate the Listbox index to the correct SkyObject Type ID 
+        int f2( f ); // in most cases, they are the same number
+	if ( f >= 7 ) f2 = f + 1; //need to skip unused "Supernova Remnant" Type at position 7
+	
+        // check if filter was changed or if filter is still the same
+	if ( Filter != f2 ) {
+		Filter = f2;
 		if ( Filter == 0 ) {  // any type will shown
 		// delete old connections and create new connections
 			disconnect( SearchBox, SIGNAL( textChanged( const QString & ) ), this, SLOT( filterByType() ) );
