@@ -97,8 +97,8 @@ GeoLocation::GeoLocation( double x, double y, double z, QString name, QString pr
 void GeoLocation::reset( GeoLocation *g ) {
 	indexEllipsoid = g->ellipsoid();
 	setEllipsoid ( indexEllipsoid );
-	Longitude = g->lng();
-	Latitude  = g->lat();
+	setLong( g->lng()->Degrees() );
+	setLat( g->lat()->Degrees() );
 	Name      = g->name();
 	Province  = g->province();
 	Country   = g->country();
@@ -157,9 +157,10 @@ void GeoLocation::geodToCart (void) {
 	double sinLong, cosLong, sinLat, cosLat;
 
 	e2 = 2*flattening-flattening*flattening;
+	
 	Longitude.SinCos(sinLong,cosLong);
 	Latitude.SinCos(sinLat,cosLat);
-
+	
 	xn = axis/( sqrt(1-e2*sinLat*sinLat) );
 	PosCartX = (xn+Height)*cosLat*cosLong;
 	PosCartY = (xn+Height)*cosLat*sinLong;
