@@ -18,7 +18,7 @@
 #ifndef KSMOON_H
 #define KSMOON_H
 
-#include <ksplanetbase.h>
+#include "ksplanetbase.h"
 #include "dms.h"
 
 /**
@@ -31,47 +31,17 @@
 	*@version 0.9
   */
 
-class KStars;
+class KStarsData;
 class KSMoon : public KSPlanetBase  {
-public: 
+public:
 	/**
 		*Default constructor.  Set name="Moon".
 		*/
-	KSMoon(KStars *ks);
+	KSMoon(KStarsData *kd);
 
 	/**Destructor (empty). */
 	~KSMoon();
 
-	/**
-    *Reimplemented from KSPlanet, this function employs unique algorithms for
-    *estimating the lunar coordinates.  Finding the position of the moon is
-    *much more difficult than the other planets.  For one thing, the Moon is
-    *a lot closer, so we can detect smaller deviations in its orbit.  Also,
-    *the Earth has a significant effect on the Moon's orbit, and their
-    *interaction is complex and nonlinear.  As a result, the positions as
-    *calculated by findPosition() are only accurate to about 10 arcseconds
-		*(10 times less precise than the planets' positions!)
-		*@short moon-specific coordinate finder
-		*@param jd current Julian Date
-		*/
-	virtual bool findPosition( const KSNumbers *num, const KSPlanetBase *Earth = 0);
-
-	/**
-	  *@short Calls findPosition( Epoch ), then localizeCoords( lat, LST ).
-		*@param jd current Julian Date
-		*@param lat The geographic latitude
-		*@param LST The local sidereal time
-		*/
-	void findPosition( KSNumbers *num, dms lat, dms LST );
-
-	/**
-		*Convert geocentric coordinates to local (topographic) coordinates,
-		*by correcting for the effect of parallax (a.k.a "figure of the Earth").
-		*@param lat The geographic latitude
-		*@param LST The local sidereal time
-		*/
-	void localizeCoords( dms lat, dms LST );
-
 	/**
 		*Determine the phase angle of the moon, and assign the appropriate
 		*moon image
@@ -79,25 +49,34 @@ public:
 		*/
 	void findPhase( const KSSun *Sun );
 
-	/**
-		*@returns the moon's current distance from the Earth
-		*/
-	double distance( void ) { return Rearth; }
-
-	/**
-		*@returns the moon's current phase angle, as a dms angle
+	/**@return the moon's current phase angle, as a dms angle
 		*/
 	dms phase( void ) { return Phase; }
 
-	/**
-	 * reimplemented from KSPlanetBase
-	 */
+	/**@return the illuminated fraction of the Moon as seen from Earth
+		*/
+	double illum( void ) { return 0.5*(1.0 - cos( phase().radians() ) ); }
+	
+	/** reimplemented from KSPlanetBase
+		*/
 	virtual bool loadData();
 
 protected:
+	/**Reimplemented from KSPlanetBase, this function employs unique algorithms for
+		*estimating the lunar coordinates.  Finding the position of the moon is
+		*much more difficult than the other planets.  For one thing, the Moon is
+		*a lot closer, so we can detect smaller deviations in its orbit.  Also,
+		*the Earth has a significant effect on the Moon's orbit, and their
+		*interaction is complex and nonlinear.  As a result, the positions as
+		*calculated by findPosition() are only accurate to about 10 arcseconds
+		*(10 times less precise than the planets' positions!)
+		*@short moon-specific coordinate finder
+		*@param num KSNumbers pointer for the target date/time
+		*@param Earth pointer to the Earth (not used for the Moon)
+		*/
+	virtual bool findGeocentricPosition( const KSNumbers *num, const KSPlanetBase *Earth = 0 );
 
 private:
-	double Rearth; //Distance from Earth, in km.
 	dms Phase;
 	static bool data_loaded;
 
@@ -115,12 +94,12 @@ private:
 			int nf;
 			double Li;
 			double Ri;
-			
+
 			MoonLRData( int pnd, int pnm, int pnm1, int pnf, double pLi, double pRi ):
 				nd(pnd), nm(pnm), nm1(pnm1), nf(pnf), Li(pLi), Ri(pRi) {};
 	};
 
-	static QList<MoonLRData> LRData;
+	static QPtrList<MoonLRData> LRData;
 
 /**Class to encapsulate the Latitude terms of the sums
 	*used to compute the moon's position.
@@ -135,12 +114,12 @@ private:
 			int nm1;
 			int nf;
 			double Bi;
-			
+
 			MoonBData( int pnd, int pnm, int pnm1, int pnf, double pBi ):
 				nd(pnd), nm(pnm), nm1(pnm1), nf(pnf), Bi(pBi) {};
 	};
 
-	static QList<MoonBData> BData;
+	static QPtrList<MoonBData> BData;
 };
 
 #endif
