@@ -15,13 +15,11 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qfile.h>
-#include <qtextstream.h>
 #include <math.h>
 #include <kdebug.h>
 #include "ksutils.h"
 #include "ksplanet.h"
-
+#include "ksfilereader.h"
 
 KSPlanet::OrbitDataManager KSPlanet::odm;
 
@@ -40,24 +38,34 @@ KSPlanet::OrbitDataManager::OrbitDataManager() : dict(31, true) {
 	dict.setAutoDelete(true);
 }
 
-bool KSPlanet::OrbitDataManager::readOrbitData(QString fname, 
-		QVector<KSPlanet::OrbitData> *vector) {
+bool KSPlanet::OrbitDataManager::readOrbitData(QString fname,
+		QPtrVector<KSPlanet::OrbitData> *vector) {
 	QString line;
 	QFile f;
 	double A, B, C;
 
-	QList<OrbitData> DData;
+	QPtrList<OrbitData> DData;
 
 	if ( KSUtils::openDataFile( f, fname ) ) {
+		KSFileReader fileReader( f ); // close file is included
+    while ( fileReader.hasMoreLines() ) {
+      line = fileReader.readLine();
+			QTextIStream instream( &line );
+			instream >> A >> B >> C;
+			DData.append(new OrbitData(A, B, C));
+
+		}
+/* old code
 		QTextStream stream( &f );
 		while ( !stream.eof() ) {
 			line = stream.readLine();
 			QTextIStream instream( &line );
 			instream >> A >> B >> C;
 			DData.append(new OrbitData(A, B, C));
-				
+
 		}
 		f.close();
+*/
 	} else {
 		return false;
 	}
@@ -95,9 +103,9 @@ KSPlanet::OrbitDataColl *KSPlanet::OrbitDataManager::loadData(QString n) {
 
 	if ( nCount==0 ){ //No longitude data found!
 		delete ret;
-		return 0; 
+		return 0;
 	}
-	
+
 	//Ecliptic Latitude
 	for (int i=0; i<6; ++i) {
 		snum.setNum( i );
@@ -128,7 +136,7 @@ KSPlanet::OrbitDataColl *KSPlanet::OrbitDataManager::loadData(QString n) {
 
 	dict.insert(n, ret);
 
-	
+
 //	kdDebug() << k_funcinfo << " successful load" << endl;
 
 	return ret;
@@ -138,15 +146,14 @@ KSPlanet::OrbitDataColl *KSPlanet::OrbitDataManager::loadData(QString n) {
 //========================================================================
 //
 
-KSPlanet::KSPlanet( KStars *ks, QString s, QString imfile )
- : KSPlanetBase(ks, s, imfile), data_loaded(false) {
+KSPlanet::KSPlanet( KStarsData *kd, QString s, QString imfile )
+ : KSPlanetBase(kd, s, imfile), data_loaded(false) {
 }
 
 bool KSPlanet::loadData() {
 	return (odm.loadData(name()) != 0);
 }
 
-
 void KSPlanet::calcEcliptic(double Tau, EclipticPosition &epret) const {
 	double sum[6];
 	OrbitDataColl * odc;
@@ -171,7 +178,7 @@ void KSPlanet::calcEcliptic(double Tau, EclipticPosition &epret) const {
 		for (uint j = 0; j < odc->Lon[i].size(); ++j) {
 			sum[i] += odc->Lon[i][j]->A * cos( odc->Lon[i][j]->B + odc->Lon[i][j]->C*Tau );
 			/*
-			kdDebug() << "sum[" << i <<"] =" << sum[i] << 
+			kdDebug() << "sum[" << i <<"] =" << sum[i] <<
 				" A = " << odc->Lon[i][j]->A << " B = " << odc->Lon[i][j]->B <<
 				" C = " << odc->Lon[i][j]->C << endl;
 				*/
@@ -182,7 +189,7 @@ void KSPlanet::calcEcliptic(double Tau, EclipticPosition &epret) const {
 
 	epret.longitude.setRadians( sum[0] + sum[1] + sum[2] + sum[3] + sum[4] + sum[5] );
 	epret.longitude.setD( epret.longitude.reduce().Degrees() );
-	  	
+
 	//Compute Ecliptic Latitude
 	for (uint i=0; i<6; ++i) {
 		sum[i] = 0.0;
@@ -194,7 +201,7 @@ void KSPlanet::calcEcliptic(double Tau, EclipticPosition &epret) const {
 
 
 	epret.latitude.setRadians( sum[0] + sum[1] + sum[2] + sum[3] + sum[4] + sum[5] );
-  	
+
 	//Compute Heliocentric Distance
 	for (uint i=0; i<6; ++i) {
 		sum[i] = 0.0;
@@ -207,13 +214,13 @@ void KSPlanet::calcEcliptic(double Tau, EclipticPosition &epret) const {
 	epret.radius = sum[0] + sum[1] + sum[2] + sum[3] + sum[4] + sum[5];
 
 	/*
-	kdDebug() << name() << " pre: Lat = " << epret->latitude.toDMSString() << " Long = " << 
-		epret->longitude.toDMSString() << " Dist = " << epret->radius << endl;
-		*/
+	kdDebug() << name() << " pre: Lat = " << epret.latitude.toDMSString() << " Long = " <<
+		epret.longitude.toDMSString() << " Dist = " << epret.radius << endl;
+	*/
 
 }
 
-bool KSPlanet::findPosition( const KSNumbers *num, const KSPlanetBase *Earth ) {
+bool KSPlanet::findGeocentricPosition( const KSNumbers *num, const KSPlanetBase *Earth ) {
 
 	if ( Earth != NULL ) {
 		double sinL, sinL0, sinB, sinB0;
@@ -226,31 +233,40 @@ bool KSPlanet::findPosition( const KSNumbers *num, const KSPlanetBase *Earth ) {
 		EclipticPosition trialpos;
 
 		double jm = num->julianMillenia();
-		Earth->ecLong().SinCos( sinL0, cosL0 );
-		Earth->ecLat().SinCos( sinB0, cosB0 );
+
+		Earth->ecLong()->SinCos( sinL0, cosL0 );
+		Earth->ecLat()->SinCos( sinB0, cosB0 );
+
 		double eX = Earth->rsun()*cosB0*cosL0;
 		double eY = Earth->rsun()*cosB0*sinL0;
 		double eZ = Earth->rsun()*sinB0;
 
+		bool once = true;
+		
 		while (fabs(dst - olddst) > .001) {
 			calcEcliptic(jm, trialpos);
+		
+			// We store the heliocentric ecliptic coordinates the first time 
+			// they are computed.
+			if(once){
+				   helEcPos = trialpos;
+				   once=false;
+			}
+			
 			olddst = dst;
+
 			trialpos.longitude.SinCos( sinL, cosL );
 			trialpos.latitude.SinCos( sinB, cosB );
+
 			x = trialpos.radius*cosB*cosL - eX;
 			y = trialpos.radius*cosB*sinL - eY;
 			z = trialpos.radius*sinB - eZ;
 
+			//distance from Earth
 			dst = sqrt(x*x + y*y + z*z);
 
 			double delay = (.0057755183 * dst) / 365250.0;
 
-			/*
-			kdDebug() << name() << " : Lat = " << trialpos->latitude.toDMSString() << " Long = " << 
-				trialpos->longitude.toDMSString() << " rsun = " << trialpos->radius << 
-				" dst = " << dst << " olddst = " << olddst << " delay = " << delay << endl;
-				*/
-
 			jm = num->julianMillenia() - delay;
 
 		}
@@ -258,6 +274,8 @@ bool KSPlanet::findPosition( const KSNumbers *num, const KSPlanetBase *Earth ) {
 		ep.longitude.setRadians( atan( y/x ) );
 		if (x<0) ep.longitude.setD( ep.longitude.Degrees() + 180.0 ); //resolve atan ambiguity
 		ep.latitude.setRadians( atan( z/( sqrt( x*x + y*y ) ) ) );
+		setRsun( trialpos.radius );
+		setRearth( dst );
 
 		EclipticToEquatorial( num->obliquity() );
 
@@ -267,7 +285,11 @@ bool KSPlanet::findPosition( const KSNumbers *num, const KSPlanetBase *Earth ) {
 	} else {
 
 		calcEcliptic(num->julianMillenia(), ep);
+		helEcPos = ep;
 	}
 
+	//determine the position angle
+	findPA( num );
+
 	return true;
 }
