@@ -18,7 +18,7 @@
 #ifndef KSPLUTO_H
 #define KSPLUTO_H
 
-#include <ksplanetbase.h>
+#include "ksplanetbase.h"
 
 /**
 	*A subclass of KSPlanetBase that provides a custom findPosition() function
@@ -30,32 +30,31 @@
 	*@version 0.9
 	*/
 
-class KStars;
+class KStarsData;
 class KSPluto : public KSPlanetBase  {
 public:
 /**
 	*Default constructor.  Calls KSPlanetBase constructor with name="Pluto" and
 	*a null image.
 	*/
-	KSPluto(KStars *ks, QString fn="");
+	KSPluto(KStarsData *kd, QString fn="");
 
 /**Destructor */
 	virtual ~KSPluto();
 
-/**
-	*A custom findPosition() function needed for the unique orbit of Pluto.
-	*Pluto coordinates are first solved in heliocentric rectangular (X, Y, Z)
-	*coordinates, which are then converted to heliocentric spherical
-	*(R, EcLong, EcLat) coordinates, and finally translated to geocentric
-	*(RA, Dec) coordinates.
-	*/
-	virtual bool findPosition( const KSNumbers *num, const KSPlanetBase *Earth=NULL );
-
 	virtual bool loadData();
 
 protected:
 	virtual bool loadData(QString n);
 
+/**A custom findPosition() function needed for the unique orbit of Pluto.
+	*Pluto's coordinates are first solved in heliocentric rectangular (X, Y, Z)
+	*coordinates, which are then converted to heliocentric spherical
+	*(R, EcLong, EcLat) coordinates, and finally translated to geocentric
+	*(RA, Dec) coordinates.
+	*/
+	virtual bool findGeocentricPosition( const KSNumbers *num, const KSPlanetBase *Earth=NULL );
+
 private:
 	class XYZData {
 		public:
