@@ -21,6 +21,7 @@
 #include <config.h>
 #endif
 
+#include <dcopclient.h>
 #include <kmainwindow.h>
 #include <kmenubar.h>
 #include <kaction.h>
@@ -37,15 +38,9 @@
 #include <qwidget.h>
 #include <qpoint.h>
 
-#if (QT_VERSION < 300)
-#include <kapp.h>
-#include <kstddirs.h>
-#include <qlist.h>
-#else
 #include <kapplication.h>
 #include <kstandarddirs.h>
 #include <qptrlist.h>
-#endif
 
 #include "skymap.h"
 #include "geolocation.h"
@@ -62,130 +57,100 @@
 #include "toggleaction.h"
 
 // forward declaration is enough. We only need pointers
+class KDialogBase;
+class KKey;
 class TimeDialog;
 class LocationDialog;
 class FindDialog;
 class ViewOpsDialog;
-class SimClock;
-class InfoPanel;
 class InfoBoxes;
 class AstroCalc;
-
-//Define some global constants
-#define NCIRCLE 360   //number of points used to define equator, ecliptic and horizon
-#define NMILKYWAY 11  //number of Milky Way segments
-#define MINZOOMLEVEL 0
-#define MAXZOOMLEVEL 26
-#define TIMER_INTERVAL 10
+class INDIMenu;
+class INDIDriver;
 
 /**
 	*kstars is the base class for the KStars project.  It is derived from KMainWindow.
 	*In addition to the GUI elements, the class contains the program clock,
-	*KStarsData, KStarsOptions, SkyMap, and InfoPanel child objects.
+	*KStarsData, KStarsOptions, and SkyMap objects.
 	*It also contains functions for the DCOP interface.
 	*@short KStars base class
 	*@author Jason Harris
-	*@version 0.9
+	*@version 1.0
 	*/
 
 class KStars : public KMainWindow, virtual public KStarsInterface
 {
 
-  Q_OBJECT 
+  Q_OBJECT
   public:
-    /**
-	 *Constructor.
-	 *@param kstarsData the KStars Data object
-	 */
-    KStars( KStarsData* kstarsData );
+	/**Constructor.
+		*@param kstarsData the KStars Data object
+		*/
+		KStars( KStarsData* kstarsData );
 
-	/**
-	 * Constructor.
-	 * @param doSplash should the splash panel be displayed during
-	 * intialization.
-	 */
-	KStars( bool doSplash );
+	/**Constructor.
+		*@param doSplash should the splash panel be displayed during
+		*initialization.
+		*/
+		KStars( bool doSplash );
 
-    /**
-			*Destructor.  Synchs config file.  Deletes objects.
-			*/
-    ~KStars();
+	/**Destructor.  Synchs config file.  Deletes objects.
+		*/
+		~KStars();
 
-		/**
-			*@returns pointer to KStarsData object which contains application data.
-			*/
+	/**@returns pointer to KStarsData object which contains application data.
+		*/
 		KStarsData* data();
 
-		/**
-			*@returns pointer to KStarsOptions object which contains application options.
-			*/
+	/**@returns pointer to the local sidereal time.
+		*/
+		dms* LST() { return data()->LST; }
+
+	/**@returns pointer to KStarsOptions object which contains application options.
+		*/
 		KStarsOptions* options() { return data()->options; }
 
-		/**
-			*@returns pointer to SkyMap object which is the sky display widget.
-			*/
+	/**@returns pointer to SkyMap object which is the sky display widget.
+		*/
 		SkyMap* map() { return skymap; }
 
-		/**
-			*@returns pointer to GeoLocation object which is the current geographic location.
-			*/
+	/**@returns pointer to GeoLocation object which is the current geographic location.
+		*/
 		GeoLocation* geo() { return options()->Location(); }
 
-		/**
-			*@returns pointer to InfoBoxes object.
-			*/
-		InfoBoxes* infoBoxes() { return IBoxes; }
+	/**@returns pointer to InfoBoxes object.
+		*/
+		InfoBoxes* infoBoxes() { return map()->infoBoxes(); }
 
-		/**Display object name and coordinates in the FocusBox
-			*/
-		void showFocusCoords();
+	/**@returns pointer to the INDI driver
+		*/
+		INDIDriver* getINDIDriver(void) { return indidriver; }
 
-		/**
-			*Load KStars options from the kstarsrc file.
-			*/
-		void loadOptions();
+	/**@returns pointer to the INDI menu
+		*/
+		INDIMenu* getINDIMenu(void) { return indimenu; }
 
-		/**
-			*Save KStars options to the kstarsrc file.
-			*/
-		void saveOptions();
+	/** Establish the INDI system. No GUI
+		*/
+		void establishINDI();
 
-		/**
-			*Add an item to the color-scheme action menu
-			*@param name The name to use in the menu
-			*@param actionName The internal name for the action (derived from filename)
-			*/
+	/**Add an item to the color-scheme action manu
+		*@param name The name to use in the menu
+		*@param actionName The internal name for the action (derived from filename)
+		*/
 		void addColorMenuItem( QString name, QString actionName );
 
 		void removeColorMenuItem( QString actionName );
 
-	/**Find object by name.
-		*@param name Object name to find
-		*@returns pointer to SkyObject matching this name
-		*/
-		SkyObject* getObjectNamed( QString name );	
+	/**DCOP interface function.  Set focus to given Ra/Dec coordinates */
+		ASYNC setRaDec( double ra, double dec );
 
-	/**@returns pointer to the simulation clock.
-		*/
-		SimClock* getClock( void ) { return clock; }
-
-	/**@returns the local sidereal time.
-		*/
-		dms LSTh();
-
-	/**@returns the timestep scale of the simulation clock.
-		*/
-		double clockScale( void ) const { return clock->scale(); }
-
-/**Set the KStarsData::HourAngle according to the current LST and focus->ra
-	*/
-		void setHourAngle();
+	/**DCOP interface function.  Set focus to given Alt/Az coordinates. */
+		ASYNC setAltAz(double alt, double az);
 
 	/**DCOP interface function.
-		*Point in the direction described by the string argument.  
-		*@param direction the object or direction to foxus on
-		*/
-		ASYNC lookTowards(QString direction);
+		*Point in the direction described by the string argument.  */
+		ASYNC lookTowards( const QString direction );
 
 	/**DCOP interface function.  Zoom in. */
 		ASYNC zoomIn(void) { slotZoomIn(); };
@@ -193,22 +158,36 @@ class KStars : public KMainWindow, virtual public KStarsInterface
 	/**DCOP interface function.  Zoom out. */
 		ASYNC zoomOut(void){ slotZoomOut(); };
 
-	/**DCOP interface function.  Set focus to given Alt/Az coordinates. 
-		*@param alt new focus Altiude 
-		*@param az  new focus Azimuth 
-		*/
-		ASYNC setAltAz(double alt, double az);
+	/**DCOP interface function.  Default Zoom. */
+		ASYNC defaultZoom(void) { slotDefaultZoom(); }
 
-	/**DCOP interface function.  Set local time and date. 
-		*@param yr Year portion of new date
-		*@param mth Month portion of new date
-		*@param day Day portion of new date
-		*@param hr Hour portion of new time
-		*@param min Minute portion of new time
-		*@param sec Second portion of new time
-		*/
+	/**DCOP interface function.  Set ZoomLevel manually. */
+		ASYNC zoom(double);
+
+	/**DCOP interface function.  Set local time and date. */
 		ASYNC setLocalTime(int yr, int mth, int day, int hr, int min, int sec);
 
+	/**DCOP interface function.  Pause for t seconds. */
+		ASYNC waitFor( double t );
+
+	/**DCOP interface function.  Pause until Key k is pressed. */
+		ASYNC waitForKey( const QString k );
+
+	/**DCOP interface function.  Toggle tracking. */
+		ASYNC setTracking( bool track );
+
+	/**DCOP interface function.  modify option. */
+		ASYNC changeViewOption( const QString option, const QString value );
+
+	/**DCOP interface function.  Show text message in a popup window. */
+		ASYNC popupMessage( int x, int y, const QString message );
+
+	/**DCOP interface function.  Draw a line on the sky. */
+		ASYNC drawLine( int x1, int y1, int x2, int y2, int speed=0 );
+
+	/**DCOP interface function.  Set the geographic location. */
+		ASYNC setGeoLocation( const QString city, const QString province, const QString country );
+
 	public slots:
 		/**
 			*Update time-dependent data and (possibly) repaint the sky map.
@@ -224,13 +203,27 @@ class KStars : public KMainWindow, virtual public KStarsInterface
 			*Zoom out
 			*/
 		void slotZoomOut();
-	
+
+		void slotDefaultZoom();
+		void slotSetZoom();
+
 	/**
- 		*Delete FindDialog because ObjNames list has changed in KStarsData due to
-   	*reloading star data. So list in FindDialog must be new filled with current data.
-   	*/
+		*action slot: Toggle whether kstars is tracking current position
+		*/
+		void slotTrack();
+
+	/**
+		*action slot: open dialog for selecting a new geographic location
+		*/
+		void slotGeoLocator();
+
+		/* Delete FindDialog because ObjNames list has changed in KStarsData due to
+		*reloading star data. So list in FindDialog must be new filled with current data.
+		*/
 		void clearCachedFindDialog();
 
+		void resumeDCOP( void ) { kapp->dcopClient()->resume(); }
+
 	private slots:
 		/**
 			*action slot: synch kstars clock to system time
@@ -249,19 +242,9 @@ class KStars : public KMainWindow, virtual public KStarsInterface
 
 		/**
 			*action slot: open dialog for finding a named object
-			*/	
+			*/
 		void slotFind();
 
-		/**
-			*action slot: Toggle whether kstars is tracking current position
-			*/	
-		void slotTrack();
-
-		/**
-			*action slot: open dialog for selecting a new geographic location
-			*/	
-		void slotGeoLocator();
-
 		/**
 		 * action slot: open KStars calculator to compute astronomical
 		 * ephemeris
@@ -269,13 +252,64 @@ class KStars : public KMainWindow, virtual public KStarsInterface
 
 		void slotCalculator();
 
+		/**
+		 * action slot: open KStars AAVSO Light Curve Generator
+		 */
+
+		void slotLCGenerator();
+
+		/**
+		* action slot: open Elevation vs. Time tool
+		*/
+
+		void slotAVT();
+
+		/**
+		 * action slot: open What's up tonight dialog
+		 */
+		 void slotWUT();
+
+		/**
+		 * action slot: open ScriptBuilder dialog
+		 */
+		void slotScriptBuilder();
+
+		/**
+		 * action slot: open Solar system viewer
+		 */
+		void slotSolarSystem();
+
+		/**
+		 * action slot: open Jupiter Moons tool
+		 */
+		void slotJMoonTool();
+
+		/**
+		 * action slot: open Telescope wizard
+		 */
+		void slotTelescopeWizard();
+
+		 /**
+		 * action slot: open INDI driver panel
+		 */
+		void slotINDIDriver();
+
+		 /**
+		 * action slot: open INDI control panel
+		 */
+		void slotINDIPanel();
+
+		/**
+		 * action slot: open INDI configuration dialog
+		 */
+		void slotINDIConf();
+
 		/**
 			*action slot: open dialog for setting the view options
-			*/	
+			*/
 		void slotViewOps();
 
 		/** finish setting up after the kstarsData has finished
-		 *@param worked Did the data initialization finish successfully?
 		 */
 		void datainitFinished(bool worked);
 
@@ -285,6 +319,12 @@ class KStars : public KMainWindow, virtual public KStarsInterface
 		/**Close KStars window. */
 		void closeWindow();
 
+		/**Action slot to save the sky image to a file.*/
+		void slotExportImage();
+
+		/**Action slot to select a DCOP script and run it.*/
+		void slotRunScript();
+
 		/**Action slot to print skymap. */
 		void slotPrint();
 
@@ -303,6 +343,11 @@ class KStars : public KMainWindow, virtual public KStarsInterface
 			*Action which sent the activating signal.  */
 		void slotColorScheme();
 
+		/**Select the Target symbol (a.k.a. field-of-view indicator) */
+		void slotTargetSymbol();
+
+		void slotFOVEdit();
+
 		/**Toggle between Equatorial and Ecliptic coordinte systems */
 		void slotCoordSys();
 
@@ -310,32 +355,13 @@ class KStars : public KMainWindow, virtual public KStarsInterface
 			*uses the name of the sender to identify the item to change.  */
 		void slotViewToolBar();
 
-		/**Meta-slot to handle toggling display of GUI elements (toolbars and infopanel)
+		/**Meta-slot to handle toggling display of GUI elements (toolbars and infoboxes)
 			*uses name of the sender action to identify the widget to hide/show.  */
 		void slotShowGUIItem( bool );
 
 		/**Re-assign the input focus to the SkyMap widget.
 			*/
-		void mapGetsFocus();
-
-		/**Record shaded state of TimeBox in config object.
-			*/
-		void saveTimeBoxShaded( bool s );
-		/**Record shaded state of GeoBox in config object.
-			*/
-		void saveGeoBoxShaded( bool s );
-		/**Record shaded state of FocusBox in config object.
-			*/
-		void saveFocusBoxShaded( bool s );
-		/**Record position of TimeBox in config object.
-			*/
-		void saveTimeBoxPos( QPoint p );
-		/**Record position of GeoBox in config object.
-			*/
-		void saveGeoBoxPos( QPoint p );
-		/**Record position of FocusBox in config object.
-			*/
-		void saveFocusBoxPos( QPoint p );
+		void mapGetsFocus() { map()->QWidget::setFocus(); }
 
 	private:
 		/**
@@ -343,59 +369,37 @@ class KStars : public KMainWindow, virtual public KStarsInterface
 			*/
 		void initActions();
 
+		void initFOV();
+
 		/**
 			*Initialize Status bar.
 			*/
 		void initStatusBar();
 
-		/**
-			*Initialize celestial equator, horizon and ecliptic.
-			*/
-		void initGuides(KSNumbers *num);
-
-		/**format a date string
-			*@param d QDate to format as a string
-			*@returns formatted date string for the given date
-			*/
-		QString getDateString( QDate d );
-
-		/**change the current simulation time to the time and date specified as the arguments.
-			*Specified date and time is always local time.
-			*@param newDate the date to set.
-			*@param newTIme the time to set.
-			*/
-		void changeTime(QDate newDate, QTime newTime );
-
-		/**Set the KStarsData::LSTh member from the current UTC.
-		*/
-		void setLSTh( QDateTime UTC );
-
 		SkyMap *skymap;
-		SimClock *clock;
 
 		FindDialog *findDialog;
-		InfoPanel   *infoPanel;
-		InfoBoxes   *IBoxes;
 		KToolBar *viewToolBar;
 		TimeStepBox *TimeStep;
 
 		ToggleAction *actCoordSys;
-		KActionMenu *colorActionMenu;
+		KActionMenu *colorActionMenu, *fovActionMenu;
 		QWidget *centralWidget;
 		QVBoxLayout *topLayout;
 
+       		KDialogBase *AAVSODialog;
+		INDIMenu *indimenu;
+		INDIDriver *indidriver;
+
+
 		int idSpinBox;
-		bool useDefaultOptions, DialogIsObsolete;
+		bool DialogIsObsolete;
 
 		class privatedata;
 		friend class privatedata;
 		privatedata *pd;
 };
 
-/**privatedata is a class exposed only to the KStars class.
-	*It contains a pointer to the KStarsData object, and to the KStarsSplash object.
-	*It also contains the buildGUI() function.
-	*/
 class KStars::privatedata {
 
 	public:
@@ -403,14 +407,9 @@ class KStars::privatedata {
 		KStarsSplash *splash;
 		KStarsData *kstarsData;
 
-		/**Constructor.*/
 		privatedata(KStars *parent) : ks(parent), splash(0), kstarsData(0) {};
-		
-		/**Construct the KStars GUI.  
-			*/
 		void buildGUI();
 
-		/**Destructor*/
 		virtual ~privatedata() {
 			if (splash) delete splash;
 			if (kstarsData) delete kstarsData;
