@@ -20,41 +20,63 @@
 
 #include <qfile.h>
 #include <qmap.h>
+#include <qptrlist.h>
 #include <qstring.h>
 #include <qstringlist.h>
 #include <qdatetime.h>
 #include <qtimer.h>
 
 #include <klocale.h>
+#include <kshortcut.h>
 
+#include <iostream>
+
+#include "dms.h"
+#include "fov.h"
 #include "geolocation.h"
+#include "skypoint.h"
 #include "skyobject.h"
 #include "starobject.h"
-#include "kstarsoptions.h"
+#include "deepskyobject.h"
+#include "skyobjectname.h"
 #include "ksplanet.h"
+#include "ksasteroid.h"
+#include "kscomet.h"
 #include "kspluto.h"
 #include "kssun.h"
 #include "ksmoon.h"
-#include "skypoint.h"
-#include "skyobjectname.h"
-#include "dms.h"
+#include "planetcatalog.h"
+
+#include "kstarsoptions.h"
 #include "simclock.h"
 #include "skymap.h"
-#include "planetcatalog.h"
 #include "objectnamelist.h"
 #include "timezonerule.h"
+#include "lcgenerator.h"
+#include "detaildialog.h"
+#include "jupitermoons.h"
+#include "indidriver.h"
+#include "indistd.h"
+#include "telescopewizardprocess.h"
 
-#include <qglobal.h>
-#if (QT_VERSION <= 299)
-#include <qlist.h>
-#else 
-#include <qptrlist.h>
-#endif
+#define NHIPFILES 127
+#define NMWFILES  11
+#define NNGCFILES 14
+#define NTYPENAME 12
+#define NCIRCLE 360   //number of points used to define equator, ecliptic and horizon
+
+#define MINZOOM 200.
+#define MAXZOOM 1000000.
+#define DEFAULTZOOM 2000.
+#define DZOOM 1.10
+#define AU_KM 1.49605e8  //km in one AU
 
 class KStandardDirs;
 class FileSource;
 class StarDataSink;
 class QDataPump;
+class elts;
+class KSFileReader;
 
 /**KStarsData manages all the data objects used by KStars: Lists of stars, deep-sky objects,
 	*planets, geographic locations, and constellations.  Also, the milky way, and URLs for
@@ -73,13 +95,26 @@ public:
 	friend class FindDialog;
 	friend class KStars;
 	friend class LocationDialog;
+	friend class FOVDialog;
 	friend class MapCanvas;
 	friend class SkyMap;
 	friend class FileSource;
 	friend class StarDataSink;
-	
+	friend class LCGenerator;
+	friend class DetailDialog;
+	friend class AltVsTime;
+	friend class KSPopupMenu;
+	friend class WUTDialog;
+	friend class ViewOpsDialog;
+	friend class INDIDriver;
+	friend class INDI_P;
+	friend class PlanetViewer;
+	friend class JMoonTool;
+	friend class telescopeWizardProcess;
+	friend class INDIStdProperty;
+
 	/**Constructor. */
-	KStarsData( KStars *ks );
+	KStarsData();
 
 	/**Destructor.  Delete data objects. */
   virtual ~KStarsData();
@@ -114,7 +149,7 @@ public:
 		*@param line The line from the geographic database to be parsed
 		*@returns true if location successfully parsed; otherwise false.
 		*/
-	bool processCity( QString line );
+	bool processCity( QString& line );
 
 	/**Populate list of star objects from the stars database file.
 		*Each line in the file provides the information required to construct a
@@ -123,16 +158,21 @@ public:
 		*columns  field
 		*0-1      RA hours [int]
 		*2-3      RA minutes [int]
-		*4-9      RA seconds [float]
-		*10-16    dRA/dt (we don't read this field yet)
-		*17       Dec sign [char; '+' or '-']
-		*18-19    Dec degrees [int]
-		*20-21    Dec minutes [int]
-		*22-26    Dec seconds [float]
-		*27-32    dDec/dt (we don't read this field yet)
-		*33-36    magnitude [float]
-		*37-39    Spectral type [string]
-		*40-      Name(s) [string].  This field may be blank.  The string is the common
+		*4-8      RA seconds [float]
+		*10       Dec sign [char; '+' or '-']
+		*11-12    Dec degrees [int]
+		*13-14    Dec minutes [int]
+		*15-18    Dec seconds [float]
+		*20-28    dRA/dt (milli-arcsec/yr) [float]
+		*29-37    dDec/dt (milli-arcsec/yr) [float]
+		*38-44    Parallax (milli-arcsec) [float]
+		*46-50    Magnitude [float]
+		*51-55    B-V color index [float]
+		*56-57    Spectral type [string]
+		*59       Multiplicity flag (1=true, 0=false) [int]
+		*61-64    Variability range of brightness (magnitudes; bank if not variable) [float]
+		*66-71    Variability period (days; blank if not variable) [float]
+		*72-      Name(s) [string].  This field may be blank.  The string is the common
              name for the star (e.g., "Betelgeuse").  If there is a colon, then
              everything after the colon is the genetive name for the star (e.g.,
              "alpha Orionis").
@@ -141,6 +181,9 @@ public:
 		*/
 	bool readStarData( void );
 
+//	void processSAO(QString *line, bool reloadedData=false);
+	void processStar(QString *line, bool reloadedData=false);
+
 	/**Populate the list of deep-sky objects from the database file.
 		*Each line in the file is parsed according to column position:
 		*columns  field
@@ -169,6 +212,9 @@ public:
 		*/
 	bool readDeepSkyData( void );
 
+	bool readAsteroidData( void );
+	bool readCometData( void );
+
 	/**Read in Constellation line data.  The constellations are represented as a list of
 		*SkyPoints and an associated list of chars that indicates whether to draw a line
 		*between points (i) and (i+1) or to simply move to point (i+1). The lines are parsed
@@ -216,6 +262,39 @@ public:
 		*/
 	bool readMWData( void );
 
+    /**Read Variable Stars data and stores them in structure of type VariableStarsInfo.
+        *0-8 AAVSO Star Designation
+        *10-20 Common star name
+		*@short read Variable Stars data.
+		*@returns true if data is successfully read.
+		*/
+    bool readVARData(void);
+
+    //TODO JM: ADV tree should use XML instead
+    /**Read Advanced interface structure to be used later to construct the list view in
+       *the advanced tab in the Detail Dialog.
+       *KSLABEL designates a top-level parent label
+       *KSINTERFACE designates a common URL interface for several objects
+       *END designates the end of a sub tree structure
+		*@short read Advanted interface structure.
+		*@returns true if data is successfully read.
+		*/
+   bool readADVTreeData(void);
+
+    /**Read INDI hosts from an XML file*/
+   bool readINDIHosts(void);
+
+       //TODO JM: Use XML instead; The logger should have more features
+       // that allow users to enter details about their observation logs
+       // objects observed, eye pieces, telescope, conditions, mag..etc
+       /**Read user logs. The log file is formatted as following:
+       *KSLABEL designates the beginning of a log
+       *KSLogEnd designates the end of a log.
+		*@short read user logs.
+		*@returns true if data is successfully read.
+		*/
+   bool readUserLog(void);
+
 	/**Read in URLs to be attached to a named object's right-click popup menu.  At this
 		*point, there is no way to attach URLs to unnamed objects.  There are two
 		*kinds of URLs, each with its own data file: image links and webpage links.  In addition,
@@ -231,13 +310,16 @@ public:
 		*/
 	bool readURLData( QString url, int type=0 );
 
-	/**Read in custom object catalog.  Object data is read from a file, and parsed into a 
-		*QList of SkyObjects which is returned by reference through the 2nd argument.
+   // Used several times in the code, so why not
+   bool openURLFile(QString urlfile, QFile& file);
+
+	/**Read in custom object catalog.  Object data is read from a file, and parsed into a
+		*QPtrList of SkyObjects which is returned by reference through the 2nd argument.
 		*@param filename The custom catalog data file
 		*@param olist the list of skyobjects, returned as a reference through this variable
 		*@bool showerrs if true, notify user of unparsed lines.
 		*/
-	bool readCustomData( QString filename, QList<SkyObject> &olist, bool showerrs );
+	bool readCustomData( QString filename, QPtrList<DeepSkyObject> &olist, bool showerrs );
 
 	/**@short reset the faint limit for the stellar database
 		*@param newMagnitude the new faint limit.
@@ -248,11 +330,11 @@ public:
 	void setMagnitude( float newMagnitude, bool forceReload=false );
 
 	/**Add a custom object catalog.  The QString name of the catalog and
-		*the QList of SkyObjects comprising the data are given as arguments.
-		*This function simply appends the QList as an entry in the
+		*the QPtrList of SkyObjects comprising the data are given as arguments.
+		*This function simply appends the QPtrList as an entry in the
 		*CustomCatalogs QMap, with the name string used as the key.
 		*/
-	void addCatalog( QString name, QList<SkyObject> );
+	void addCatalog( QString name, QPtrList<DeepSkyObject> );
 
 	/**Set the NextDSTChange member.
 		*Need this accessor because I could not make KStars::privatedata a friend
@@ -260,10 +342,26 @@ public:
 		*/
 	void setNextDSTChange( long double jd ) { NextDSTChange = jd; }
 
+	/**
+		*return pointer to KStars options.
+		*/
+	KStarsOptions *getOptions() const { return options; }
+
+	/**
+		*Load KStars options.
+		*/
+	void loadOptions();
+
+	/**
+		*Save KStars options.  Optional KStars parameter for saving
+		*certain GUI options.
+		*/
+	void saveOptions(KStars *ks=0);
+
 	/**Make a backup copy of the KStarsOptions object.
 		*This is needed in case the user presses "cancel" after making changes in
 		*the ViewOpsDialog. */
-	void saveOptions();
+	void backupOptions();
 
 	/**Restore the KStarsOptions object from the backup copy.
 		*This is needed in case the user presses "cancel" after making changes in
@@ -277,7 +375,13 @@ public:
 
 	KLocale *getLocale() { return locale; };
 
-	KSPlanet *earth() { return PC->earth(); }
+	KSPlanet *earth() { return PCat->earth(); }
+
+	/**Find object by name.
+		*@param name Object name to find
+		*@returns pointer to SkyObject matching this name
+		*/
+	SkyObject* objectNamed( const QString &name );
 
 	/**The Sky is updated more frequently than the moon, which is updated more frequently
 		*than the planets.  The date of the last update for each category is recorded so we
@@ -287,6 +391,38 @@ public:
 		*/
 	void setFullTimeUpdate();
 
+	/**change the current simulation time to the time and date specified as the arguments.
+		*Specified date and time is always local time.
+		*@param newDate the date to set.
+		*@param newTIme the time to set.
+		*/
+	void changeTime(QDate newDate, QTime newTime );
+
+	/**Set the LST from the simulation clock's UTC value.
+		*/
+	void setLST();
+	/**Set the LST from the UTC specified as an argument.
+		*@param UTC the Universal time from which to set the LST.
+		*/
+	void setLST( QDateTime UTC );
+
+	void setHourAngle( double ha ) { HourAngle->setH( ha ); }
+
+	//Some members need to be accessed outside of the friend classes (i.e., in the main fcn).
+	GeoLocation *geo() { return options->Location(); }
+	SimClock *clock() { return Clock; }
+	dms *lst() { return LST; }
+	long double currentDate() {return CurrentDate;}
+
+	bool executeScript( const QString &name, SkyMap *map );
+
+	/**
+		*Initialize celestial equator, horizon and ecliptic.
+		*/
+	void initGuides( KSNumbers *num );
+
+	bool useDefaultOptions, startupComplete;
+
 signals:
 	/**Signal that specifies the text that should be drawn in the KStarsSplash window.
 		*/
@@ -303,7 +439,7 @@ signals:
 
 /**
 	*If data changed, emit clearCache signal.
-	*/	
+	*/
 	void clearCache();
 
 public slots:
@@ -311,6 +447,9 @@ public slots:
 	/**Create a timer and connect its timeout() signal to slotInitialize(). */
 	void initialize();
 
+	/**@short send a message to the console*/
+	void slotConsoleMessage( QString s ) { std::cout << s.utf8() << std::endl; }
+
 	/**Update the Simulation Clock.  Update positions of Planets.  Update
 		*Alt/Az coordinates of objects.  Update precession.  Update Focus position.
 		*Draw new Skymap.
@@ -319,7 +458,7 @@ public slots:
 		* It _will_ change!
 		*(JH:)hey, it's much less ugly now...can we lose the comment yet? :p
 		*/
-	void updateTime(SimClock *clock, GeoLocation *geo, SkyMap * skymap, const bool automaticDSTchange = true);
+	void updateTime(GeoLocation *geo, SkyMap * skymap, const bool automaticDSTchange = true);
 
 	/**Sets the direction of time and stores it in bool TimeRunForwards. If scale >= 0
 		*time is running forward else time runs backward. We need this to calculate just
@@ -327,6 +466,13 @@ public slots:
 		*/
 	void setTimeDirection( float scale );
 
+	void saveTimeBoxShaded( bool b ) { options->shadeTimeBox = b; }
+	void saveGeoBoxShaded( bool b ) { options->shadeGeoBox = b; }
+	void saveFocusBoxShaded( bool b ) { options->shadeFocusBox = b; }
+	void saveTimeBoxPos( QPoint p ) { options->posTimeBox = p; }
+	void saveGeoBoxPos( QPoint p ) { options->posGeoBox = p; }
+	void saveFocusBoxPos( QPoint p ) { options->posFocusBox = p; }
+
 private slots:
 	/**This function runs while the splash screen is displayed as KStars is
 		*starting up.  It is connected to the timeout() signal of a timer
@@ -341,7 +487,7 @@ private slots:
 	void slotInitialize();
 
 /**
-	*Checks if data transmission is allready running or not.
+	*Checks if data transmission is already running or not.
 	*/
 	void checkDataPumpAction();
 
@@ -356,6 +502,9 @@ private slots:
 	void sendClearCache();
 
 private:
+
+ 	void initError(QString fn, bool required);
+
 /**Reset local time to new daylight saving time. Use this function if DST has changed.
 	*Used by updateTime().
 	*/
@@ -365,7 +514,7 @@ private:
 	* Store the highest magnitude level at the current session and compare with current used
 	* magnitude. If current magnitude is equal to maxSetMagnitude reload data on next increment
 	* of magnitude level.
-	*/	
+	*/
 	float maxSetMagnitude;
 /*
 	* Store the last position in star data file. Needed by reloading star data.
@@ -374,37 +523,68 @@ private:
 
 	bool reloadingData();  // is currently reloading of data in progress
 
-	QList<GeoLocation> geoList;
-	QList<SkyObject> objList;
-	QList<StarObject> starList;
-	QList<SkyObject> deepSkyList;
-	QList<SkyPoint> clineList;
-	QList<QChar> clineModeList;
-	QList<SkyObject> cnameList;
-	QList<SkyPoint> Equator;
-	QList<SkyPoint> Ecliptic;
-	QList<SkyPoint> Horizon;
-	QList<SkyPoint> MilkyWay[11];
+/*	bool openSAOFile(int i);*/
+	bool openStarFile(int i);
+
+	KSFileReader *starFileReader;
+
+	static QPtrList<GeoLocation> geoList;
+	QPtrList<SkyObject> objList;
+
+	QPtrList<StarObject> starList;
+
+	unsigned int StarCount;
+
+  /** List of all deep sky objects */
+	QPtrList<DeepSkyObject> deepSkyList;
+  /** List of all deep sky objects per type, to speed up drawing the sky map */
+	QPtrList<DeepSkyObject> deepSkyListMessier;
+  /** List of all deep sky objects per type, to speed up drawing the sky map */
+	QPtrList<DeepSkyObject> deepSkyListNGC;
+  /** List of all deep sky objects per type, to speed up drawing the sky map */
+	QPtrList<DeepSkyObject> deepSkyListIC;
+  /** List of all deep sky objects per type, to speed up drawing the sky map */
+	QPtrList<DeepSkyObject> deepSkyListOther;
+
+	QPtrList<KSAsteroid> asteroidList;
+	QPtrList<KSComet> cometList;
+
+	QPtrList<SkyPoint> MilkyWay[NMWFILES];
+
+	QPtrList<SkyPoint> clineList;
+	QPtrList<QChar> clineModeList;
+	QPtrList<SkyObject> cnameList;
+	QPtrList<SkyObject> ObjLabelList;
+
+	QPtrList<SkyPoint> Equator;
+	QPtrList<SkyPoint> Ecliptic;
+	QPtrList<SkyPoint> Horizon;
+	QPtrList<VariableStarInfo> VariableStarsList;
+	QPtrList<ADVTreeData> ADVtreeList;
+	QPtrList<INDIHostsInfo> INDIHostsList;
 	ObjectNameList ObjNames;
 
-	QMap<QString, QList<SkyObject> > CustomCatalogs;
-	QMap<QString, TimeZoneRule> Rulebook;
+	QMap<QString, QPtrList<DeepSkyObject> > CustomCatalogs;
+	static QMap<QString, TimeZoneRule> Rulebook;
 
-	PlanetCatalog *PC;
+	SimClock *Clock;
+	QDateTime LTime, UTime;
+	bool TimeRunsForward, temporaryTrail;
 
 	QString cnameFile;
 	KStandardDirs *stdDirs;
-
-	QDateTime LTime, UTime;
-	QTime LST;
-	bool TimeRunsForward;
-	dms LSTh, HourAngle;
-	int ZoomLevel;
 	KLocale *locale;
 
-	QString TypeName[10];
+	dms *LST, *HourAngle;
 
+	QString TypeName[NTYPENAME];
+	KKey resumeKey;
+
+	PlanetCatalog *PCat;
 	KSMoon *Moon;
+	JupiterMoons *jmoons;
+
+	FOV fovSymbol;
 
 	double Obliquity, dObliq, dEcLong;
 	long double CurrentDate, LastNumUpdate, LastSkyUpdate, LastPlanetUpdate, LastMoonUpdate;
@@ -417,9 +597,7 @@ private:
 	KStars *kstars; //pointer to the parent widget
 
 	QTimer *initTimer;
-	bool inited;
 	int initCounter;
-	void initError(QString fn, bool required);
 
 /**
 	*Reloading of star data asynchronous:
@@ -429,6 +607,10 @@ private:
 	StarDataSink *loader;
 	QDataPump *pump;
 
+/**
+	*Count the number of KStarsData objects.
+	*/
+	static int objects;
 };
 
 
