@@ -15,77 +15,87 @@
  *                                                                         *
  ***************************************************************************/
 #include <dcopclient.h>
-#include <kaccel.h>
-#include <kconfig.h>
+#include <kshortcut.h>
 #include <kiconloader.h>
-#include <kmessagebox.h>
+#include <kpopupmenu.h>
 #include <kstatusbar.h>
-#include <kstdaction.h>
 #include <ktip.h>
 
-#include <qtooltip.h>
-#include <qtextstream.h>
+#include <kmessagebox.h>
 
 //#include "infopanel.h"
 #include "infoboxes.h"
 #include "kstars.h"
 #include "ksutils.h"
 #include "toggleaction.h"
+#include "indimenu.h"
 
 //This file contains functions that kstars calls at startup (except constructors).
 //These functions are declared in kstars.h
 
 void KStars::initActions() {
 //File Menu:
-	new KAction(i18n("New Window"), "window_new", KAccel::stringToKey( "Ctrl+N"  ),
+	new KAction(i18n("&New Window"), "window_new", KShortcut( "Ctrl+N"  ),
 			this, SLOT( newWindow() ), actionCollection(), "new_window");
-	new KAction(i18n("Close Window"), KAccel::stringToKey( "Ctrl+W"  ),
+	new KAction(i18n("&Close Window"), "fileclose", KShortcut( "Ctrl+W"  ),
 			this, SLOT( closeWindow() ), actionCollection(), "close_window");
+	new KAction( i18n( "&Save Sky Image..." ), "fileexport", KShortcut( "Ctrl+I" ),
+			this, SLOT( slotExportImage() ), actionCollection(), "export_image" );
+	new KAction( i18n( "&Run Script..." ), "launch", KShortcut( "Ctrl+R" ),
+			this, SLOT( slotRunScript() ), actionCollection(), "run_script" );
   KStdAction::print(this, SLOT( slotPrint() ), actionCollection(), "print" );
 	KStdAction::quit(this, SLOT( close() ), actionCollection(), "quit" );
 
 //Time Menu:
-	new KAction( i18n( "Set Time to &Now" ), KAccel::stringToKey( "Ctrl+E"  ),
+	new KAction( i18n( "Set Time to &Now" ), KShortcut( "Ctrl+E"  ),
 		this, SLOT( slotSetTimeToNow() ), actionCollection(), "time_to_now" );
-	new KAction( i18n( "set clock to a new time", "&Set Time..." ), "clock", KAccel::stringToKey( "Ctrl+S"  ),
+	new KAction( i18n( "set clock to a new time", "&Set Time..." ), "clock", KShortcut( "Ctrl+S"  ),
 		this, SLOT( slotSetTime() ), actionCollection(), "time_dialog" );
 	ToggleAction *actTimeRun = new ToggleAction( i18n( "Stop &Clock" ), BarIcon("player_pause"),
 				i18n("Start &Clock"), BarIcon("1rightarrow"),
 				0, this, SLOT( slotToggleTimer() ), actionCollection(), "timer_control" );
 	actTimeRun->setOffToolTip( i18n( "Start Clock" ) );
 	actTimeRun->setOnToolTip( i18n( "Stop Clock" ) );
-	QObject::connect(clock, SIGNAL(clockStarted()), actTimeRun, SLOT(turnOn()) );
-	QObject::connect(clock, SIGNAL(clockStopped()), actTimeRun, SLOT(turnOff()) );
+	QObject::connect(data()->clock(), SIGNAL(clockStarted()), actTimeRun, SLOT(turnOn()) );
+	QObject::connect(data()->clock(), SIGNAL(clockStopped()), actTimeRun, SLOT(turnOff()) );
 //UpdateTime() if clock is stopped (so hidden objects get drawn)
-	QObject::connect(clock, SIGNAL(clockStopped()), this, SLOT(updateTime()) );
+	QObject::connect(data()->clock(), SIGNAL(clockStopped()), this, SLOT(updateTime()) );
 
 //Focus Menu:
-	new KAction(i18n( "&Zenith" ), KAccel::stringToKey( "Z" ),
+	new KAction(i18n( "&Zenith" ), KShortcut( "Z" ),
 			this, SLOT( slotPointFocus() ),  actionCollection(), "zenith");
-	new KAction(i18n( "&North" ), KAccel::stringToKey( "N" ),
+	new KAction(i18n( "&North" ), KShortcut( "N" ),
 			this, SLOT( slotPointFocus() ),  actionCollection(), "north");
-	new KAction(i18n( "&East" ), KAccel::stringToKey( "E" ),
+	new KAction(i18n( "&East" ), KShortcut( "E" ),
 			this, SLOT( slotPointFocus() ),  actionCollection(), "east");
-	new KAction(i18n( "&South" ), KAccel::stringToKey( "S" ),
+	new KAction(i18n( "&South" ), KShortcut( "S" ),
 			this, SLOT( slotPointFocus() ),  actionCollection(), "south");
-	new KAction(i18n( "&West" ), KAccel::stringToKey( "W" ),
+	new KAction(i18n( "&West" ), KShortcut( "W" ),
 			this, SLOT( slotPointFocus() ),  actionCollection(), "west");
 	KAction *tmpAction = KStdAction::find( this, SLOT( slotFind() ),
 												actionCollection(), "find_object" );
 	tmpAction->setText( i18n( "&Find Object..." ) );
-	tmpAction->setToolTip( i18n( "Find Object" ) );
-	new KAction( i18n( "&Track Object" ), "decrypted", KAccel::stringToKey( "Ctrl+T"  ),
+	tmpAction->setToolTip( i18n( "Find object" ) );
+	
+	new KAction( i18n( "Engage &Tracking" ), "decrypted", KShortcut( "Ctrl+T"  ),
 		this, SLOT( slotTrack() ), actionCollection(), "track_object" );
-	new KAction( i18n( "Set Focus &Manually..." ), KAccel::stringToKey( "Ctrl+M" ),
+	if ( options()->isTracking ) { 
+		actionCollection()->action("track_object")->setText( i18n( "Stop &Tracking" ) );
+		actionCollection()->action("track_object")->setIconSet( BarIcon( "encrypted" ) );
+	}
+
+	new KAction( i18n( "Set Focus &Manually..." ), KShortcut( "Ctrl+M" ),
 			this, SLOT( slotManualFocus() ),  actionCollection(), "manual_focus" );
 
 //View Menu:
 	KStdAction::zoomIn(this, SLOT( slotZoomIn() ), actionCollection(), "zoom_in" );
 	KStdAction::zoomOut(this, SLOT( slotZoomOut() ), actionCollection(), "zoom_out" );
-//	new KAction( i18n( "Equatorial &Coordinates" ), KAccel::stringToKey( "C" ),
-//			this, SLOT( slotCoordSys() ),  actionCollection(), "coordsys" );
+	new KAction( i18n( "&Default Zoom" ), "viewmagfit.png", KShortcut( "Ctrl+Z" ),
+		this, SLOT( slotDefaultZoom() ), actionCollection(), "zoom_default" );
+	new KAction( i18n( "&Zoom to Angular Size..." ), "viewmag.png", KShortcut( "Ctrl+Shift+Z" ),
+		this, SLOT( slotSetZoom() ), actionCollection(), "zoom_set" );
 	actCoordSys = new ToggleAction( i18n("Horizontal &Coordinates"), i18n( "Equatorial &Coordinates" ),
-			0, this, SLOT( slotCoordSys() ), actionCollection(), "coordsys" );
+			Key_Space, this, SLOT( slotCoordSys() ), actionCollection(), "coordsys" );
 	if ( options()->useAltAz ) actCoordSys->turnOff();
 
 //Settings Menu:
@@ -96,26 +106,26 @@ void KStars::initActions() {
 	// to me, but ...
 	//
 	//Info Boxes option actions
-	KToggleAction *a = new KToggleAction(i18n( "Show the information boxes", "Show Info Boxes"),
+	KToggleAction *a = new KToggleAction(i18n( "Show the information boxes", "Show &Info Boxes"),
 			0, 0, 0, actionCollection(), "show_boxes");
 	a->setChecked( options()->showInfoBoxes );
 	QObject::connect(a, SIGNAL( toggled(bool) ), infoBoxes(), SLOT(setVisible(bool)));
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
 	infoBoxes()->setVisible( options()->showInfoBoxes );
 
-	a = new KToggleAction(i18n( "Show time-related info box", "Show Time"),
+	a = new KToggleAction(i18n( "Show time-related info box", "Show &Time Box"),
 			0, 0, 0, actionCollection(), "show_time_box");
 	a->setChecked( options()->showTimeBox );
 	QObject::connect(a, SIGNAL( toggled(bool) ), infoBoxes(), SLOT(showTimeBox(bool)));
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
 
-	a = new KToggleAction(i18n( "Show focus-related info box", "Show Focus"),
+	a = new KToggleAction(i18n( "Show focus-related info box", "Show &Focus Box"),
 			0, 0, 0, actionCollection(), "show_focus_box");
 	a->setChecked( options()->showFocusBox );
 	QObject::connect(a, SIGNAL( toggled(bool) ), infoBoxes(), SLOT(showFocusBox(bool)));
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
 
-	a = new KToggleAction(i18n( "Show location-related info box", "Show Location"),
+	a = new KToggleAction(i18n( "Show location-related info box", "Show &Location Box"),
 			0, 0, 0, actionCollection(), "show_location_box");
 	a->setChecked( options()->showGeoBox );
 	QObject::connect(a, SIGNAL( toggled(bool) ), infoBoxes(), SLOT(showGeoBox(bool)));
@@ -133,10 +143,11 @@ void KStars::initActions() {
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
 
 //Color scheme actions.  These are added to the "colorschemes" KActionMenu.
-	colorActionMenu = new KActionMenu( i18n( "&Color Schemes" ), actionCollection(), "colorschemes" );
+	colorActionMenu = new KActionMenu( i18n( "C&olor Schemes" ), actionCollection(), "colorschemes" );
 	addColorMenuItem( i18n( "&Default" ), "cs_default" );
 	addColorMenuItem( i18n( "&Star Chart" ), "cs_chart" );
 	addColorMenuItem( i18n( "&Night Vision" ), "cs_night" );
+	addColorMenuItem( i18n( "&Moonless Night" ), "cs_moonless-night" );
 
 //	colorActionMenu->insert( new KAction( i18n( "&Default" ), 0, this, SLOT( slotColorScheme() ), actionCollection(), "cs_default" ) );
 //	colorActionMenu->insert( new KAction( i18n( "&Star Chart" ), 0, this, SLOT( slotColorScheme() ), actionCollection(), "cs_chart" ) );
@@ -162,34 +173,76 @@ void KStars::initActions() {
 		file.close();
 	}
 
+	//Add FOV Symbol actions
+	fovActionMenu = new KActionMenu( i18n( "&FOV Symbols" ), actionCollection(), "fovsymbols" );
+	initFOV();
+
+// 	new KAction( i18n( "do not use a target symbol", "No Symbol" ), 0,
+// 			this, SLOT( slotTargetSymbol() ), actionCollection(), "target_symbol_none" );
+//
+// 	new KAction( i18n( "use a circle target symbol", "Circle" ), 0,
+// 			this, SLOT( slotTargetSymbol() ), actionCollection(), "target_symbol_circle" );
+//
+// 	new KAction( i18n( "use a crosshairs target symbol", "Crosshairs" ), 0,
+// 			this, SLOT( slotTargetSymbol() ), actionCollection(), "target_symbol_crosshairs" );
+//
+// 	new KAction( i18n( "use a bullseye target symbol", "Bullseye" ), 0,
+// 			this, SLOT( slotTargetSymbol() ), actionCollection(), "target_symbol_bullseye" );
+//
+// 	new KAction( i18n( "use a rectangle target symbol", "Rectangle" ), 0,
+// 			this, SLOT( slotTargetSymbol() ), actionCollection(), "target_symbol_rectangle" );
+
 	//use custom icon earth.png for the geoLocator icon.  If it is not installed
   //for some reason, use standard icon gohome.png instead.
 	QFile tempFile;
 	if (KSUtils::openDataFile( tempFile, "earth.png" ) ) {
 		tmpAction = new KAction( i18n( "Set Geographic Location..." ),
-				tempFile.name(), KAccel::stringToKey( "Ctrl+G"  ),
+				tempFile.name(), KShortcut( "Ctrl+G"  ),
 				this, SLOT( slotGeoLocator() ), actionCollection(), "geolocation" );
-		tmpAction->setToolTip( i18n( "Geographic Location" ) );
+		tmpAction->setToolTip( i18n( "Geographic location" ) );
 		tempFile.close();
 	} else {
-		new KAction( i18n( "Location on Earth", "&Geographic..." ), "gohome", KAccel::stringToKey( "Ctrl+G"  ),
+		new KAction( i18n( "Location on Earth", "&Geographic..." ), "gohome", KShortcut( "Ctrl+G"  ),
 				this, SLOT( slotGeoLocator() ), actionCollection(), "geolocation" );
 	}
 
 	KStdAction::preferences( this, SLOT( slotViewOps() ), actionCollection(), "configure" );
-
+	actionCollection()->action( "configure" )->setShortcut( KShortcut( "Ctrl+O" ) );
 
 //Tools Menu:
-	new KAction(i18n( "Calculator"), KAccel::stringToKey ( "Ctrl+C"),
+	new KAction(i18n( "Calculator..."), KShortcut( "Ctrl+C"),
 			this, SLOT( slotCalculator() ), actionCollection(), "astrocalculator");
 
+	// enable action only if file was loaded and processed successfully.
+	if (!data()->VariableStarsList.isEmpty())
+		new KAction(i18n( "AAVSO Light Curves..."), KShortcut( "Ctrl+V"),
+						this, SLOT( slotLCGenerator() ), actionCollection(), "lightcurvegenerator");
+
+	new KAction(i18n( "Altitude vs. Time..."), KShortcut( "Ctrl+A"),
+						this, SLOT( slotAVT() ), actionCollection(), "altitude_vs_time");
+	new KAction(i18n( "What's up Tonight..."), KShortcut("Ctrl+U"),
+						this, SLOT(slotWUT()), actionCollection(), "whats_up_tonight");
+	new KAction(i18n( "Script Builder..."), KShortcut("Ctrl+B"),
+						this, SLOT(slotScriptBuilder()), actionCollection(), "scriptbuilder");
+	new KAction(i18n( "Solar System..."), KShortcut("Ctrl+Y"),
+						this, SLOT(slotSolarSystem()), actionCollection(), "solarsystem");
+	new KAction(i18n( "Jupiter's Moons..."), KShortcut("Ctrl+J"),
+						this, SLOT(slotJMoonTool()), actionCollection(), "jmoontool");
+
+// devices Menu
+	new KAction(i18n("Telescope Wizard..."), 0, this, SLOT(slotTelescopeWizard()), actionCollection(), "telescope_wizard");
+	new KAction(i18n("Device Manager..."), 0, this, SLOT(slotINDIDriver()), actionCollection(), "device_manager");
+	new KAction(i18n("INDI Control Panel"), 0, this, SLOT(slotINDIPanel()), actionCollection(), "indi_control_panel");
+	new KAction(i18n("Configure INDI..."), 0, this, SLOT(slotINDIConf()), actionCollection(), "configure_indi");
+
+
 
 //Help Menu:
 	new KAction( i18n( "Tip of the Day" ), "idea", 0,
 			this, SLOT( slotTipOfDay() ), actionCollection(), "help_tipofday" );
 
 //Handbook toolBar item:
-	new KAction( i18n( "&Handbook" ), "contents", KAccel::stringToKey( "F1"  ),
+	new KAction( i18n( "&Handbook" ), "contents", KShortcut( "F1"  ),
 			this, SLOT( appHelpActivated() ), actionCollection(), "handbook" );
 
 //
@@ -289,70 +342,73 @@ void KStars::initActions() {
 
 //show_horizon:
 	if (KSUtils::openDataFile( tempFile, "show_horiz.png" ) ) {
-		KToggleAction *a = new KToggleAction( i18n( "Toggle Horizon" ),
+		KToggleAction *a = new KToggleAction( i18n( "Toggle Ground" ),
 				tempFile.name(), 0,
 				this, SLOT( slotViewToolBar() ), actionCollection(), "show_horizon" );
 		tempFile.close();
 		a->setChecked( options()->drawGround );
 	} else {
-		KToggleAction *a = new KToggleAction( i18n( "Toggle Horizon" ), "wizard", 0,
+		KToggleAction *a = new KToggleAction( i18n( "Toggle Ground" ), "wizard", 0,
 				this, SLOT( slotViewToolBar() ), actionCollection(), "show_horizon" );
 		a->setChecked( options()->drawGround );
 	}
 }
 
+void KStars::initFOV() {
+	//Read in the user's fov.dat and populate the FOV menu with its symbols.  If no fov.dat exists, populate
+	//create a default version.
+	QFile f;
+	QStringList fields;
+	QString nm;
+
+	f.setName( locateLocal( "appdata", "fov.dat" ) );
+
+	//if file s empty, let's start over
+	if ( (uint)f.size() == 0 ) f.remove();
+
+	if ( ! f.exists() ) {
+		if ( ! f.open( IO_WriteOnly ) ) {
+			kdDebug() << i18n( "Could not open fov.dat!" ) << endl;
+		} else {
+			QTextStream ostream(&f);
+			ostream << i18n( "Do not use a field-of-view indicator", "No FOV" ) <<  ":0.0:0:#AAAAAA" << endl;
+			ostream << i18n( "use field-of-view for binoculars", "7x35 Binoculars" ) << ":558:1:#AAAAAA" << endl;
+			ostream << i18n( "use 1-degree field-of-view indicator", "One Degree" ) << ":60:2:#AAAAAA" << endl;
+			ostream << i18n( "use HST field-of-view indicator", "HST WFPC2" ) << ":2.4:0:#AAAAAA" << endl;
+			f.close();
+		}
+	}
+
+	//just populate the FOV menu with items, don't need to fully parse the lines
+	if ( f.open( IO_ReadOnly ) ) {
+		QTextStream stream( &f );
+		while ( !stream.eof() ) {
+			QString line = stream.readLine();
+			fields = QStringList::split( ":", line );
+
+			if ( fields.count() == 4 ) {
+				nm = fields[0].stripWhiteSpace();
+				fovActionMenu->insert( new KAction( nm, 0, this, SLOT( slotTargetSymbol() ), actionCollection(), nm.utf8() ) );
+			}
+		}
+	} else {
+		kdDebug() << i18n( "Could not open file: %1" ).arg( f.name() ) << endl;
+	}
+
+	fovActionMenu->popupMenu()->insertSeparator();
+	fovActionMenu->insert( new KAction( i18n( "Edit FOV Symbols..." ), 0, this, SLOT( slotFOVEdit() ), actionCollection(), "edit_fov" ) );
+}
+
 void KStars::initStatusBar() {
 	statusBar()->insertItem( i18n( " Welcome to KStars " ), 0, 1, true );
 	statusBar()->setItemAlignment( 0, AlignLeft | AlignVCenter );
-	QString s = "00h 00m 00s,   +00d 00\'00\"";
+	QString s = "00h 00m 00s,   +00d 00\' 00\"";
 
 	statusBar()->insertItem( s, 1, 1, true );
 	statusBar()->setItemAlignment( 1, AlignRight | AlignVCenter );
 	statusBar()->setItemFixed( 1, -1 );
 }
 
-void KStars::initGuides(KSNumbers *num)
-{
-	// Define the Celestial Equator
-	for ( unsigned int i=0; i<NCIRCLE; ++i ) {
-		SkyPoint *o = new SkyPoint( i*24./NCIRCLE, 0.0 );
-		o->EquatorialToHorizontal( data()->LSTh, geo()->lat() );
-		data()->Equator.append( o );
-	}
-
-  // Define the horizon.
-  // Use the celestial Equator as a convenient starting point, but instead of RA and Dec,
-  // interpret the coordinates as azimuth and altitude, and then convert to RA, dec.
-  // The horizon will be redefined whenever the positions of sky objects are updated.
-	for (SkyPoint *point = data()->Equator.first(); point; point = data()->Equator.next()) {
-		double sinlat, coslat, sindec, cosdec, sinAz, cosAz;
-		double HARad;
-		dms dec, HA, RA, Az;
-		Az = point->ra();
-		Az.SinCos( sinAz, cosAz );
-		geo()->lat().SinCos( sinlat, coslat );
-
-		dec.setRadians( asin( coslat*cosAz ) );
-		dec.SinCos( sindec, cosdec );
-		HARad = acos( -1.0*(sinlat*sindec)/(coslat*cosdec) );
-		if ( sinAz > 0.0 ) { HARad = 2.0*dms::PI - HARad; }
-		HA.setRadians( HARad );
-		RA = data()->LSTh.Degrees() - HA.Degrees();
-
-		SkyPoint *o = new SkyPoint( RA, dec );
-		o->setAlt( 0.0 );
-		o->setAz( Az );
-
-		data()->Horizon.append( o );
-
-		//Define the Ecliptic (use the same ListIteration; interpret coordinates as Ecliptic long/lat)
-		o = new SkyPoint( 0.0, 0.0 );
-		o->setFromEcliptic( num->obliquity(), point->ra(), dms( 0.0 ) );
-		o->EquatorialToHorizontal( data()->LSTh, geo()->lat() );
-		data()->Ecliptic.append( o );
-	}
-}
-
 void KStars::datainitFinished(bool worked) {
 	if (!worked) {
 		kapp->quit();
@@ -365,81 +421,78 @@ void KStars::datainitFinished(bool worked) {
 	}
 
 	pd->buildGUI();
+	data()->setFullTimeUpdate();
 	updateTime();
-	clock->start();
+
+	data()->clock()->start();
+
+//Initialize FOV symbol from options
+	data()->fovSymbol.setName( options()->FOVName );
+	data()->fovSymbol.setSize( options()->FOVSize );
+	data()->fovSymbol.setShape( options()->FOVShape );
+	data()->fovSymbol.setColor( options()->FOVColor );
+
 	show();
 
 //Check whether initial position is below the horizon.
-//We sued to just call slotCenter() in buildGUI() which performs this check.  
-//However, on a Gentoo system, if the messagebox is shown before show() is called, 
+//We used to just call slotCenter() in buildGUI() which performs this check.
+//However, on some systems, if the messagebox is shown before show() is called,
 //the program exits.  It does not crash (at least there are no error messages),
 //it simply exits.  Very strange.
 	if ( options()->useAltAz && options()->drawGround &&
-			map()->focus()->alt().Degrees() < -1.0 ) {
+			map()->focus()->alt()->Degrees() < -1.0 ) {
 		QString caption = i18n( "Initial Position is Below Horizon" );
 		QString message = i18n( "The initial position is below the horizon.\nWould you like to reset to the default position?" );
-		if ( KMessageBox::warningYesNo( this, message, caption, 
+		if ( KMessageBox::warningYesNo( this, message, caption,
 				KStdGuiItem::yes(), KStdGuiItem::no(), "dag_start_below_horiz" ) == KMessageBox::Yes ) {
 			map()->setClickedObject( NULL );
-			map()->setFoundObject( NULL );
+			map()->setFocusObject( NULL );
 			options()->isTracking = false;
 			options()->setSnapNextFocus(true);
-			
+
 			SkyPoint DefaultFocus;
 			DefaultFocus.setAz( 180.0 );
 			DefaultFocus.setAlt( 45.0 );
-			DefaultFocus.HorizontalToEquatorial( LSTh(), geo()->lat() );
+			DefaultFocus.HorizontalToEquatorial( LST(), geo()->lat() );
 			map()->setDestination( &DefaultFocus );
 		}
 	}
 
-// just show dialog if option is set (don't force it)	
+	//If there is a focusObject() and it is a SS body, add a temporary Trail to it.
+	if ( map()->focusObject() && map()->focusObject()->isSolarSystem()
+			&& options()->useAutoTrail ) {
+		((KSPlanetBase*)map()->focusObject())->addToTrail();
+		data()->temporaryTrail = true;
+	}
+
+// just show dialog if option is set (don't force it)
 	KTipDialog::showTip( "kstars/tips" );
 }
 
 void KStars::privatedata::buildGUI() {
-	// need to set the mainwidget here, in main() this will cause a segfault because
-	// skymap will be created in this constructor and needs kapp->mainWidget()
-//	kapp->setMainWidget( ks );
-	// here we get the preloaded data (stars, constellations etc.)
-
-	//Instantiate the SimClock object
-	ks->clock = new SimClock(ks);
-
 	//create the widgets
 	ks->centralWidget = new QWidget( ks );
 	ks->setCentralWidget( ks->centralWidget );
 
-	ks->IBoxes = new InfoBoxes( ks->options()->windowWidth, ks->options()->windowHeight,
-			ks->options()->posTimeBox, ks->options()->shadeTimeBox,
-			ks->options()->posGeoBox, ks->options()->shadeGeoBox,
-			ks->options()->posFocusBox, ks->options()->shadeFocusBox,
-			ks->options()->colorScheme()->colorNamed( "BoxTextColor" ),
-			ks->options()->colorScheme()->colorNamed( "BoxGrabColor" ),
-			ks->options()->colorScheme()->colorNamed( "BoxBGColor" ) );
+	//set AAVSO modaless dialog pointer to 0
+	ks->AAVSODialog = 0;
 
-	ks->infoBoxes()->showTimeBox( ks->options()->showTimeBox );
-	ks->infoBoxes()->showFocusBox( ks->options()->showFocusBox );
-	ks->infoBoxes()->showGeoBox( ks->options()->showGeoBox );
-	ks->infoBoxes()->geoChanged(ks->geo());
+	//INDI menu started without GUI
+	ks->indimenu = new INDIMenu(ks);
 
-	connect( ks->infoBoxes()->timeBox(),  SIGNAL( shaded(bool) ), ks, SLOT( saveTimeBoxShaded(bool) ) );
-	connect( ks->infoBoxes()->geoBox(),   SIGNAL( shaded(bool) ), ks, SLOT( saveGeoBoxShaded(bool) ) );
-	connect( ks->infoBoxes()->focusBox(), SIGNAL( shaded(bool) ), ks, SLOT( saveFocusBoxShaded(bool) ) );
-	connect( ks->infoBoxes()->timeBox(),  SIGNAL( moved(QPoint) ), ks, SLOT( saveTimeBoxPos(QPoint) ) );
-	connect( ks->infoBoxes()->geoBox(),   SIGNAL( moved(QPoint) ), ks, SLOT( saveGeoBoxPos(QPoint) ) );
-	connect( ks->infoBoxes()->focusBox(), SIGNAL( moved(QPoint) ), ks, SLOT( saveFocusBoxPos(QPoint) ) );
-	
-	ks->initStatusBar();
-	ks->initActions();
+	//INDI driver set to null
+	ks->indidriver = 0;
 
-	ks->skymap = new SkyMap( ks->centralWidget );
+	ks->skymap = new SkyMap( ks->data(), ks->centralWidget );
 	// update skymap if KStarsData send update signal
-	QObject::connect(kstarsData, SIGNAL( update() ), ks->skymap, SLOT( Update() ) );
+	QObject::connect(kstarsData, SIGNAL( update() ), ks->skymap, SLOT( forceUpdate() ) );
 
 	// get focus of keyboard and mouse actions (for example zoom in with +)
 	ks->map()->QWidget::setFocus();
 
+	ks->initStatusBar();
+	ks->initActions();
+
 	// create the layout of the central widget
 	ks->topLayout = new QVBoxLayout( ks->centralWidget );
 	ks->topLayout->addWidget( ks->skymap );
@@ -447,20 +500,26 @@ void KStars::privatedata::buildGUI() {
 	// 2nd parameter must be false, or plugActionList won't work!
 	ks->createGUI("kstarsui.rc", false);
 
+	//Do not show text on the view toolbar buttons
+	//FIXME: after strings freeze, remove this and make the 
+	//text of each button shorter
+	ks->toolBar( "viewToolBar" )->setIconText( KToolBar::IconOnly );
+
 	//Initialize show/hide state of toolbars.
 	//These were in initActions, but they must appear after createGUI...
 	if ( !ks->options()->showMainToolBar ) ks->toolBar( "mainToolBar" )->hide();
 	if ( !ks->options()->showViewToolBar ) ks->toolBar( "viewToolBar" )->hide();
 
 	ks->TimeStep = new TimeStepBox( ks->toolBar() );
+	ks->toolBar()->insertWidget( 0, 6, ks->TimeStep, 15 );
 
 //Changing the timestep needs to propagate to the clock, check if slew mode should be
 //(dis)engaged, and return input focus to the skymap.
 	connect( ks->TimeStep, SIGNAL( scaleChanged( float ) ), ks->data(), SLOT( setTimeDirection( float ) ) );
-	connect( ks->TimeStep, SIGNAL( scaleChanged( float ) ), ks->clock, SLOT( setScale( float )) );
-	connect( ks->TimeStep, SIGNAL( scaleChanged( float ) ), ks->skymap, SLOT( slotClockSlewing() ) );
+	connect( ks->TimeStep, SIGNAL( scaleChanged( float ) ), ks->data()->clock(), SLOT( setScale( float )) );
+//	connect( ks->TimeStep, SIGNAL( scaleChanged( float ) ), ks->skymap, SLOT( slotClockSlewing() ) );
+	connect( ks->data()->clock(), SIGNAL( scaleChanged( float ) ), ks->map(), SLOT( slotClockSlewing() ) );
 	connect( ks->TimeStep, SIGNAL( scaleChanged( float ) ), ks, SLOT( mapGetsFocus() ) );
-	ks->toolBar()->insertWidget( 0, 6, ks->TimeStep, 14 );
 
 	ks->resize( ks->options()->windowWidth, ks->options()->windowHeight );
 
@@ -468,71 +527,78 @@ void KStars::privatedata::buildGUI() {
 	ks->slotSetTimeToNow();
 
 	//Define the celestial equator, horizon and ecliptic
-	KSNumbers tempnum(ks->clock->JD());
-	ks->initGuides(&tempnum);
+	KSNumbers tempnum(ks->data()->clock()->JD());
+	ks->data()->initGuides(&tempnum);
 
 	//Connect the clock.
-	QObject::connect( ks->clock, SIGNAL( timeAdvanced() ), ks, SLOT( updateTime() ) );
-	QObject::connect( ks->clock, SIGNAL( timeChanged() ), ks, SLOT( updateTime() ) );
+	QObject::connect( ks->data()->clock(), SIGNAL( timeAdvanced() ), ks, SLOT( updateTime() ) );
+	QObject::connect( ks->data()->clock(), SIGNAL( timeChanged() ), ks, SLOT( updateTime() ) );
 
 	// Connect cache function
 	QObject::connect( kstarsData, SIGNAL( clearCache() ), ks, SLOT( clearCachedFindDialog() ) );
 
 	SkyPoint newPoint;
-	if ( ks->useDefaultOptions ) {
+	if ( ks->data()->useDefaultOptions ) {
 		newPoint.setAz( ks->options()->focusRA );
 		newPoint.setAlt( ks->options()->focusDec + 0.0001 );
-		newPoint.HorizontalToEquatorial( ks->LSTh(), ks->geo()->lat() );
+		newPoint.HorizontalToEquatorial( ks->LST(), ks->geo()->lat() );
 	} else {
 		newPoint.set( ks->options()->focusRA, ks->options()->focusDec );
 	}
 
-//need to set foundObject before updateTime, otherwise tracking is set to false
+//need to set focusObject before updateTime, otherwise tracking is set to false
 	if ( (ks->options()->focusObject != i18n( "star" ) ) &&
 		     (ks->options()->focusObject != i18n( "nothing" ) ) )
-			ks->map()->setFoundObject( ks->getObjectNamed( ks->options()->focusObject ) );
+			ks->map()->setFocusObject( ks->data()->objectNamed( ks->options()->focusObject ) );
 
 	ks->updateTime();
 
-	//Set focus of Skymap.
+	//Set focus of Skymap to value stored in config.
 	//Set default position in case stored focus is below horizon
-	SkyPoint DefaultFocus;
-	DefaultFocus.setAz( 180.0 );
-	DefaultFocus.setAlt( 45.0 );
-	DefaultFocus.HorizontalToEquatorial( ks->LSTh(), ks->geo()->lat() );
-	ks->map()->setDestination( &DefaultFocus );
+//	SkyPoint DefaultFocus;
+//	DefaultFocus.setAz( 180.0 );
+//	DefaultFocus.setAlt( 45.0 );
+//	DefaultFocus.HorizontalToEquatorial( ks->LST(), ks->geo()->lat() );
+//	ks->map()->setDestination( &DefaultFocus );
 
 	//if user was tracking last time, track on same object now.
 	if ( ks->options()->isTracking ) {
 		if ( (ks->options()->focusObject== i18n( "star" ) ) ||
 		     (ks->options()->focusObject== i18n( "nothing" ) ) ) {
-			ks->map()->setClickedPoint( &newPoint );
+			ks->map()->setFocusPoint( &newPoint );
 		} else {
-			ks->map()->setClickedObject( ks->getObjectNamed( ks->options()->focusObject ) );
+			ks->map()->setClickedObject( ks->data()->objectNamed( ks->options()->focusObject ) );
 			if ( ks->map()->clickedObject() ) {
-				ks->map()->setClickedPoint( ks->map()->clickedObject() );
+				ks->map()->setFocusPoint( ks->map()->clickedObject() );
 			} else {
-				ks->map()->setClickedPoint( &newPoint );
+				ks->map()->setFocusPoint( &newPoint );
 			}
 		}
-
 //		ks->map()->slotCenter();
 	} else {
-		ks->map()->setClickedPoint( &newPoint );
+		ks->map()->setFocusPoint( &newPoint );
 //		ks->map()->slotCenter();
 	}
 
-	ks->map()->setDestination( ks->map()->clickedPoint() );
-	ks->map()->destination()->EquatorialToHorizontal( ks->LSTh(), ks->geo()->lat() );
-	ks->map()->setFocus( ks->map()->destination() );
-	ks->map()->focus()->EquatorialToHorizontal( ks->LSTh(), ks->geo()->lat() );
+	if ( ks->options()->focusObject== i18n( "star" ) ) ks->options()->focusObject = i18n( "nothing" );
 
-	ks->setHourAngle();
+	ks->map()->setDestination( ks->map()->focusPoint() );
+	ks->map()->destination()->EquatorialToHorizontal( ks->LST(), ks->geo()->lat() );
+	ks->map()->setFocus( ks->map()->destination() );
+	ks->map()->focus()->EquatorialToHorizontal( ks->LST(), ks->geo()->lat() );
+
+	ks->infoBoxes()->focusObjChanged( ks->options()->focusObject );
+	ks->infoBoxes()->focusCoordChanged( ks->map()->focus() );
+
+	ks->data()->setHourAngle( ks->LST()->Hours() - ks->map()->focus()->ra()->Hours() );
 
 	ks->map()->setOldFocus( ks->map()->focus() );
-	ks->map()->oldfocus()->setAz( ks->map()->focus()->az().Degrees() );
-	ks->map()->oldfocus()->setAlt( ks->map()->focus()->alt().Degrees() );
+	ks->map()->oldfocus()->setAz( ks->map()->focus()->az()->Degrees() );
+	ks->map()->oldfocus()->setAlt( ks->map()->focus()->alt()->Degrees() );
+
+	// check zoom in/out buttons
+	if ( ks->options()->ZoomFactor >= MAXZOOM ) ks->actionCollection()->action("zoom_in")->setEnabled( false );
+	if ( ks->options()->ZoomFactor <= MINZOOM ) ks->actionCollection()->action("zoom_out")->setEnabled( false );
 
 	kapp->dcopClient()->resume();
-
 }
