@@ -15,25 +15,13 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qwidget.h>
-#include <qpixmap.h>
-#include <qfile.h>
-#include <qpaintdevice.h>
 #include <qlayout.h>
-#include <qlabel.h>
-#include <kmessagebox.h>
 #include <klocale.h>
 
 #include "ksutils.h"
 #include "kstarssplash.h"
 
-#if (QT_VERSION < 300)
-#include <kapp.h>
-#define FLUSH flushX
-#else
 #include <kapplication.h>
-#define FLUSH flush
-#endif
 
 KStarsSplash::KStarsSplash( QWidget *parent, const char* name )
 	: KDialogBase( KDialogBase::Plain, i18n( "Loading KStars..." ),
@@ -65,6 +53,7 @@ KStarsSplash::KStarsSplash( QWidget *parent, const char* name )
 	label = new QLabel( page, "label1" );
 	QPalette pal( label->palette() );
 	pal.setColor( QPalette::Normal, QColorGroup::Background, QColor( "Black" ) );
+	pal.setColor( QPalette::Inactive, QColorGroup::Background, QColor( "Black" ) );
 	pal.setColor( QPalette::Normal, QColorGroup::Foreground, QColor( "White" ) );
 	pal.setColor( QPalette::Inactive, QColorGroup::Foreground, QColor( "White" ) );
 	label->setPalette( pal );
@@ -106,7 +95,7 @@ void KStarsSplash::setMessage( QString s ) {
 	*repaint call will queued in event buffer. With flush all X11 events of
 	*this application will flushed.
 	*/
-	kapp->FLUSH();
+	kapp->flush();
 }
 
 #include "kstarssplash.moc"
