@@ -18,33 +18,13 @@
 #include <stdlib.h>
 #include <stdio.h>
 
-#include <qlabel.h>
-#include <qlineedit.h>
-#include <qlistbox.h>
-#include <qpushbutton.h>
-#include <qlayout.h>
-#include <qgroupbox.h>
-#include <qvalidator.h>
-#include <qvariant.h>
-#include <qspinbox.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
-#include <qfile.h>
-#include <qtextstream.h>
 
-#include <klocale.h>
 #include <kmessagebox.h>
 
 #include "kstars.h"
-#include "kstarsmessagebox.h"
 #include "locationdialog.h"
 
-#include <qglobal.h>
-#if (QT_VERSION <= 299)
-#include <kstddirs.h>
-#else
 #include <kstandarddirs.h>
-#endif
 
 LocationDialog::LocationDialog( QWidget* parent )
     : KDialogBase( KDialogBase::Plain, i18n( "Set Geographic Location" ), Ok|Cancel, Ok, parent ) {
@@ -85,10 +65,10 @@ LocationDialog::LocationDialog( QWidget* parent )
 
   CountLabel = new QLabel( CityBox );
 
-  CityFilter = new QLineEdit( CityBox );
-  CityFilter->setFocus();		// set focus to city inputline
-  ProvinceFilter = new QLineEdit( CityBox );
-  CountryFilter = new QLineEdit( CityBox );
+  CityFilter = new KLineEdit( CityBox );
+  CityFilter->setFocus();  // set focus to city inputline
+  ProvinceFilter = new KLineEdit( CityBox );
+  CountryFilter = new KLineEdit( CityBox );
 
   GeoBox = new QListBox( CityBox );
   GeoBox->setVScrollBarMode( QListBox::AlwaysOn );
@@ -102,12 +82,12 @@ LocationDialog::LocationDialog( QWidget* parent )
 	NewCountryLabel = new QLabel( i18n( "Country:" ), CoordBox );
 	LongLabel = new QLabel( i18n( "Longitude:" ), CoordBox );
 	LatLabel = new QLabel( i18n( "Latitude:" ), CoordBox );
-	TZLabel = new QLabel( i18n( "timezone offset from universal time", "UT offset: " ), CoordBox );
-	TZRuleLabel = new QLabel( i18n( "daylight savings time rule", "    DST rule: " ), CoordBox );
+	TZLabel = new QLabel( i18n( "timezone offset from universal time", "UT offset:" ), CoordBox );
+	TZRuleLabel = new QLabel( i18n( "daylight savings time rule", "DST rule:" ), CoordBox );
 
-	NewCityName = new QLineEdit( CoordBox );
-	NewProvinceName = new QLineEdit( CoordBox );
-	NewCountryName = new QLineEdit( CoordBox );
+	NewCityName = new KLineEdit( CoordBox );
+	NewProvinceName = new KLineEdit( CoordBox );
+	NewCountryName = new KLineEdit( CoordBox );
 	NewLong = new dmsBox( CoordBox );
 	NewLat = new dmsBox( CoordBox );
 
@@ -115,9 +95,11 @@ LocationDialog::LocationDialog( QWidget* parent )
 	TZRuleBox = new QComboBox( CoordBox );
 	TZBox->setMinimumWidth( 16 );
 	TZRuleBox->setMinimumWidth( 16 );
+	TZBox->setEditable( true );
+	TZBox->setDuplicatesEnabled( false );
 
 	for ( int i=0; i<25; ++i )
-		TZBox->insertItem( QString("%1").arg( i-12 ) );
+		TZBox->insertItem( QString("%1").arg( (double)(i-12), 0, 'f', 2 ) );
 
 	QMap<QString, TimeZoneRule>::Iterator it;
 	for ( it = p->data()->Rulebook.begin(); it != p->data()->Rulebook.end(); ++it )
@@ -195,8 +177,6 @@ LocationDialog::LocationDialog( QWidget* parent )
 	connect( NewCityName, SIGNAL( textChanged( const QString & ) ), this, SLOT( nameChanged() ) );
 	connect( NewProvinceName, SIGNAL( textChanged( const QString & ) ), this, SLOT( nameChanged() ) );
 	connect( NewCountryName, SIGNAL( textChanged( const QString & ) ), this, SLOT( nameChanged() ) );
-	connect( NewLong, SIGNAL( textChanged( const QString & ) ), this, SLOT( checkLong() ) );
-	connect( NewLat, SIGNAL( textChanged( const QString & ) ), this, SLOT( checkLat() ) );
 	connect( NewLong, SIGNAL( textChanged( const QString & ) ), this, SLOT( dataChanged() ) );
 	connect( NewLat, SIGNAL( textChanged( const QString & ) ), this, SLOT( dataChanged() ) );
 	connect( TZBox, SIGNAL( activated(int) ), this, SLOT( dataChanged() ) );
@@ -210,6 +190,13 @@ LocationDialog::LocationDialog( QWidget* parent )
 	nameModified = false;
 	AddCityButton->setEnabled( false );
 
+	NewCityName->setTrapReturnKey(true);
+	NewProvinceName->setTrapReturnKey(true);
+	NewCountryName->setTrapReturnKey(true);
+	CityFilter->setTrapReturnKey(true);
+	ProvinceFilter->setTrapReturnKey(true);
+	CountryFilter->setTrapReturnKey(true);
+	
 	initCityList();
 	resize (640, 480);
 }
@@ -229,6 +216,16 @@ void LocationDialog::initCityList( void ) {
 		}
 		GeoBox->insertItem( s );
 		GeoID[GeoBox->count() - 1] = p->data()->geoList.at();
+
+		//If TZ is not even integer value, add it to listbox 
+		if ( loc->TZ0() - int( loc->TZ0() ) && ! TZBox->listBox()->findItem( QString("%1").arg( loc->TZ0(), 0, 'f', 2 ) ) ) {
+			for ( unsigned int i=0; i<TZBox->count(); ++i ) {
+				if ( TZBox->text( i ).toDouble() > loc->TZ0() ) {
+					TZBox->insertItem( QString("%1").arg( loc->TZ0(), 0, 'f', 2 ), i-1 );
+					break;
+				}
+			}
+		}
 	}
 
 	QString scount;
@@ -313,10 +310,10 @@ void LocationDialog::changeCity( void ) {
 	NewCountryName->setText( c.translatedCountry() );
 	NewLong->showInDegrees( c.lng() );
 	NewLat->showInDegrees( c.lat() );
-	TZBox->setCurrentItem( int( c.TZ0() ) + 12 );
+	TZBox->setCurrentText( QString("%1").arg( c.TZ0(), 0, 'f', 2 ) );
 
 //Pick the City's rule from the rulebook
-	for ( unsigned int i=0; i<TZRuleBox->count(); ++i ) {
+	for ( int i=0; i<TZRuleBox->count(); ++i ) {
 		if ( p->data()->Rulebook[ TZRuleBox->text(i) ].equals( c.tzrule() ) ) {
 			TZRuleBox->setCurrentItem( i );
 			break;
@@ -344,16 +341,21 @@ void LocationDialog::addCity( void ) {
 		return;
 	}
 
-	bool latOk(false), lngOk(false);
-	dms lat = NewLat->createDms( &latOk );
-	dms lng = NewLong->createDms( &lngOk );
+	bool latOk(false), lngOk(false), tzOk(false);
+	dms lat = NewLat->createDms( true, &latOk );
+	dms lng = NewLong->createDms( true, &lngOk );
+	double TZ = TZBox->lineEdit()->text().toDouble( &tzOk );
 
-	if ( NewCityName->text().isEmpty() || NewCountryName->text().isEmpty() ||
-		! latOk || ! lngOk ) {
-
-		QString message = i18n( "All fields (except Province) must be filled to add this location." );
+	if ( NewCityName->text().isEmpty() || NewCountryName->text().isEmpty() ) {
+		QString message = i18n( "All fields (except province) must be filled to add this location." );
 		KMessageBox::sorry( 0, message, i18n( "Fields are Empty" ) );
 		return;
+	
+	//FIXME after strings freeze lifts, separate TZ check from lat/long check 
+	} else if ( ! latOk || ! lngOk || ! tzOk ) {
+		QString message = i18n( "Could not parse coordinates." );
+		KMessageBox::sorry( 0, message, i18n( "Bad Coordinates" ) );
+		return;
 	} else {
 		if ( !nameModified ) {
 			QString message = i18n( "Really override original data for this city?" );
@@ -373,19 +375,18 @@ void LocationDialog::addCity( void ) {
 		file.setName( locateLocal( "appdata", "mycities.dat" ) ); //determine filename in local user KDE directory tree.
 
 		if ( !file.open( IO_ReadWrite | IO_Append ) ) {
-			QString message = i18n( "Local cities database could not be opened.\nLocation will not be recorded." );		
-			KMessageBox::sorry( 0, message, i18n( "Could not Open File" ) );
+			QString message = i18n( "Local cities database could not be opened.\nLocation will not be recorded." );
+			KMessageBox::sorry( 0, message, i18n( "Could Not Open File" ) );
 			return;
 		} else {
 			char ltsgn = 'N'; if ( lat.degree()<0 ) ltsgn = 'S';
 			char lgsgn = 'E'; if ( lng.degree()<0 ) lgsgn = 'W';
-			double TZ = double( TZBox->currentItem() - 12 );
 			QString TZrule = TZRuleBox->currentText();
 
 			entry = entry.sprintf( "%-32s : %-21s : %-21s : %2d : %2d : %2d : %c : %3d : %2d : %2d : %c : %5.1f : %2s\n",
 						name.local8Bit().data(), province.local8Bit().data(), country.local8Bit().data(),
-						abs(lat.degree()), lat.getArcMin(), lat.getArcSec(), ltsgn,
-						abs(lng.degree()), lng.getArcMin(), lat.getArcSec(), lgsgn,
+						abs(lat.degree()), lat.arcmin(), lat.arcsec(), ltsgn,
+						abs(lng.degree()), lng.arcmin(), lat.arcsec(), lgsgn,
 						TZ, TZrule.local8Bit().data() );
 
 			QTextStream stream( &file );
@@ -420,8 +421,8 @@ void LocationDialog::findCitiesNear( int lng, int lat ) {
 	//find all cities within 3 degrees of (lng, lat); list them in GeoBox
 	GeoBox->clear();
 	for ( unsigned int i=0; i<ks->data()->geoList.count(); ++i ) {
-		if ( ( abs(	lng - int( ks->data()->geoList.at(i)->lng().Degrees() ) ) < 3 ) &&
-				 ( abs( lat - int( ks->data()->geoList.at(i)->lat().Degrees() ) ) < 3 ) ) {
+		if ( ( abs(	lng - int( ks->data()->geoList.at(i)->lng()->Degrees() ) ) < 3 ) &&
+				 ( abs( lat - int( ks->data()->geoList.at(i)->lat()->Degrees() ) ) < 3 ) ) {
 	    QString sc( ks->data()->geoList.at(i)->translatedName() );
 			sc.append( ", " );
 			if ( !ks->data()->geoList.at(i)->province().isEmpty() ) {
@@ -449,23 +450,19 @@ void LocationDialog::findCitiesNear( int lng, int lat ) {
 	repaint();
 }
 
-void LocationDialog::checkLong( void ) {
-	double lng = NewLong->createDms().Degrees();
+bool LocationDialog::checkLongLat( void ) {
+	if ( NewLong->text().isEmpty() || NewLat->text().isEmpty() ) return false;
+	
+	bool ok(false);
+	double lng = NewLong->createDms(true, &ok).Degrees();
+	if ( ! ok ) return false;
+	double lat = NewLat->createDms(true, &ok).Degrees();
+	if ( ! ok ) return false;
+	 
+	if ( lng < -180.0 || lng > 180.0 ) return false;
+	if ( lat <  -90.0 || lat >  90.0 ) return false;
 
-	if ( ! NewLong->text().isEmpty() && ( lng < -180.0 || lng > 180.0 ) ) {
-		QString message = i18n( "The longitude must be expressed as \na floating-point number between -180.0 and 180.0" );
-		KMessageBox::sorry( 0, message, i18n( "Invalid Longitude" ) );
-		NewLong->clearFields();
-	}
-}
-
-void LocationDialog::checkLat( void ) {
-	double lat = NewLat->createDms().Degrees();
-	if ( ! NewLat->text().isEmpty() && ( lat < -90.0 || lat > 90.0 ) ) {
-		QString message = i18n( "The latitude must be expressed as \na floating-point number between -90.0 and 90.0" );
-		KMessageBox::sorry( 0, message, i18n( "Invalid Latitude" ) );
-		NewLat->clearFields();
-	}
+	return true;
 }
 
 void LocationDialog::clearFields( void ) {
@@ -477,7 +474,7 @@ void LocationDialog::clearFields( void ) {
 	NewCountryName->clear();
 	NewLong->clearFields();
 	NewLat->clearFields();
-	TZBox->setCurrentItem( 12 );
+	TZBox->lineEdit()->setText( QString( "%1" ).arg( 0.0, 0, 'f', 2 ) );
 	TZRuleBox->setCurrentItem( 0 );
 	nameModified = true;
 	dataModified = false;
@@ -516,21 +513,21 @@ void LocationDialog::showTZRules( void ) {
 	lines.append( i18n( "ZN: Apr. 1 (01:00) / Oct. 1 (00:00)" ) );
 
 	QString message = i18n( "Daylight Saving Time Rules" );
-	KStarsMessageBox::badCatalog( 0, message, lines, message );
+	KMessageBox::informationList( 0, message, lines, message );
 }
 
 void LocationDialog::nameChanged( void ) {
 	nameModified = true;
-	if ( !NewCityName->text().isEmpty() && !NewProvinceName->text().isEmpty() &&
-				!NewCountryName->text().isEmpty() )
-		AddCityButton->setEnabled( true );
-//	kdDebug() << "name changed." << endl;
+	dataChanged();
 }
 
+//do not enable Add button until all data are present and valid.
 void LocationDialog::dataChanged( void ) {
 	dataModified = true;
-	AddCityButton->setEnabled( true );
-//	kdDebug() << "data changed." << endl;
+	if ( ! NewCityName->text().isEmpty() && ! NewCountryName->text().isEmpty() && checkLongLat() )
+		AddCityButton->setEnabled( true );
+	else
+		AddCityButton->setEnabled( false );
 }
 
 void LocationDialog::slotOk( void ) {
