@@ -25,7 +25,7 @@
 	*The top section allows the location to be selected from a database
 	*of 2000 cities.  It contains a MapCanvas (showing map of the globe
 	*with cities overlaid, with a handler for mouse clicks), a QListBox
-	*containing the names of cities in the database, and three QLineEdit
+	*containing the names of cities in the database, and three KLineEdit
 	*widgets, which allow the user to filter the List by the name of the
 	*City, Province, and Country.  In addition, the List
 	*can be filtered by location, by clicking anywhere in the MapCanvas.
@@ -33,7 +33,7 @@
 	*
 	*The bottom section allows the location to be specified manually.
 	*The Longitude, Latitude, City name, Province/State name, and Country name
-	*are entered into QLineEdits.  There is also a QPushButton for adding the
+	*are entered into KLineEdits.  There is also a QPushButton for adding the
 	*location to the custom Cities database.  If the user selects "Add" without
 	*filling in all of the manual entry fields, an error message is displayed.
 	*@short Geographic Location dialog
@@ -41,16 +41,14 @@
 	*@version 0.9
   */
 #include <kdialogbase.h>
-#include <qlineedit.h>
+#include <klineedit.h>
 #include <qpushbutton.h>
 
 #include "mapcanvas.h"
 #include "dmsbox.h"
 
 #include <qglobal.h>
-#if (QT_VERSION > 299)
 #include <qmemarray.h>
-#endif
 
 class QVBoxLayout;
 class QHBoxLayout;
@@ -87,7 +85,7 @@ public:
 	*Retrieve ID number of the highlighted City in the QListBox.
 	*Because the list can be filtered, the city's position in the List
 	*cannot be used to directly identify the city in the database.
-	*So, we maintain an integer QArray that contains the database ID of each
+	*So, we maintain an integer QMemArray that contains the database ID of each
 	*city in the list.  This function uses the List position of the highlighted
 	*city to select the corresponding database ID.
 	*@returns the position of the highlighted city in the List of cities.
@@ -107,7 +105,15 @@ public:
 
 /**@returns the name of the selected city.
 	*/
-	QString selectedCityName( void ) { return NewCityName->text(); }
+	QString selectedCity( void ) { return NewCityName->text(); }
+
+/**@returns the name of the selected city.
+	*/
+	QString selectedProvince( void ) { return NewProvinceName->text(); }
+
+/**@returns the name of the selected city.
+	*/
+	QString selectedCountry( void ) { return NewCountryName->text(); }
 
 /**@returns true if the AddCityBUtton is enabled
 	*/
@@ -117,9 +123,9 @@ public:
 
 public slots:
 /**
-	*When text is entered in the City/Province/Country Filter QLineEdits,
+	*When text is entered in the City/Province/Country Filter KLineEdits,
 	*the List of cities is trimmed to show only cities beginning with the entered text.
-	*Also, the QArray of ID numbers is kept in sync with the filtered list.
+	*Also, the QMemArray of ID numbers is kept in sync with the filtered list.
 	*/
   void filterCity( void );
 
@@ -135,43 +141,20 @@ public slots:
 	*/
 	void addCity( void );
 
-/**
-	*Make sure a valid Longitude value was entered.
-	*/
-	void checkLong( void );
-
-/**
-	*Make sure a valid Latitude value was entered.
-	*/
-	void checkLat( void );
-
-/**Clear all city data fields in preparation of adding a custom location.
-	*/
 	void clearFields( void );
-	
-/**Display a window summarizing the Daylight Savings Time Rules.
-	*/
 	void showTZRules( void );
-	
-/**If any of the name fields (city/province/country) change, check to see that none of them
-	*are empty.  If none are empty, enable AddCity button.
-	*/
 	void nameChanged( void );
-	
-/**If any of the data fields (long/lat/tz/rule) change, check to see that none of them
-	*are empty.  If none are empty, enable AddCity button.
-	*/
 	void dataChanged( void );
-	
 //	void prepareToAccept( void );
-	
-/**Check to see if the AddCity button is enabled.  If so, call "addCity()" for the user.
-	*In any case, call accept().
-	*/
 	void slotOk();
 
 private:
-  int newCity;
+/**
+	*Make sure Longitude and Latitude values are valid.
+	*/
+	bool checkLongLat( void );
+
+	int newCity;
 	bool dataModified, nameModified, bCityAdded;
 	QGridLayout *glay, *glay2;
 	QHBoxLayout *hlay, *hlayCoord, *hlayTZ, *hlayButtons, *hlay3;
@@ -181,13 +164,13 @@ private:
 	QLabel *NewCityLabel, *NewProvinceLabel, *NewCountryLabel;
 	QLabel *LongLabel, *LatLabel, *CountLabel;
 	QLabel *TZLabel, *TZRuleLabel;
-	QLineEdit *NewCityName, *NewProvinceName, *NewCountryName;
+	KLineEdit *NewCityName, *NewProvinceName, *NewCountryName;
+	KLineEdit *CityFilter, *ProvinceFilter, *CountryFilter;
 	dmsBox *NewLong, *NewLat;
-	QLineEdit *CityFilter, *ProvinceFilter, *CountryFilter;
 	QComboBox *TZBox, *TZRuleBox;
 	QPushButton *AddCityButton, *ClearFields, *ShowTZRules;
 	MapCanvas *MapView;
-	QArray<int> GeoID;
+        QMemArray<int> GeoID;
 
 };
 
