@@ -15,37 +15,40 @@
  *                                                                         *
  ***************************************************************************/
 
-
-
-
 #ifndef SKYMAP_H
 #define SKYMAP_H
 
 #include <qwidget.h>
 #include <qpainter.h>
+#include <qpaintdevice.h>
 #include <qpoint.h>
 #include <qpixmap.h>
 
 #include "skyobject.h"
 #include "starobject.h"
+#include "ksplanetbase.h"
 #include "ksplanet.h"
 #include "dms.h"
 #include "skypoint.h"
 #include "starpixmap.h"
+#include "kstarsdata.h"
 
-#define NZOOM 30
-
-class QPopupMenu;
 class QLabel;
+class KSPopupMenu;
+class InfoBoxes;
 class KStars;
 
-/**Class for the sky display, derived from QWidget.  This widget is just a canvas
-	*on which the sky is painted.  It's the main widget for KStars.  The widget also
-	*handles user interaction (both mouse and keyboard).
+/**This is the canvas on which the sky is painted.  It's the main widget for KStars.
+	*Contains SkyPoint members for the map's Focus (current central position), Destination
+	*(requested central position), FocusPoint (next queued position to be focused),
+	*MousePoint (position of mouse cursor), and ClickedPoint (position of last mouse click).
+	*Also contains the InfoBoxes for on-screen data display.
 	*
-	*@short Canvas widget for displaying the sky bitmap; also handles user input.
+	*SkyMap handles most user interaction events (both mouse and keyboard).
+	*
+	*@short Canvas widget for displaying the sky bitmap; also handles user interaction events.
 	*@author Jason Harris
-	*@version 0.9
+	*@version 1.0
 	*/
 
 class SkyMap : public QWidget  {
@@ -53,22 +56,59 @@ class SkyMap : public QWidget  {
 public:
 /**
 	*Constructor.  Read stored settings from KConfig object (focus position,
-	*zoom level, sky color, etc.).  Run initPopupMenus().
+	*zoom factor, sky color, etc.).  Run initPopupMenus().
 	*/
-	SkyMap(QWidget *parent=0, const char *name=0);
+	SkyMap( KStarsData *d, QWidget *parent=0, const char *name=0);
+
 /**
 	*Destructor (empty)
 	*/
 	~SkyMap();
 
+/**
+	*@returns pointer to InfoBoxes object.
+	*/
+		InfoBoxes* infoBoxes() const { return IBoxes; }
+
+/**Display object name and coordinates in the FocusBox
+	*/
+		void showFocusCoords();
+
+/**@short Update the focus position according to current options.
+	*/
+	void updateFocus();
+
 /**@returns a pointer to the central focus point of the sky map
 	*/
 	SkyPoint* focus() { return &Focus; }
 
+/**@returns a pointer to the destination point of the sky map
+	*/
+	SkyPoint* destination()  { return &Destination; }
+
 /**@short sets the central focus point of the sky map
 	*@param f a pointer to the SkyPoint the map should be centered on
 	*/
-	void setFocus( SkyPoint *f ) { Focus.set( f->ra(), f->dec() ); }
+	void setFocus( SkyPoint *f );
+
+/**@short sets the focus point of the skymap, using ra/dec coordinates
+	*@param ra the new right ascension
+	*@param dec the new declination
+	*/
+	void setFocus( const dms &ra, const dms &dec );
+
+/**@short sets the focus point of the sky map, using ra/dec coordinates
+	*Differs from the above function only in the type of its parameters
+	*@param ra the new right ascension
+	*@param dec the new declination
+	*/
+	void setFocus(double ra, double dec);
+
+/**@short sets the focus point of the sky map, using alt/az coordinates
+	*@param alt the new altitude
+	*@param az the new azimuth
+	*/
+	void setFocusAltAz( const dms &alt, const dms & az);
 
 /**@short sets the central focus point of the sky map, using alt/az coordinates
 	*@param alt the new altitude
@@ -76,16 +116,32 @@ public:
 	*/
 	void setFocusAltAz(double alt, double az);
 
-/**@returns a pointer to the destination point of the sky map
-	*/
-	SkyPoint* destination() { return &Destination; }
-
 /**@short sets the destination point of the sky map
 	*@param f a pointer to the SkyPoint the map should slew to
 	*/
 	void setDestination( SkyPoint *f );
 
+/**@short sets the destination point of the skymap, using ra/dec coordinates
+	*@param ra the new right ascension
+	*@param dec the new declination
+	*/
+	void setDestination( const dms &ra, const dms &dec );
+
+/**@short sets the destination point of the sky map, using ra/dec coordinates
+	*Differs from the above function only in the type of its parameters
+	*@param ra the new right ascension
+	*@param dec the new declination
+	*/
+	void setDestination(double ra, double dec);
+
 /**@short sets the destination point of the sky map, using alt/az coordinates
+	*@param alt the new altitude
+	*@param az the new azimuth
+	*/
+	void setDestinationAltAz( const dms &alt, const dms & az);
+
+/**@short sets the destination point of the sky map, using alt/az coordinates.
+	*Differs from the above function only in the type of its parameters
 	*@param alt the new altitude
 	*@param az the new azimuth
 	*/
@@ -114,6 +170,9 @@ public:
 	*/
 	void setClickedPoint( SkyPoint *f ) { ClickedPoint.set( f->ra(), f->dec() ); }
 
+	SkyPoint* focusPoint() { return &FocusPoint; }
+	void setFocusPoint( SkyPoint *f ) { if ( f ) FocusPoint.set( f->ra(), f->dec() ); }
+
 /**When the user moves the mouse in the sky map, the sky coordinates of the mouse
 	*cursor are continually passed to the private member MousePoint.  This function retrieves
 	*a pointer to MousePoint.
@@ -140,15 +199,15 @@ public:
 
 /**If the user centers the sky map on an object (by double-clicking or using the
 	*Find Object dialog), a pointer to the "focused" object is stored in
-	*the private member FoundObject.  This function returns the FoundObject pointer.
+	*the private member FocusObject.  This function returns the FocusObject pointer.
 	*@returns a pointer to the object centered on by the user.
 	*/
-	SkyObject* foundObject( void ) const { return FoundObject; }
+	SkyObject* focusObject( void ) const { return FocusObject; }
 
-/**Sets the FoundObject pointer to the argument.
-	*@param o the SkyObject pointer to be assigned to FoundObject
+/**Sets the FocusObject pointer to the argument.
+	*@param o the SkyObject pointer to be assigned to FocusObject
 	*/
-	void setFoundObject( SkyObject *o ) { FoundObject = o; }
+	void setFocusObject( SkyObject *o ) { FocusObject = o; }
 
 /**@returns the current setting of the starpix color mode (real colors, solid red, solid
 	*white or solid black)
@@ -168,12 +227,6 @@ public:
 	*/
 	void setStarColorIntensity( int value ) { starpix->setIntensity( value ); }
 
-/**pixelScale is referenced one time outside of skymap.  This is the access method
-	*for this external reference.
-	*@returns current value of pixelScale
-	*/
-	int getPixelScale( void );
-
 /**@returns estimate of the display's angular field of view
 	*/
 	float fov( void );
@@ -181,7 +234,7 @@ public:
 /**
 	*Determine if the skypoint p might be visible in the current display window
 	*/
-	bool checkVisibility( SkyPoint *p, float fov, bool useAltAz, bool isPoleVisible, bool drawGround=false );
+	bool checkVisibility( SkyPoint *p, float fov, double XMax );
 
 /**call keyPressEvent, as if the key given as an argument had been pressed. */
 	void invokeKey( int key );
@@ -195,23 +248,42 @@ public:
 /**@returns whether the map is in slewing mode */
 	bool isSlewing() const { return slewing; }
 
+	bool isObjectLabeled( SkyObject *o );
+
+/**@short Convenience function for shutting off tracking mode.  Just calls KStars::slotTrack().
+	*/
+	void stopTracking();
+
+  //These were protected, but KStars needs them for slotPrint()...
+	void drawMilkyWay( QPainter& psky, double scale = 1.0 );
+	void drawCoordinateGrid( QPainter& psky, double scale = 1.0 );
+	void drawEquator( QPainter& psky, double scale = 1.0 );
+	void drawEcliptic( QPainter& psky, double scale = 1.0 );
+	void drawConstellationLines( QPainter& psky, double scale = 1.0 );
+	void drawConstellationNames( QPainter& psky, QFont& stdFont, double scale = 1.0 );
+	void drawStars( QPainter& psky, double scale = 1.0 );
+	void drawDeepSkyObjects( QPainter& psky, double scale = 1.0 );
+	void drawDeepSkyCatalog( QPainter& psky, QPtrList<DeepSkyObject>& catalog, QColor& color, bool drawObject, bool drawImage, double scale = 1.0 );
+	void drawPlanetTrail( QPainter& psky, KSPlanetBase *ksp, double scale = 1.0 );
+	void drawSolarSystem( QPainter& psky, bool drawPlanets, double scale = 1.0 );
+	void drawHorizon( QPainter& psky, QFont& stdFont, double scale = 1.0 );
+	void drawAttachedLabels( QPainter &psky, double scale = 1.0 );
+	void drawNameLabel( QPainter &psky, SkyObject *obj, int x, int y, double scale );
+
+	void setMapGeometry( void );
+	void exportSkyImage( const QPaintDevice *pd );
+
 public slots:
 	virtual void setGeometry( int x, int y, int w, int h );
 	virtual void setGeometry( const QRect &r );
 
 /**Recalculates the positions of objects in the sky, and then repaints the sky map.
-	*If the positions don't need to be recalculated, use update() instead of Update().
-	*This saves a lot of CPU time.  Note that update() is called automatically when the widget
-	*window is brought to the front from behind another window.
-	*/	
-	void Update();
-
-/**Identical to Update(), except calls repaint() instead of update() in order
-	*to have the paintEvent executed immediately (whereas update() simply adds
-	*the call to the event queue, so if many calls to Update() are made, some
-	*will be dropped.  UpdateNow() avoids this, forcing each paintEvent to execute.
+	*If the positions don't need to be recalculated, use update() instead of forceUpdate().
+	*This saves a lot of CPU time.
+	*@param now if true, paintEvent() is run immediately.  Otherwise, it is added to the event queue
 	*/
-	void UpdateNow();
+	void forceUpdate( bool now=false );
+	void forceUpdateNow() { forceUpdate( true ); }
 
 /**Estimate the effect of atmospheric refraction.  Refraction only affects the
 	*altitude of objects beyond the atmosphere (so it shouldn't be used for the horizon).
@@ -221,7 +293,7 @@ public slots:
 	*@param findApparent if true, then alt is the true altitude, and we'll find the apparent alt.  Otherwise, vice versa.
 	*@returns the corrected altitude.
 	*/
-	dms refract( dms alt, bool findApparent );
+	dms refract( const dms *alt, bool findApparent );
 
 /**Step the Focus point toward the Destination point.  If the Focus is within 1 step of the
 	*destination, snap directly to the destination.
@@ -247,16 +319,23 @@ public slots:
 /**Popup menu function: Show Detailed Information Dialog. */
 	void slotDetail( void );
 
+	void slotAddObjectLabel( void );
+	void slotRemoveObjectLabel( void );
+
+	void slotAddPlanetTrail( void );
+	void slotRemovePlanetTrail( void );
+
 /**Popup menu function: Add a custom Image or Information URL. */
 	void addLink( void );
 
-/**Checks whether the timestep exceeds a threshhold value.  If so, sets
+/**Checks whether the timestep exceeds a threshold value.  If so, sets
 	*ClockSlewing=true and sets the SimClock to ManualMode. */
 	void slotClockSlewing();
 
 signals:
 	void destinationChanged();
-	
+    void linkAdded();
+
 protected:
 /**Draw the Sky, and all objects in it. */
 	virtual void paintEvent( QPaintEvent *e );
@@ -292,56 +371,12 @@ protected:
 /**If the skymap will be resized, the sky must be new computed. So this function calls explicite new computing of
 	*the skymap. */
 	virtual void resizeEvent( QResizeEvent * );
-	
+
 private slots:
 /**Set the shape of mouse cursor to a cross with 4 arrows. */
 	void setMouseMoveCursor();
-	
-private:
-/**Initialize the popup menus. Adds name and type labels, and possibly
-	*Rise/Set/Transit labels, Center/Track item, and Show Details item.
-	*@short initialize the right-click popup menu
-	*@param name1 The primary object name
-	*@param name2 The (optional) secondary object name
-	*@param type a string identifying the object type
-	*@param showRiseSet if true, the Rise/Set/Transit labels are added
-	*@param showCenterTrack if true, the Center/Track item is added
-	*@param showDetails if true, the Show-Details item is added
-	*/
-	void initPopupMenu( QString name1, QString name2, QString type,
-		bool showRiseSet=true, bool showCenterTrack=true, bool showDetails=true );
 
-/**Completes the popup menu by adding Image and Information links as menu items.
-	*@param showDSS show DSS Image links?  These links are inappropriate for planets, so 
-	*this should be false for planets' menus.
-	*@param allowCustom If true, add the "Add link..." menu item
-	*/
-	void addLinksToMenu( bool showDSS=true, bool allowCustom=true );
-	
-/**Call initPopupMenu() and addLinksToMenu() with parameters set for a star object
-	*@param star a pointer to the StarObject to which the menu is attached.
-	*/
-	void createStarMenu( StarObject *star );
-	
-	/**Call initPopupMenu() and addLinksToMenu() with parameters set for a general sky object
-	*@param obj a pointer to the SkyObject to which the menu is attached.
-	*/
-	void createSkyObjectMenu( SkyObject *obj );
-	
-	/**Call initPopupMenu() and addLinksToMenu() with parameters set for a custom sky object
-	*@param obj a pointer to the SkyObject to which the menu is attached.
-	*/
-	void createCustomObjectMenu( SkyObject *obj );
-	
-	/**Call initPopupMenu() and addLinksToMenu() with parameters set for a planet
-	*@param p a pointer to the SkyObject of the planet to which the menu is attached.
-	*/
-	void createPlanetMenu( SkyObject *p );
-	
-	/**Call initPopupMenu() and addLinksToMenu() with parameters set for empty sky.
-	*/
-	void createEmptyMenu( void );
-	
+private:
 /**Given the coordinates of the SkyPoint argument, determine the
 	*pixel coordinates in the SkyMap.  If Horiz==true, use the SkyPoint's
 	*Alt/AZ coordinates; otherwise, use RA/Dec.
@@ -350,7 +385,7 @@ private:
 	*@param Horiz if true, use Alt/Az coordinates.
 	*@param doRefraction if true, correct for atmospheric refraction
 	*/
-	QPoint getXY( SkyPoint *o, bool Horiz, bool doRefraction=true );
+	QPoint getXY( SkyPoint *o, bool Horiz, bool doRefraction=true, double scale = 1.0 );
 
 /**Determine RA, Dec coordinates of the pixel at (dx, dy), which are the
 	*pixel coordinates measured from the center of the SkyMap bitmap.
@@ -359,35 +394,58 @@ private:
 	*@param Horiz if true, the SkyMap is displayed using the Horizontal coordinate system
 	*@param LSTh Local sidereal time.
 	*@param lat current geographic laitude
-	*/	
-	SkyPoint dXdYToRaDec( double dx, double dy, bool Horiz, dms LST, dms lat, bool doRefraction=true );
+	*/
+	SkyPoint dXdYToRaDec( double dx, double dy, bool Horiz, dms *LST, const dms *lat, bool doRefraction=true );
 
 /**Large switch-controlled statement to draw objects on the SkyMap
 	*according to their type and catalog.  This is going to be changed
 	*So that each SkyObject has its own draw() function, which will be
-	*called from SkyMap's paintEvent().	
+	*called from SkyMap's paintEvent().
 	*color is only needed by Stars.
 	*/
-	void drawSymbol( QPainter &p, int type, int x, int y, int size, double e=1.0, int pa=0, QChar color=0 );
+	void drawSymbol( QPainter &p, int type, int x, int y, int size, double e=1.0, int pa=0, QChar color=0, double scale = 1.0 );
 
-/**Determine the on-screen position angle of the SkyObject.  This is the sum
+/**Determine the on-screen position angle of a DeepSkyObject.  This is the sum
 	*of the object's sky position angle (w.r.t. North), and the position angle
 	*of "North" at the position of the object.  The latter is determined by
 	*constructing a test point with the same RA but a slightly increased Dec
 	*as the Object, and calculating the angle of a line connecing the object to
 	*its test point. */
-	int findPA( SkyObject *o, int x, int y );
+	int findPA( DeepSkyObject *o, int x, int y );
 
 /**Draw a planet.  This is an image if the planet image is loaded, the zoomlevel
 	*is high enough (but not so high that the image fills the screen), and the
 	*user has selected that planet images be shown.  If one of these conditions
 	*is false, then a simple circle is drawn instead.  */
-	void drawPlanet(QPainter &psky, KSPlanetBase *p, QColor c, int sizemin,
-			double mult, int zoommin, int resize_mult = 1);
+	void drawPlanet(QPainter &psky, KSPlanetBase *p, QColor c,
+			double zoommin, int resize_mult = 1, double scale = 1.0 );
 
-	void drawBoxes( QPixmap *pm );
+/**Draw overlays on top of the sky map.  These include the infoboxes,
+	*field-of-view indicator, telescope symbols, zoom box and any other
+	*user-interaction graphics
+	*/
+	void drawOverlays( QPixmap *pm );
 
-/**Sets the shape of the default mouse cursor to a cross.  */
+/**Draw the InfoBoxes on the QPainter passed as an argument (this should be
+	*the skymap's painter).
+	*/
+	void drawBoxes( QPainter &p );
+
+/**Draw the Field-of-View indicator.
+	*@param psky The QPainter to draw on (this should be skymap's QPainter).
+	*@param style The kind of FOV indicator to draw:
+	*0: no symbol
+	*1: 1-degree circle
+	*2: crosshairs
+	*3: bullseye (2, 1, 0.5 degrees)
+	*4: rectangle (user-defined width, height)
+	*/
+	void drawTargetSymbol( QPainter &psky );
+
+	void drawTelescopeSymbols(QPainter &psky);
+	void drawZoomBox( QPainter &psky);
+
+/**@short Sets the shape of the default mouse cursor to a cross.  */
 	void setDefaultMouseCursor();
 
 /**Check if the current point on screen is a valid point on the sky. This is needed
@@ -395,38 +453,45 @@ private:
 	*corners of the sky map at the lowest zoom level are the invalid points).  */
 	bool unusablePoint (double dx, double dy);
 
-/**Set the text of the Rise time and Set time labels in the popup menu  */
-	void setRiseSetLabels( void );
+/**@short convenience function for getting the ZoomFactor from the options object
+	*The Zoom Factor is the pixel scale of the display (i.e., the number of pixels which subtend one radian)
+	*/
+	double zoomFactor() const;
 
-	KStars *ksw;
-	QString sURL;
-	QPopupMenu *pmenu, *pmStar, *pmSolarSys, *pmMoon, *pmMess, *pmNGC;
-	QLabel *pmStarTitle, *pmSolTitle, *pmMoonTitle, *pmMessTitle, *pmMessTitle2, *pmNGCTitle, *pmNGCTitle2, *nothing_label;
-	QLabel *pmMessType, *pmNGCType, *pmTitle, *pmTitle2, *pmType;
-	QLabel *pmRiseTime, *pmSetTime, *pmTransitTime;
 	bool mouseButtonDown, midMouseButtonDown;
 	bool mouseMoveCursor;		// true if mouseMoveEvent; needed by setMouseMoveCursor
-	
-	QPixmap *sky;
-
-	SkyPoint  Focus, OldFocus, ClickedPoint, MousePoint, Destination;
-	SkyObject *ClickedObject, *FoundObject;
-
-	StarPixmap *starpix;	// the pixmap of the stars
-	int idSolInfo, idMessHST, idMoonInfo, idMoonImages, idMessInfo, idNGCHST;
 	bool slewing, clockSlewing;
-	int pixelScale[NZOOM];
-	double Range[NZOOM];
+	bool computeSkymap;	// if false only old pixmap will repainted with bitBlt(), this saves a lot of cpu usage
+	int idSolInfo, idMessHST, idMoonInfo, idMoonImages, idMessInfo, idNGCHST;
+	int scrollCount;
+	double Range;
 	double RefractCorr1[184], RefractCorr2[184];
 	double y0;
-	int scrollCount;
-	bool computeSkymap;	// if false only old pixmap will repainted with bitBlt(), this saves a lot of cpu usage
-//DEBUG
-	bool dumpHorizon;
-//END_DEBUG
+
+	//data for checkVisibility
+	bool isPoleVisible;
+	int guidemax;
+	float guideFOV;
+	double XRange, Ymax;
+	double guideXRange;
+
+	KStars *ksw;
+	KStarsData *data;
+	QString sURL;
+	KSPopupMenu *pmenu;
+	QPixmap *sky;
+	InfoBoxes   *IBoxes;
+	SkyPoint  Focus, OldFocus, ClickedPoint, FocusPoint, MousePoint, Destination;
+	SkyObject *ClickedObject, *FocusObject;
+	StarPixmap *starpix;	// the pixmap of the stars
 
 	QPointArray *pts;	// needed in paintEvent() so it should not every event call reallocated (save time)
 	SkyPoint *sp;			// see line above
+
+	QRect ZoomRect; //The manual-focus circle.
+//DEBUG
+	bool dumpHorizon;
+//END_DEBUG
 };
 
 #endif
