@@ -19,17 +19,19 @@
 #define TIMEDIALOG_H
 
 #include <kdialogbase.h>
-#include <kdatepik.h>
 #include <qdatetime.h>
-#include <qcombobox.h>
-#include <qlabel.h>
-#include <qpushbutton.h>
-#include <qspinbox.h>
-#include <qlayout.h>
 #include <qvariant.h>
 #include <qtooltip.h>
 #include <qwhatsthis.h>
 
+class QHBoxLayout;
+class QVBoxLayout;
+class KDatePicker;
+class QSpinBox;
+class QLabel;
+class QPushButton;
+class KStars;
+
 /**Dialog for adjusting the Time and Date.  Contains a KDatePicker widget
 	*for selecting the date, and three QSpinBoxes for selecting the Hour,
 	*Minute and Second.  There is also a "Now" QPushbutton for selecting the
@@ -46,7 +48,7 @@ public:
 	*Constructor.  Creates widgets and packs them into QLayouts.
 	*Connects	Signals and Slots.
 	*/
-	TimeDialog( QDateTime now, QWidget* parent = 0 );
+	TimeDialog( QDateTime now, QWidget* parent = 0, bool isUTCNow = false );
 
 /**
 	*Destructor (empty)
@@ -86,23 +88,26 @@ public slots:
 
 /**
 	*When the value of the MinuteBox QSpinBox is changed, prefix a "0" to
-	*the displayed text, if the value is less than 10. 	
+	*the displayed text, if the value is less than 10.
 	*/
 	void MinutePrefix( int value );
 
 /**
 	*When the value of the SecondBox QSpinBox is changed, prefix a "0" to
-	*the displayed text, if the value is less than 10. 	
+	*the displayed text, if the value is less than 10.
 	*/
 	void SecondPrefix( int value );
 
 protected:
-  bool event( QEvent* );
+	bool event( QEvent* );
+	void keyReleaseEvent( QKeyEvent* );
 
 private:
-	QHBoxLayout *hlay;
-	QVBoxLayout *vlay;
-	KDatePicker *dPicker;
+  KStars *ksw;
+  bool UTCNow;
+  QHBoxLayout *hlay;
+  QVBoxLayout *vlay;
+  KDatePicker *dPicker;
   QSpinBox* HourBox;
   QLabel* TextLabel1;
   QSpinBox* MinuteBox;
