@@ -154,7 +154,7 @@ QString TimeSpinBox::mapValueToText( int value ) {
 
 void TimeSpinBox::changeScale( float x ) {
 	//Pick the closest value
-	int imin;
+	int imin = 0;
 	float dx, dxlast(10000000000.0), dxmin(10000000000.0);
 	for ( unsigned int i=0; i<42; ++i ) {
 		dx = fabs( TimeScale[i] - fabs(x) );
@@ -167,7 +167,7 @@ void TimeSpinBox::changeScale( float x ) {
 	setValue( imin );
 }
 
-float TimeSpinBox::timeScale( void ) {
+float TimeSpinBox::timeScale( void ) const {
 	return value() > 0 ? TimeScale[ value() ] : -1.*TimeScale[ abs(value()) ];
 }
 
