@@ -23,9 +23,7 @@
 #include <qpushbutton.h>
 #include <qtabwidget.h>
 //#include <qvaluelist.h>
-#include <qtooltip.h>
 
-#include "klocale.h"
 #include <kmessagebox.h>
 
 //#include "verbspanish.h"
