@@ -15,13 +15,9 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qvaluelist.h>
 #include <qlistview.h>
-#include <qstring.h>
-#include <qptrlist.h>
 
 #include "kverbedit.h"
-#include "kverbosdoc.h"
 #include "verbspanish.h"
 #include "kerfassen.h"
 
