@@ -16,36 +16,25 @@
  ***************************************************************************/
 
 // include files for QT
-#include <qdir.h>
 #include <qprinter.h>
-#include <qpainter.h>
 #include <qcheckbox.h>
 #include <qradiobutton.h>
-#include <qlineedit.h>
 
 // include files for KDE
-#include <kiconloader.h>
-#include <kmessagebox.h>
 #include <kfiledialog.h>
-#include <kmenubar.h>
 #include <klineeditdlg.h>
-#include <klocale.h>
-#include <kconfig.h>
-#include <kstdaction.h>
-#include <kstartuplogo.h>
+#include "kstartuplogo.h"
 #include <kstandarddirs.h>
 #include <kstatusbar.h>
 
 // application specific includes
 #include "kverbos.h"
 #include "kverbosview.h"
-#include "kverbosdoc.h"
 
 // my includes
 #include "kerfassen.h"
 #include "kverbedit.h"
 #include "kverbosoptions.h"
-#include "kverbosuser.h"
 #include "kresult.h"
 #include "kfeedercontrol.h"
 
@@ -78,6 +67,7 @@ KVerbosApp::KVerbosApp(QWidget* , const char* name):KMainWindow (0, name)
   initView();
 
   readOptions();
+  setAutoSaveSettings();
 
   ///////////////////////////////////////////////////////////////////
   // disable actions at startup
@@ -141,12 +131,13 @@ void KVerbosApp::initActions()
   editPaste = KStdAction::paste(this, SLOT(slotEditPaste()), actionCollection());
   editErfassen = new KAction(i18n("E&nter New Verb..."), 0, 0, this, SLOT(slotEditErfassen()), actionCollection(),"edit_erfassen");
   editBearbeiten = new KAction(i18n("&Edit Verblist..."), 0, 0, this, SLOT(slotEditBearbeiten()), actionCollection(), "edit_bearbeiten");
-  viewToolBar = KStdAction::showToolbar(this, SLOT(slotViewToolBar()), actionCollection());
-  viewStatusBar = KStdAction::showStatusbar(this, SLOT(slotViewStatusBar()), actionCollection());
+
+  setStandardToolBarMenuEnabled(true);
+  createStandardStatusBarAction();
   settingOptions = new KAction(i18n("&Configure KVerbos..."), 0, 0, this, SLOT(slotSettingsOptions()), actionCollection(), "settings_options");
   userUsername = new KAction(i18n("&Username..."), 0, 0, this, SLOT(slotSettingsUsername()), actionCollection(), "user_username");
   userResults = new KAction(i18n("&Results"), 0, 0, this, SLOT(slotUserResults()), actionCollection(), "user_results");
-
+ 
   fileNewWindow->setStatusText(i18n("Opens a new application window"));
   fileOpenStandard->setStatusText(i18n("Opens the standard KVerbos verb file"));
   fileNew->setStatusText(i18n("Creates a new document"));
@@ -162,8 +153,6 @@ void KVerbosApp::initActions()
   editPaste->setStatusText(i18n("Pastes the clipboard contents to actual position"));
   editErfassen->setStatusText(i18n("Add new verbs."));
   editBearbeiten->setStatusText(i18n("Edit the list of verbs."));
-  viewToolBar->setStatusText(i18n("Enables/disables the toolbar"));
-  viewStatusBar->setStatusText(i18n("Enables/disables the statusbar"));
   settingOptions->setStatusText(i18n("Change some options of the program"));
   userUsername->setStatusText(i18n("Enter your name as the username"));
   userResults->setStatusText(i18n("These are your latest results."));
@@ -186,10 +175,10 @@ void KVerbosApp::initStatusBar()
   // STATUSBAR
   // TODO: add your own items you need for displaying current application status.
   statusBar()->insertItem(i18n("Ready."), ID_STATUS_MSG);
-  statusBar()->insertItem(i18n("trained: 0"), ID_TRAINED_MSG);
-  statusBar()->insertItem(i18n("correct: 0"), ID_CORRECT_MSG);
-  statusBar()->insertItem(i18n("number of verbs: 0"), ID_VERBS_MSG);
-  statusBar()->insertItem(i18n("user: nobody"), ID_USERNAME_MSG);
+  statusBar()->insertItem(i18n("Trained: 0"), ID_TRAINED_MSG);
+  statusBar()->insertItem(i18n("Correct: 0"), ID_CORRECT_MSG);
+  statusBar()->insertItem(i18n("Number of verbs: 0"), ID_VERBS_MSG);
+  statusBar()->insertItem(i18n("User: nobody"), ID_USERNAME_MSG);
 }
 
 void KVerbosApp::initDocument()
@@ -233,11 +222,6 @@ KVerbosDoc* KVerbosApp::getDocument() const
 
 void KVerbosApp::saveOptions()
 {
-  config->setGroup("General Options");
-  config->writeEntry("Geometry", size());
-  config->writeEntry("Show Toolbar", viewToolBar->isChecked());
-  config->writeEntry("Show Statusbar",viewStatusBar->isChecked());
-  config->writeEntry("ToolBarPos", (int) toolBar("mainToolBar")->barPos());
   fileOpenRecent->saveEntries(config,"Recent Files");
 
   // Meine eigenen Optionen
@@ -265,31 +249,9 @@ void KVerbosApp::saveOptions()
 
 void KVerbosApp::readOptions()
 {
-  config->setGroup("General Options");
-
-  // bar status settings
-  bool bViewToolbar = config->readBoolEntry("Show Toolbar", true);
-  viewToolBar->setChecked(bViewToolbar);
-  slotViewToolBar();
-
-  bool bViewStatusbar = config->readBoolEntry("Show Statusbar", true);
-  viewStatusBar->setChecked(bViewStatusbar);
-  slotViewStatusBar();
-
-  // bar position settings
-  KToolBar::BarPosition toolBarPos;
-  toolBarPos=(KToolBar::BarPosition) config->readNumEntry("ToolBarPos", KToolBar::Top);
-  toolBar("mainToolBar")->setBarPos(toolBarPos);
-
   // initialize the recent file list
   fileOpenRecent->loadEntries(config,"Recent Files");
 
-  QSize size=config->readSizeEntry("Geometry");
-  if(!size.isEmpty())
-  {
-    resize(size);
-  }
-
   // Meine eigenen Optionen
   // Die zum Lernen ausgewhlten Zeiten
   config->setGroup("tiempos");
@@ -334,7 +296,7 @@ void KVerbosApp::saveProperties(KConfig *_cfg)
   else
   {
     KURL url=doc->URL();	
-    _cfg->writeEntry("filename", url.url());
+    _cfg->writePathEntry("filename", url.url());
     _cfg->writeEntry("modified", doc->isModified());
     QString tempname = kapp->tempSaveName(url.url());
     QString tempurl= KURL::encode_string(tempname);
@@ -346,7 +308,7 @@ void KVerbosApp::saveProperties(KConfig *_cfg)
 
 void KVerbosApp::readProperties(KConfig* _cfg)
 {
-  QString filename = _cfg->readEntry("filename", "");
+  QString filename = _cfg->readPathEntry("filename");
   KURL url(filename);
   bool modified = _cfg->readBoolEntry("modified", false);
   if(modified)
@@ -427,7 +389,7 @@ void KVerbosApp::slotFileOpen()
   else
   {
     KURL url=KFileDialog::getOpenURL(QString::null,
-        i18n("*|All files"), this, i18n("Open File"));
+        i18n("*|All Files"), this, i18n("Open File"));
     if(!url.isEmpty())
     {
       doc->openDocument(url);
@@ -502,7 +464,7 @@ void KVerbosApp::slotFileSaveAs()
   slotStatusMsg(i18n("Saving file with a new filename..."));
 
   KURL url=KFileDialog::getSaveURL(QDir::currentDirPath(),
-        i18n("*|All files"), this, i18n("Save As"));
+        i18n("*|All Files"), this, i18n("Save As"));
   if(!url.isEmpty())
   {
     doc->saveDocument(url);
@@ -577,41 +539,6 @@ void KVerbosApp::slotEditPaste()
   slotStatusMsg(i18n("Ready."));
 }
 
-void KVerbosApp::slotViewToolBar()
-{
-  slotStatusMsg(i18n("Toggling toolbar..."));
-  ///////////////////////////////////////////////////////////////////
-  // turn Toolbar on or off
-  if(!viewToolBar->isChecked())
-  {
-    toolBar("mainToolBar")->hide();
-  }
-  else
-  {
-    toolBar("mainToolBar")->show();
-  }
-
-  slotStatusMsg(i18n("Ready."));
-}
-
-void KVerbosApp::slotViewStatusBar()
-{
-  slotStatusMsg(i18n("Toggle the statusbar..."));
-  ///////////////////////////////////////////////////////////////////
-  //turn Statusbar on or off
-  if(!viewStatusBar->isChecked())
-  {
-    statusBar()->hide();
-  }
-  else
-  {
-    statusBar()->show();
-  }
-
-  slotStatusMsg(i18n("Ready."));
-}
-
-
 void KVerbosApp::slotStatusMsg(const QString &text)
 {
   ///////////////////////////////////////////////////////////////////
@@ -625,7 +552,7 @@ void KVerbosApp::slotStatusVerbMsg(int n)
 {
   QString s;
   s.setNum(n,10);
-  s = i18n("number of verbs: ") + s;
+  s = i18n("Number of verbs: ") + s;
   statusBar()->changeItem(s, ID_VERBS_MSG);
 }
 
@@ -634,7 +561,7 @@ void KVerbosApp::slotStatusTrainedMsg(int n)
 {
   QString s;
   s.setNum(n,10);
-  s = i18n("trained: ") + s;
+  s = i18n("Trained: ") + s;
   statusBar()->changeItem(s, ID_TRAINED_MSG);
 }
 
@@ -643,7 +570,7 @@ void KVerbosApp::slotStatusCorrectMsg(int n)
 {
   QString s;
   s.setNum(n,10);
-  s = i18n("correct: ") + s;
+  s = i18n("Correct: ") + s;
   statusBar()->changeItem(s, ID_CORRECT_MSG);
 }
 
@@ -810,7 +737,7 @@ void KVerbosApp::slotSettingsUsername()
 	if (dlg.exec())
 	{
 		QString n = dlg.text().simplifyWhiteSpace();
-		if (n!="")
+		if (!n.isEmpty())
 		{
 			statusBar()->changeItem(i18n("user: ") + n, ID_USERNAME_MSG);
 			doc->setNewUser(n);
