@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: TenseOptPage.cpp,v 1.12 2002/07/21 05:12:04 binner Exp $
+    $Id: TenseOptPage.cpp,v 1.13 2003/07/17 12:48:20 binner Exp $
 
                    user tense options dialog page
 
@@ -15,51 +15,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: TenseOptPage.cpp,v $
-    Revision 1.12  2002/07/21 05:12:04  binner
-    Use KLineEditDlg and QInputDialog.
-
-    Revision 1.11  2002/04/22 19:12:15  binner
-    CVS_SILENT Capitalisation fixes.
-
-    Revision 1.10  2002/04/12 10:09:55  coolo
-    replacing tons of these (for gcc 3):
-    -      queryList.erase(&queryList[i], &queryList[i+1]);
-    +      queryList.erase(queryList.begin() + i);
-
-    Revision 1.9  2002/01/27 07:17:47  binner
-    CVS_SILENT Fixed capitalisation.
-
-    Revision 1.8  2001/12/26 15:11:08  mueller
-    CVSSILINT: fixincludes
-
-    Revision 1.7  2001/11/11 12:52:26  arnold
-    fixed some strings for i18n purposes
-
-    Revision 1.6  2001/11/10 22:27:55  arnold
-    removed compatibility for kde1
-
-    Revision 1.5  2001/10/21 15:22:00  arnold
-    replaced qtarch dialog files by qtdesigner
-
-    Revision 1.4  2001/10/17 21:41:15  waba
-    Cleanup & port to Qt3, QTableView -> QTable
-    TODO:
-    * Fix actions that work on selections
-    * Fix sorting
-    * Fix language-menu
-
-    Revision 1.3  2001/10/13 21:14:27  arnold
-    tested and fixed changes from previous cvs updatecd
-
-    Revision 1.2  2001/10/13 11:45:29  coolo
-    includemocs and other smaller cleanups. I tried to fix it, but as it's still
-    qt2 I can't test :(
-
-    Revision 1.1  2001/10/05 15:38:38  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************/
 
 /***************************************************************************
