@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: EntryDlg.cpp,v 1.24 2002/07/21 04:27:09 binner Exp $
+    $Id: EntryDlg.cpp,v 1.26 2003/06/21 14:31:23 deller Exp $
 
                    entry dialog for table cell contents
 
@@ -14,85 +14,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: EntryDlg.cpp,v $
-    Revision 1.24  2002/07/21 04:27:09  binner
-    CVS_SILENT Style guide fixes
-
-    Revision 1.23  2002/05/09 09:19:04  arnold
-    fixed missing entry dialog
-
-    Revision 1.22  2002/04/03 15:19:29  mlaurent
-    Fix header
-
-    Revision 1.21  2002/03/05 18:33:44  arnold
-    fix for display problems
-
-    Revision 1.20  2002/02/03 08:39:20  arnold
-    moved checkbox to options dialog
-
-    Revision 1.19  2002/01/27 07:17:47  binner
-    CVS_SILENT Fixed capitalisation.
-
-    Revision 1.18  2002/01/26 15:51:26  arnold
-    fixes due to new entry dialog
-
-    Revision 1.17  2002/01/21 21:13:27  arnold
-    calculate 'docked' size correctly
-
-    Revision 1.16  2002/01/21 18:56:17  arnold
-    fixed disabling of dialog pages
-
-    Revision 1.15  2002/01/20 11:41:01  arnold
-    fixed issues with modeless dialogs
-
-    Revision 1.14  2002/01/19 10:33:09  arnold
-    made entry dialog modeless
-
-    Revision 1.13  2001/12/30 12:12:57  arnold
-    fixed smart appending and editing
-
-    Revision 1.12  2001/12/26 15:11:29  mueller
-    CVSSILINT: fixincludes
-
-    Revision 1.11  2001/12/13 18:39:29  arnold
-    added phonetic alphabet stuff
-
-    Revision 1.10  2001/11/17 17:58:55  arnold
-    added inline editing of all columns
-
-    Revision 1.9  2001/11/10 22:28:25  arnold
-    removed compatibility for kde1
-
-    Revision 1.8  2001/11/10 21:13:00  arnold
-    removed icons and compatibilty for kde1
-
-    Revision 1.7  2001/11/09 14:18:49  arnold
-
-    fixed and improved some dialog pages
-
-    Revision 1.6  2001/11/09 10:40:05  arnold
-    removed ability to display a different font for each column
-
-    Revision 1.5  2001/10/30 14:10:32  arnold
-    added property 'multiple choice'
-
-    Revision 1.4  2001/10/23 18:15:39  arnold
-    replaced qtarch dialog files with qtdesigner
-
-    Revision 1.3  2001/10/17 21:41:15  waba
-    Cleanup & port to Qt3, QTableView -> QTable
-    TODO:
-    * Fix actions that work on selections
-    * Fix sorting
-    * Fix language-menu
-
-    Revision 1.2  2001/10/13 11:45:29  coolo
-    includemocs and other smaller cleanups. I tried to fix it, but as it's still
-    qt2 I can't test :(
-
-    Revision 1.1  2001/10/05 15:40:37  arnold
-    import of version 0.7.0pre8 to kde-edu
-
  ***************************************************************************
 
  ***************************************************************************
@@ -109,7 +30,7 @@
 #include <kvoctraindoc.h>
 #include <kmainwindow.h>
 
-#include <iostream.h>
+#include <iostream>
 
 #include <qpixmap.h>
 #include <qlayout.h>
@@ -191,9 +112,9 @@ EntryDlg::EntryDlg(
                                            i18n("Original &expression in %1:").arg(s), querymanager, active,
                                            ipafont);
           aux_page = new AuxInfoEntryPage (this, multi_sel, synonym, antonym, example, rem, paraphrase);
-          mc_page = new MCEntryPage (this, multi_sel, mc, 0, QString(_EntryDlg_MULTIPLECHOICE).local8Bit());
-          tense_page = new TenseEntryPage (this, multi_sel, con_prefix, conjugations, 0, QString(_EntryDlg_CONJUGATION).local8Bit());
-          adj_page = new AdjEntryPage (this, multi_sel, comp, 0, QString(_EntryDlg_ADJECTIVE).local8Bit());
+          mc_page = new MCEntryPage (this, multi_sel, mc, 0, "MultipleChoice");
+          tense_page = new TenseEntryPage (this, multi_sel, con_prefix, conjugations, 0, "Conjugation");
+          adj_page = new AdjEntryPage (this, multi_sel, comp, 0, "Comparison");
         }
         else {
           comm_page = new CommonEntryPage (this, doc, multi_sel, expr, lesson, lessonbox,
@@ -201,9 +122,9 @@ EntryDlg::EntryDlg(
                                            i18n("Translated &expression in %1:").arg(s), querymanager, active,
                                            ipafont);
           aux_page = new AuxInfoEntryPage (this, multi_sel, synonym, antonym, example, rem, paraphrase);
-          mc_page = new MCEntryPage (this, multi_sel, mc, 0, QString(_EntryDlg_MULTIPLECHOICE).local8Bit());
-          tense_page = new TenseEntryPage (this, multi_sel, con_prefix, conjugations, 0, QString(_EntryDlg_CONJUGATION).local8Bit());
-          adj_page = new AdjEntryPage (this, multi_sel, comp, 0, QString(_EntryDlg_ADJECTIVE).local8Bit());
+          mc_page = new MCEntryPage (this, multi_sel, mc, 0, "MultipleChoice");
+          tense_page = new TenseEntryPage (this, multi_sel, con_prefix, conjugations, 0, "Conjugation");
+          adj_page = new AdjEntryPage (this, multi_sel, comp, 0, "Comparison");
         }
 
         from_page = new FromToEntryPage (this, multi_sel, f_grd, f_qdate, f_qcount, f_bcount,
@@ -219,9 +140,9 @@ EntryDlg::EntryDlg(
 
         tabber->addTab( comm_page,  i18n( "Co&mmon" ));
         tabber->addTab( aux_page,   i18n( "&Additional" ));
-        tabber->addTab( mc_page,   _EntryDlg_MULTIPLECHOICE);
-        tabber->addTab( tense_page, _EntryDlg_CONJUGATION);
-        tabber->addTab( adj_page,   _EntryDlg_ADJECTIVE);
+        tabber->addTab( mc_page,    i18n( "&Multiple Choice" ));
+        tabber->addTab( tense_page, i18n( "Con&jugation"));
+        tabber->addTab( adj_page,   i18n( "Compar&ison"));
         tabber->addTab( from_page, i18n( "&From Original" ));
         tabber->addTab( to_page, i18n( "&To Original" ));
 
