@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: MySpinBox.cpp,v 1.3 2002/11/14 22:52:35 mueller Exp $
+    $Id: MySpinBox.cpp,v 1.4 2003/07/17 12:48:20 binner Exp $
 
          display special spinbox (only meaningful for QT2x)
 
@@ -15,21 +15,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: MySpinBox.cpp,v $
-    Revision 1.3  2002/11/14 22:52:35  mueller
-    compiler warning fixes
-
-    Revision 1.2  2001/10/17 21:41:15  waba
-    Cleanup & port to Qt3, QTableView -> QTable
-    TODO:
-    * Fix actions that work on selections
-    * Fix sorting
-    * Fix language-menu
-
-    Revision 1.1  2001/10/05 15:40:37  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************/
 
 /***************************************************************************
