@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: blockall.cpp,v 1.1.6.1 2003/07/16 19:09:14 mueller Exp $
+    $Id: blockall.cpp,v 1.3 2003/07/26 18:52:51 mueller Exp $
 
                      dummy validator which blocks all
 
@@ -14,14 +14,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: blockall.cpp,v $
-    Revision 1.1.6.1  2003/07/16 19:09:14  mueller
-    fix compilation (gcc 3.4+)
-
-    Revision 1.1  2001/10/05 15:40:37  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************/
 
 /***************************************************************************
