@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kva_header.cpp,v 1.18 2002/05/09 09:48:55 arnold Exp $
+    $Id: kva_header.cpp,v 1.20 2003/06/21 14:31:22 deller Exp $
 
                      header buttons part of kvoctrain
 
@@ -15,68 +15,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: kva_header.cpp,v $
-    Revision 1.18  2002/05/09 09:48:55  arnold
-    fixed i18n issue
-
-    Revision 1.17  2002/04/23 12:47:52  binner
-    CVS_SILENT Capitalisation fixes.
-
-    Revision 1.16  2002/04/20 12:55:48  binner
-    CVS_SILENT Capitalisation fixes.
-
-    Revision 1.15  2002/01/19 11:04:02  mhunter
-    CVS_SILENT Corrected typographical errors
-
-    Revision 1.14  2002/01/18 04:40:08  waba
-    Remove linbreaks from messageboxes.
-    Use KMessageBox.
-
-    Revision 1.13  2002/01/04 17:28:51  arnold
-    fixed resuming a query
-
-    Revision 1.12  2001/12/29 10:39:46  arnold
-    merged fixes from POST-branch
-
-    Revision 1.11  2001/12/24 14:28:44  arnold
-    fixed sorting
-
-    Revision 1.10  2001/12/01 11:28:13  arnold
-    fixed flickering in query dialogs
-
-    Revision 1.9  2001/11/20 01:38:03  jsinger
-    Proofreading changes for grammar and spelling. No functional changes.
-
-    Revision 1.8  2001/11/11 12:51:45  arnold
-    fixed some strings for i18n purposes
-
-    Revision 1.7  2001/11/10 22:27:08  arnold
-    removed compatibility for kde1
-
-    Revision 1.6  2001/11/10 21:11:57  arnold
-    removed icons and compatibilty for kde1
-
-    Revision 1.5  2001/11/09 10:39:25  arnold
-    removed ability to display a different font for each column
-
-    Revision 1.4  2001/10/28 10:15:46  arnold
-    quick 'n dirty fixes for new query dialogs
-
-    Revision 1.3  2001/10/20 00:58:26  waba
-    * Selection fixes
-    * Compile fixes
-
-    Revision 1.2  2001/10/17 21:41:15  waba
-    Cleanup & port to Qt3, QTableView -> QTable
-    TODO:
-    * Fix actions that work on selections
-    * Fix sorting
-    * Fix language-menu
-
-    Revision 1.1  2001/10/05 15:36:34  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************/
 
 /************x***************************************************************
@@ -88,13 +26,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#define SORT_ALPHA  i18n("&Sort alphabetically")
-#define SORT_NUM    i18n("Sort by &index")
-
-#ifdef __ONLY_TO_BE_SEEN_BY_XGETTEXT
-   SORT_ALPHA
-   SORT_NUM
-#else
+#define SORT_ALPHA  I18N_NOOP("&Sort alphabetically")
+#define SORT_NUM    I18N_NOOP("Sort by &index")
 
 #include "kvoctrain.h"
 #include "query-dialogs/QueryDlgBase.h"
@@ -119,8 +52,8 @@ void kvoctrainApp::slotHeaderMenu(int header, int x, int y) /*FOLD00*/
 
   if (header == KV_COL_LESS) {
     header_m = new QPopupMenu();
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/sort_alpha.xpm")), SORT_ALPHA, (header << 16) | IDH_SORT_COL_ALPHA);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/sort_num.xpm")), SORT_NUM, (header << 16) | IDH_SORT_COL_NUM);
+    header_m->insertItem(QPixmap(locate("data", "kvoctrain/sort_alpha.xpm")), i18n(SORT_ALPHA), (header << 16) | IDH_SORT_COL_ALPHA);
+    header_m->insertItem(QPixmap(locate("data", "kvoctrain/sort_num.xpm")), i18n(SORT_NUM), (header << 16) | IDH_SORT_COL_NUM);
 
     connect (header_m, SIGNAL(activated(int)), this, SLOT(slotHeaderCallBack(int)));
     connect (header_m, SIGNAL(highlighted(int)), this, SLOT(slotHeaderStatus(int)));
@@ -179,7 +112,7 @@ void kvoctrainApp::slotHeaderMenu(int header, int x, int y) /*FOLD00*/
     header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-exmp.xpm")), i18n("E&xamples"), (header << 16) | IDH_START_EXAMPLE);
     header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-para.xpm")), i18n("&Paraphrase"), (header << 16) | IDH_START_PARAPHRASE);
     header_m->insertSeparator();
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/sort_alpha.xpm")), SORT_ALPHA, (header+KV_EXTRA_COLS << 16) | IDH_SORT_COL_ALPHA);
+    header_m->insertItem(QPixmap(locate("data", "kvoctrain/sort_alpha.xpm")), i18n(SORT_ALPHA), (header+KV_EXTRA_COLS << 16) | IDH_SORT_COL_ALPHA);
     header_m->insertItem(QPixmap(locate("data", "kvoctrain/flags.xpm")), i18n("Set &Language"), langs_m, (2 << 16) | IDH_NULL);
     header_m->insertSeparator();
     header_m->insertItem(QPixmap(locate("data", "kvoctrain/reset.xpm")), i18n("Reset &Grades"), (header << 16) | IDH_RESET_GRADE);
@@ -241,7 +174,7 @@ void kvoctrainApp::slotHeaderMenu(int header, int x, int y) /*FOLD00*/
     connect (multiple_m, SIGNAL(highlighted(int)), this, SLOT(slotHeaderStatus(int)));
 
     header_m->insertSeparator();
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/sort_alpha.xpm")), SORT_ALPHA, (header+KV_EXTRA_COLS << 16) | IDH_SORT_COL_ALPHA);
+    header_m->insertItem(QPixmap(locate("data", "kvoctrain/sort_alpha.xpm")), i18n(SORT_ALPHA), (header+KV_EXTRA_COLS << 16) | IDH_SORT_COL_ALPHA);
     header_m->insertItem(QPixmap(locate("data", "kvoctrain/flags.xpm")), i18n("Set &Language"), langs_m, (2 << 16) | IDH_NULL);
   }
 
@@ -638,4 +571,3 @@ void kvoctrainApp::slotHeaderCallBack (int header_and_cmd) /*FOLD00*/
 }
 
 
-#endif // __ONLY_TO_BE_SEEN_BY_XGETTEXT
