@@ -1,123 +1,20 @@
 /***************************************************************************
 
-    $Id: kva_init.cpp,v 1.31 2002/10/23 18:31:10 asserhal Exp $
+    $Id: kva_init.cpp,v 1.34.2.1 2004/04/14 16:24:06 binner Exp $
 
                    initialisation part of kvoctrain
 
     -----------------------------------------------------------------------
 
     begin                : Thu Mar 11 20:50:53 MET 1999
-                                           
+
     copyright            : (C) 1999-2001 Ewald Arnold
                            (C) 2001 The KDE-EDU team
-                         
-    email                : kvoctrain@ewald-arnold.de                                    
+
+    email                : kvoctrain@ewald-arnold.de
 
     -----------------------------------------------------------------------
 
-    $Log: kva_init.cpp,v $
-    Revision 1.31  2002/10/23 18:31:10  asserhal
-    Corrected i18n
-
-    Revision 1.30  2002/09/17 20:24:59  binner
-    CVS_SILENT Style guide fix, use "cvslastchange" or X-WebCVS header line to view
-
-    Revision 1.29  2002/07/21 04:27:08  binner
-    CVS_SILENT Style guide fixes
-
-    Revision 1.28  2002/04/19 09:12:10  arnold
-    xml structure now more conforming
-
-    Revision 1.27  2002/04/16 17:54:09  binner
-    Capitalisation fixes.
-
-    Revision 1.26  2002/03/13 09:25:42  staikos
-    Don't crash on exit
-
-    Initialise the KMainWindow constructor
-
-    Revision 1.25  2002/01/27 07:17:44  binner
-    CVS_SILENT Fixed capitalisation.
-
-    Revision 1.24  2002/01/19 10:33:08  arnold
-    made entry dialog modeless
-
-    Revision 1.23  2002/01/13 14:34:04  mueller
-    make it compile again
-
-    Revision 1.22  2002/01/02 11:38:27  arnold
-    fixed displaying of modified doc
-
-    Revision 1.21  2001/12/30 10:36:04  arnold
-    fixed and improved dialogs
-
-    Revision 1.20  2001/12/26 15:10:25  mueller
-    CVSSILINT: fixincludes
-
-    Revision 1.19  2001/12/24 13:01:03  arnold
-    fixed crash with recent files menu
-
-    Revision 1.18  2001/12/13 18:39:09  arnold
-    added phonetic alphabet stuff
-
-    Revision 1.17  2001/12/05 09:07:21  howells
-    Fix some spelling/gramattical errors, and make the program fit better with the style guide
-
-    Revision 1.16  2001/12/01 11:28:13  arnold
-    fixed flickering in query dialogs
-
-    Revision 1.15  2001/11/25 11:11:02  arnold
-    switch for inline edit, splitted kv_resource.h
-
-    Revision 1.14  2001/11/18 12:28:25  arnold
-    provided menu entry for example files
-
-    Revision 1.13  2001/11/16 19:50:06  arnold
-    added submenu to set language to main menu
-
-    Revision 1.12  2001/11/16 18:52:59  arnold
-    added possibility to disable expressions
-
-    Revision 1.11  2001/11/11 12:51:45  arnold
-    fixed some strings for i18n purposes
-
-    Revision 1.10  2001/11/10 22:27:08  arnold
-    removed compatibility for kde1
-
-    Revision 1.9  2001/11/10 21:16:47  arnold
-    removed icons and compatibility for kde1
-
-    Revision 1.8  2001/11/10 21:11:57  arnold
-    removed icons and compatibilty for kde1
-
-    Revision 1.7  2001/11/02 10:17:48  arnold
-    fixed colum resizing and diplaying of grade colors
-
-    Revision 1.6  2001/10/28 10:15:46  arnold
-    quick 'n dirty fixes for new query dialogs
-
-    Revision 1.5  2001/10/22 06:38:58  waba
-    Show a cute little marker to indicate marked entries.
-    (Instead of using a bold type-face)
-
-    Revision 1.4  2001/10/20 12:06:28  arnold
-    removed aboutdialog files
-
-    Revision 1.3  2001/10/20 00:58:26  waba
-    * Selection fixes
-    * Compile fixes
-
-    Revision 1.2  2001/10/17 21:41:15  waba
-    Cleanup & port to Qt3, QTableView -> QTable
-    TODO:
-    * Fix actions that work on selections
-    * Fix sorting
-    * Fix language-menu
-
-    Revision 1.1  2001/10/05 15:36:34  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************/
 
 /*** content ************************************************************************
@@ -125,7 +22,7 @@
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
+ *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
 
@@ -199,7 +96,7 @@ kvoctrainApp::kvoctrainApp(QWidget *parent, const char *name)
   view->getTable()->updateContents(cr, cc);
 
   ///////////////////////////////////////////////////////////////////
-  // enable bars dependend on config file setups
+  // enable bars dependent on config file setups
   if (!bViewToolbar)
     toolBar()->hide();
   if (!bViewStatusbar)
@@ -272,7 +169,7 @@ void kvoctrainApp::initMenuBar()
 
   file_menu->insertSeparator();
   file_menu->insertItem(KGlobal::iconLoader()->loadIcon("filesave", KIcon::Small) ,i18n("&Save"), ID_FILE_SAVE );
-  file_menu->insertItem(i18n("Save &As..."), ID_FILE_SAVE_AS );
+  file_menu->insertItem(SmallIcon("filesaveas"),i18n("Save &As..."), ID_FILE_SAVE_AS );
   file_menu->insertSeparator();
   file_menu->insertItem(KGlobal::iconLoader()->loadIcon("exit", KIcon::Small), i18n("&Quit"), ID_FILE_QUIT );
 
@@ -326,8 +223,8 @@ void kvoctrainApp::initMenuBar()
   voc_menu->insertItem(QPixmap(locate("data", "kvoctrain/delete-col.xpm")), i18n("&Remove Language"), remove_m, ID_REMOVE_LANG);
 
   voc_menu->insertSeparator();
-  voc_menu->insertItem(i18n("Document &Properties..."), ID_DOC_PROPS );
-  voc_menu->insertItem(i18n("Lan&guage Properties..."), ID_DOC_PROPS_LANG );
+  voc_menu->insertItem(i18n("Document &Properties"), ID_DOC_PROPS );
+  voc_menu->insertItem(i18n("Lan&guage Properties"), ID_DOC_PROPS_LANG );
   connect( voc_menu, SIGNAL(aboutToShow()), this, SLOT(aboutToShowVocabulary()));
 
   ///////////////////////////////////////////////////////////////////
@@ -430,7 +327,7 @@ void kvoctrainApp::initToolBar()
   // add functionality for new created toolbars in:
   // enableCommand, disableCommand, in the menuBar() and an additional function slotViewToolbar_1
   // for that also create a bViewToolbar_1 and a KConfig entry (see Constructor).
-  // Also update resource values and commands 
+  // Also update resource values and commands
 
 
   ///////////////////////////////////////////////////////////////////
@@ -488,7 +385,7 @@ void kvoctrainApp::clearStatusBar()
 
 
 void kvoctrainApp::initView(const QString &name)
-{ 
+{
   view = 0;
 
   pdlg = new ProgressDlg (QString(), QString(),
