@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kva_io.cpp,v 1.32 2002/05/09 09:17:20 arnold Exp $
+    $Id: kva_io.cpp,v 1.36 2003/07/17 12:26:55 binner Exp $
 
                          i/o part of kvoctrain
 
@@ -14,115 +14,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: kva_io.cpp,v $
-    Revision 1.32  2002/05/09 09:17:20  arnold
-    fixed problem with filename handling
-
-    Revision 1.31  2002/04/20 12:55:48  binner
-    CVS_SILENT Capitalisation fixes.
-
-    Revision 1.30  2002/04/12 10:09:55  coolo
-    replacing tons of these (for gcc 3):
-    -      queryList.erase(&queryList[i], &queryList[i+1]);
-    +      queryList.erase(queryList.begin() + i);
-
-    Revision 1.29  2002/03/14 02:00:52  waba
-    * A bunch of fixes for saving files on exit.
-    * Use saveAs-dialog to save modified examples
-    * Don't add examples to list of recent document.
-
-    Revision 1.28  2002/03/13 08:22:29  waba
-    * Use KRandomSequence instead of rand()
-    * Fix crash in "resume query".
-
-    Revision 1.27  2002/02/08 19:24:02  arnold
-    fixed sleeping dialog, applied patches for Tru64 unix
-
-    Revision 1.26  2002/01/30 17:26:55  arnold
-    added some tooltips, fixed capitalisation
-
-    Revision 1.25  2002/01/30 09:57:06  binner
-    "All files" is "*", not "*.*"
-
-    Revision 1.24  2002/01/27 07:17:44  binner
-    CVS_SILENT Fixed capitalisation.
-
-    Revision 1.23  2002/01/23 18:17:40  arnold
-    fix for multiple selections
-
-    Revision 1.22  2002/01/21 18:56:14  arnold
-    fixed disabling of dialog pages
-
-    Revision 1.21  2002/01/18 04:40:08  waba
-    Remove linbreaks from messageboxes.
-    Use KMessageBox.
-
-    Revision 1.20  2002/01/02 11:38:27  arnold
-    fixed displaying of modified doc
-
-    Revision 1.19  2001/12/30 10:36:04  arnold
-    fixed and improved dialogs
-
-    Revision 1.18  2001/12/26 15:10:25  mueller
-    CVSSILINT: fixincludes
-
-    Revision 1.17  2001/12/24 13:02:23  arnold
-    fixed crash with recent files menu
-
-    Revision 1.16  2001/12/14 16:05:49  arnold
-    fixed handling of table font
-
-    Revision 1.15  2001/12/07 19:20:50  arnold
-    included multiple choice fields and false friend into query
-
-    Revision 1.14  2001/11/25 11:11:02  arnold
-    switch for inline edit, splitted kv_resource.h
-
-    Revision 1.13  2001/11/20 01:38:03  jsinger
-    Proofreading changes for grammar and spelling. No functional changes.
-
-    Revision 1.12  2001/11/19 20:05:16  arnold
-    fixed warning message
-
-    Revision 1.11  2001/11/18 12:28:25  arnold
-    provided menu entry for example files
-
-    Revision 1.10  2001/11/17 17:58:22  arnold
-    added inline editing of all columns
-
-    Revision 1.9  2001/11/16 18:52:59  arnold
-    added possibility to disable expressions
-
-    Revision 1.8  2001/11/11 12:51:45  arnold
-    fixed some strings for i18n purposes
-
-    Revision 1.7  2001/11/10 22:27:08  arnold
-    removed compatibility for kde1
-
-    Revision 1.6  2001/11/09 10:39:25  arnold
-    removed ability to display a different font for each column
-
-    Revision 1.5  2001/10/21 15:28:43  arnold
-    removed all the 'charset' stuff
-
-    Revision 1.4  2001/10/20 00:58:26  waba
-    * Selection fixes
-    * Compile fixes
-
-    Revision 1.3  2001/10/17 21:41:15  waba
-    Cleanup & port to Qt3, QTableView -> QTable
-    TODO:
-    * Fix actions that work on selections
-    * Fix sorting
-    * Fix language-menu
-
-    Revision 1.2  2001/10/12 19:28:13  arnold
-    removed references to obsolete binary format
-
-    Revision 1.1  2001/10/05 15:36:34  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************/
 
 /***************************************************************************
@@ -157,24 +48,19 @@
 #include "UsageManager.h"
 #include "common-dialogs/ProgressDlg.h"
 
-#define PATTERN_ALL  "*"            "|All files (*)\n"
-#define PATTERN_ML   "*." KVTML_EXT   "|KVocTrain Markup (*.kvtml)\n"
-#define PATTERN_LEX  "*." VT5_LEX_EXT "|Vocabulary Trainer 5.0 (*.lex)\n"
-#define PATTERN_VL   "*." KVL_EXT     "|KVoclearn (*.vl)\n"
-#define PATTERN_QVO  "*." QVOCAB_EXT  "|QVocab (*.qvo)\n"
-#define PATTERN_CSV  "*." CSV_EXT     "|Text (*.csv)\n"
-#define PATTERN_VCB  "*." VCB_EXT     "|Vocabbox (*.vocab)\n"
+#define PATTERN_ALL  I18N_NOOP("*|All Files (*)\n")
+#define PATTERN_ML   I18N_NOOP("*.kvtml|KVocTrain Markup (*.kvtml)\n")
+#define PATTERN_LEX  I18N_NOOP("*.lex|Vocabulary Trainer 5.0 (*.lex)\n")
+#define PATTERN_VL   I18N_NOOP("*.vl|KVoclearn (*.vl)\n")
+#define PATTERN_QVO  I18N_NOOP("*.qvo|QVocab (*.qvo)\n")
+#define PATTERN_CSV  I18N_NOOP("*.csv|Text (*.csv)\n")
+#define PATTERN_VCB  I18N_NOOP("*.vocab|Vocabbox (*.vocab)\n")
 
 // we can read these
-#define FILTER_RPATTERN  PATTERN_ML PATTERN_VCB PATTERN_CSV PATTERN_LEX PATTERN_ALL
+#define FILTER_RPATTERN  i18n(PATTERN_ML)+i18n(PATTERN_VCB)+i18n(PATTERN_CSV)+i18n(PATTERN_LEX)+i18n(PATTERN_ALL)
 
 // we can write these
-#define FILTER_WPATTERN  PATTERN_ML PATTERN_VCB PATTERN_CSV PATTERN_LEX PATTERN_ALL
-
-#ifdef __ONLY_TO_BE_SEEN_BY_XGETTEXT
- i18n(FILTER_RPATTERN)
- i18n(FILTER_WPATTERN)
-#endif
+#define FILTER_WPATTERN  i18n(PATTERN_ML)+i18n(PATTERN_VCB)+i18n(PATTERN_CSV)+i18n(PATTERN_LEX)+i18n(PATTERN_ALL)
 
 
 // helper that gets a file name (it only differs in the caption of the dialog)
@@ -890,7 +776,7 @@ void kvoctrainApp::slotSaveSelection ()
     saveDocProps(&seldoc);
 
     prepareProgressBar();
-    seldoc.saveAs(this, name, QString (i18n ("Part of: ")) +doc->getTitle(),
+    seldoc.saveAs(this, name, i18n ("Part of: ") + doc->getTitle(),
                 kvoctrainDoc::automatic, separator, &paste_order);
     removeProgressBar();
   }
