@@ -1,193 +1,20 @@
 /***************************************************************************
 
-    $Id: kvoctrain.cpp,v 1.54 2002/11/14 22:52:35 mueller Exp $
+    $Id: kvoctrain.cpp,v 1.59.2.1 2004/04/14 16:24:06 binner Exp $
 
                       main part of kvoctrain
 
     -----------------------------------------------------------------------
 
     begin                : Thu Mar 11 20:50:53 MET 1999
-                                           
+
     copyright            : (C) 1999-2001 Ewald Arnold
                            (C) 2001 The KDE-EDU team
-                         
-    email                : kvoctrain@ewald-arnold.de                                    
+
+    email                : kvoctrain@ewald-arnold.de
 
     -----------------------------------------------------------------------
 
-    $Log: kvoctrain.cpp,v $
-    Revision 1.54  2002/11/14 22:52:35  mueller
-    compiler warning fixes
-
-    Revision 1.53  2002/10/23 18:16:48  asserhal
-    Changed tr to i18n
-
-    Revision 1.52  2002/09/17 20:24:59  binner
-    CVS_SILENT Style guide fix, use "cvslastchange" or X-WebCVS header line to view
-
-    Revision 1.51  2002/07/23 12:39:19  binner
-    CVS_SILENT Style guide fixes
-
-    Revision 1.50  2002/07/21 05:12:04  binner
-    Use KLineEditDlg and QInputDialog.
-
-    Revision 1.49  2002/07/21 04:27:08  binner
-    CVS_SILENT Style guide fixes
-
-    Revision 1.48  2002/05/09 09:48:55  arnold
-    fixed i18n issue
-
-    Revision 1.47  2002/05/09 09:18:27  arnold
-    fixed missing entry dialog
-
-    Revision 1.46  2002/04/20 12:55:48  binner
-    CVS_SILENT Capitalisation fixes.
-
-    Revision 1.45  2002/04/12 10:09:55  coolo
-    replacing tons of these (for gcc 3):
-    -      queryList.erase(&queryList[i], &queryList[i+1]);
-    +      queryList.erase(queryList.begin() + i);
-
-    Revision 1.44  2002/03/13 08:22:29  waba
-    * Use KRandomSequence instead of rand()
-    * Fix crash in "resume query".
-
-    Revision 1.43  2002/02/08 19:24:02  arnold
-    fixed sleeping dialog, applied patches for Tru64 unix
-
-    Revision 1.42  2002/02/03 08:39:19  arnold
-    moved checkbox to options dialog
-
-    Revision 1.41  2002/01/30 17:26:55  arnold
-    added some tooltips, fixed capitalisation
-
-    Revision 1.40  2002/01/27 07:17:44  binner
-    CVS_SILENT Fixed capitalisation.
-
-    Revision 1.39  2002/01/26 15:51:08  arnold
-    fixes due to new entry dialog
-
-    Revision 1.38  2002/01/21 18:56:15  arnold
-    fixed disabling of dialog pages
-
-    Revision 1.37  2002/01/20 11:41:01  arnold
-    fixed issues with modeless dialogs
-
-    Revision 1.36  2002/01/19 11:24:47  mhunter
-    CVS_SILENT Corrected typographical errors
-
-    Revision 1.35  2002/01/19 10:33:08  arnold
-    made entry dialog modeless
-
-    Revision 1.34  2002/01/18 04:40:08  waba
-    Remove linbreaks from messageboxes.
-    Use KMessageBox.
-
-    Revision 1.33  2002/01/07 17:54:37  arnold
-    fixed typo
-
-    Revision 1.32  2002/01/07 17:19:44  arnold
-    fixed i18n() issues
-
-    Revision 1.31  2001/12/30 18:41:38  arnold
-    improved reaction upon 'empty' query selections
-
-    Revision 1.30  2001/12/30 12:12:32  arnold
-    fixed smart appending and editing
-
-    Revision 1.29  2001/12/29 15:49:11  arnold
-    fixed kmessagebox calls
-
-    Revision 1.28  2001/12/29 10:40:03  arnold
-    merged fixes from POST-branch
-
-    Revision 1.27  2001/12/26 13:15:21  arnold
-    fixed header buttons and kbd handling
-
-    Revision 1.26  2001/12/16 16:51:25  arnold
-    fixed keyboard handling in main view
-
-    Revision 1.25  2001/12/13 18:39:09  arnold
-    added phonetic alphabet stuff
-
-    Revision 1.24  2001/12/01 11:28:13  arnold
-    fixed flickering in query dialogs
-
-    Revision 1.23  2001/11/25 11:11:02  arnold
-    switch for inline edit, splitted kv_resource.h
-
-    Revision 1.22  2001/11/20 01:38:03  jsinger
-    Proofreading changes for grammar and spelling. No functional changes.
-
-    Revision 1.21  2001/11/18 12:28:25  arnold
-    provided menu entry for example files
-
-    Revision 1.20  2001/11/17 17:58:22  arnold
-    added inline editing of all columns
-
-    Revision 1.19  2001/11/16 19:50:06  arnold
-    added submenu to set language to main menu
-
-    Revision 1.18  2001/11/16 18:52:59  arnold
-    added possibility to disable expressions
-
-    Revision 1.17  2001/11/11 12:51:45  arnold
-    fixed some strings for i18n purposes
-
-    Revision 1.16  2001/11/10 22:59:17  arnold
-    fixed some bugs
-
-    Revision 1.15  2001/11/10 22:27:08  arnold
-    removed compatibility for kde1
-
-    Revision 1.14  2001/11/10 21:11:57  arnold
-    removed icons and compatibilty for kde1
-
-    Revision 1.13  2001/11/09 14:18:00  arnold
-    fixed and improved some dialog pages
-
-    Revision 1.12  2001/11/09 10:39:25  arnold
-    removed ability to display a different font for each column
-
-    Revision 1.11  2001/11/02 10:17:48  arnold
-    fixed colum resizing and diplaying of grade colors
-
-    Revision 1.10  2001/11/01 11:26:12  arnold
-    fixed some editing actions
-
-    Revision 1.9  2001/10/31 19:10:56  arnold
-    fixed generation of i18n messages
-
-    Revision 1.8  2001/10/30 14:09:46  arnold
-    added property 'multiple choice'
-
-    Revision 1.7  2001/10/21 15:28:43  arnold
-    removed all the 'charset' stuff
-
-    Revision 1.6  2001/10/20 12:08:37  arnold
-    removed aboutdialog files
-
-    Revision 1.5  2001/10/20 00:58:26  waba
-    * Selection fixes
-    * Compile fixes
-
-    Revision 1.4  2001/10/17 21:41:15  waba
-    Cleanup & port to Qt3, QTableView -> QTable
-    TODO:
-    * Fix actions that work on selections
-    * Fix sorting
-    * Fix language-menu
-
-    Revision 1.3  2001/10/13 11:45:29  coolo
-    includemocs and other smaller cleanups. I tried to fix it, but as it's still
-    qt2 I can't test :(
-
-    Revision 1.2  2001/10/12 20:55:31  arnold
-    added include file
-
-    Revision 1.1  2001/10/05 15:36:34  arnold
-    import of version 0.7.0pre8 to kde-edu
-
  ***************************************************************************/
 
 /***************************************************************************
@@ -195,20 +22,10 @@
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
+ *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
 
-#define S_RESUME_QUERY i18n("Resume &Query")
-#define S_RESUME_MULTI i18n("Resume &Multiple Choice")
-
-#ifdef __ONLY_TO_BE_SEEN_BY_XGETTEXT
-
-  S_RESUME_QUERY
-  S_RESUME_MULTI
-
-#else
-
 #include <kstatusbar.h>
 #include <klineedit.h>
 #include <kcombobox.h>
@@ -301,12 +118,12 @@ void kvoctrainApp::slotCurrentCellChanged(int row, int col)
   kvoctrainExpr *expr = doc->getEntry(row);
 
   if (rem_label != 0)
-    rem_label->setText (QString(i18n  (PREFIX_Remark))+expr->getRemark (col));
+    rem_label->setText( i18n(PREFIX_Remark) + expr->getRemark (col) );
   if (pron_label != 0)
-    pron_label->setText (QString(i18n (PREFIX_Pronunce))+expr->getPronunce (col));
+    pron_label->setText( i18n(PREFIX_Pronunce) + expr->getPronunce (col) );
   if (type_label != 0)
-    type_label->setText (QString(i18n (PREFIX_Type))
-            +QueryManager::typeStr(expr->getType (col)));
+    type_label->setText( i18n(PREFIX_Type)
+            + QueryManager::typeStr(expr->getType(col)) );
 
   if (entryDlg != 0) {
     if (col == 0)
@@ -380,7 +197,7 @@ void kvoctrainApp::commitEntryDlg(bool force)
                    i18n("The entry dialog contains unsaved changes.\n"
                         "Do you want to apply or discard your changes?"),
                    kapp->makeStdCaption("Unsaved Changes"),
-                   i18n("&Apply"), i18n("&Discard"))) {
+                   KStdGuiItem::apply(), KStdGuiItem::discard())) {
         return;
      }
    }
@@ -915,7 +732,7 @@ void kvoctrainApp::slotRemoveRow()
   else {
     if(KMessageBox::Yes == KMessageBox::questionYesNo(this,
                   i18n("Do you really want to delete the selected range?\n"),
-                  kapp->makeStdCaption("")));
+                  kapp->makeStdCaption("")))
     {
       RowTable *table = view->getTable();
 
@@ -1216,7 +1033,7 @@ void kvoctrainApp::slotGeneralOptionsPage(int index)
 
         int idx = langset.indexShortId(sid);
         QString pm = "";
-        QString lid = sid;;
+        QString lid = sid;
         if  (idx >= 0) {
           lid = langset.longId(idx);
           pm = langset.PixMapFile(idx);
@@ -1472,18 +1289,15 @@ void kvoctrainApp::aboutToShowLearn()
   }
 
   learn_menu->insertSeparator();
-  learn_menu->insertItem(QPixmap(locate("data", "kvoctrain/run-query.xpm")), S_RESUME_QUERY, ID_RESUME_QUERY );
-  learn_menu->insertItem(QPixmap(locate("data", "kvoctrain/run-multi.xpm")), S_RESUME_MULTI, ID_RESUME_MULTIPLE );
+  learn_menu->insertItem(QPixmap(locate("data", "kvoctrain/run-query.xpm")), i18n("Resume &Query"), ID_RESUME_QUERY );
+  learn_menu->insertItem(QPixmap(locate("data", "kvoctrain/run-multi.xpm")), i18n("Resume &Multiple Choice"), ID_RESUME_MULTIPLE );
+
   learn_menu->setItemEnabled(ID_RESUME_QUERY,  query_num != 0);
   learn_menu->setItemEnabled(ID_RESUME_MULTIPLE,  query_num != 0);
 
 }
 
 
-#undef  S_RESUME_QUERY
-#undef  S_RESUME_MULTI
-
-
 void kvoctrainApp::aboutToShowOptions()
 {
   opts_menu->setItemEnabled(ID_SAVE_OPTIONS, !autosaveopts);
@@ -1688,5 +1502,4 @@ void kvoctrainApp::statusCallback(int id_){
 
 #include "kvoctrain.moc"
 
-#endif // __ONLY_TO_BE_SEEN_BY_XGETTEXT
 
