@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: QueryManager.cpp,v 1.11 2002/07/21 04:27:09 binner Exp $
+    $Id: QueryManager.cpp,v 1.15 2003/11/01 09:30:18 arnold Exp $
 
                              manage queries
 
@@ -14,43 +14,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: QueryManager.cpp,v $
-    Revision 1.11  2002/07/21 04:27:09  binner
-    CVS_SILENT Style guide fixes
-
-    Revision 1.10  2002/04/12 10:09:56  coolo
-    replacing tons of these (for gcc 3):
-    -      queryList.erase(&queryList[i], &queryList[i+1]);
-    +      queryList.erase(queryList.begin() + i);
-
-    Revision 1.9  2002/02/08 19:24:03  arnold
-    fixed sleeping dialog, applied patches for Tru64 unix
-
-    Revision 1.8  2001/12/29 10:40:24  arnold
-    merged fixes from POST-branch
-
-    Revision 1.7  2001/12/26 15:11:53  mueller
-    CVSSILINT: fixincludes
-
-    Revision 1.6  2001/12/01 11:28:34  arnold
-    fixed flickering in query dialogs
-
-    Revision 1.5  2001/11/25 11:11:23  arnold
-    switch for inline edit, splitted kv_resource.h
-
-    Revision 1.4  2001/11/16 18:53:21  arnold
-    added possibility to disable expressions
-
-    Revision 1.3  2001/11/10 22:28:46  arnold
-    removed compatibility for kde1
-
-    Revision 1.2  2001/11/09 14:19:13  arnold
-    fixed and improved some dialog pages
-
-    Revision 1.1  2001/10/05 15:42:01  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************/
 
 /***************************************************************************
@@ -69,9 +32,9 @@
 #include <kapplication.h>
 #include <kconfig.h>
 
-#include <kvoctraindoc.h>
+#include "kvoctraindoc.h"
 
-#include <iostream.h>
+#include <iostream>
 #include <vector>
 using namespace std;
 
@@ -138,7 +101,7 @@ QString QueryManager::getSubType (QString type)
     return type;
   }
   else
-    return "";
+    return QString::null;
 }
 
 
@@ -164,7 +127,7 @@ QueryManager::QueryManager ()
   dateitem = 0;
   queryitem = 0;
   baditem = 0;
-  typeitem = "";
+  typeitem = QString::null;
   gradeitem = 0;
   lessonitems.clear();
 }
@@ -183,8 +146,8 @@ void QueryManager::loadConfig (KConfig *config)
   baditem = (CompType) config->readNumEntry(CFG_QM_BAD_ITEM, 0);
   queryitem = (CompType) config->readNumEntry(CFG_QM_QUERY_ITEM, 0);
   gradeitem = (CompType) config->readNumEntry(CFG_QM_GRADE_ITEM, 0);
-  typeitem = config->readEntry(CFG_QM_TYPE_ITEM, "");
-//  setLessonItemStr (config->readEntry(CFG_QM_LESSON_ITEM, ""));
+  typeitem = config->readEntry(CFG_QM_TYPE_ITEM);
+//  setLessonItemStr (config->readEntry(CFG_QM_LESSON_ITEM));
 
   blockItems.clear();
   blockItems.push_back(config->readNumEntry(CFG_QM_BLOCK_ITEM"1", 1 *      60*60*24));
@@ -192,17 +155,17 @@ void QueryManager::loadConfig (KConfig *config)
   blockItems.push_back(config->readNumEntry(CFG_QM_BLOCK_ITEM"3", 4 *      60*60*24));
   blockItems.push_back(config->readNumEntry(CFG_QM_BLOCK_ITEM"4", 1 *    7*60*60*24));
   blockItems.push_back(config->readNumEntry(CFG_QM_BLOCK_ITEM"5", 2 *    7*60*60*24));
-  blockItems.push_back(config->readNumEntry(CFG_QM_BLOCK_ITEM"6", 1 * 30*7*60*60*24));
-  blockItems.push_back(config->readNumEntry(CFG_QM_BLOCK_ITEM"7", 2 * 30*7*60*60*24));
+  blockItems.push_back(config->readNumEntry(CFG_QM_BLOCK_ITEM"6", 1 *   30*60*60*24));
+  blockItems.push_back(config->readNumEntry(CFG_QM_BLOCK_ITEM"7", 2 *   30*60*60*24));
 
   expireItems.clear();
   expireItems.push_back(config->readNumEntry(CFG_QM_EXPIRE_ITEM"1", 2 *      60*60*24));
   expireItems.push_back(config->readNumEntry(CFG_QM_EXPIRE_ITEM"2", 4 *      60*60*24));
   expireItems.push_back(config->readNumEntry(CFG_QM_EXPIRE_ITEM"3", 1 *    7*60*60*24));
   expireItems.push_back(config->readNumEntry(CFG_QM_EXPIRE_ITEM"4", 2 *    7*60*60*24));
-  expireItems.push_back(config->readNumEntry(CFG_QM_EXPIRE_ITEM"5", 1 * 30*7*60*60*24));
-  expireItems.push_back(config->readNumEntry(CFG_QM_EXPIRE_ITEM"6", 2 * 30*7*60*60*24));
-  expireItems.push_back(config->readNumEntry(CFG_QM_EXPIRE_ITEM"7", 4 * 30*7*60*60*24));
+  expireItems.push_back(config->readNumEntry(CFG_QM_EXPIRE_ITEM"5", 1 *   30*60*60*24));
+  expireItems.push_back(config->readNumEntry(CFG_QM_EXPIRE_ITEM"6", 2 *   30*60*60*24));
+  expireItems.push_back(config->readNumEntry(CFG_QM_EXPIRE_ITEM"7", 4 *   30*60*60*24));
 }
 
 
@@ -542,15 +505,15 @@ QString QueryManager::compStr (CompType type)
 QString QueryManager::gradeStr (int i)
 {
   switch (i) {
-    case KV_NORM_GRADE:    return KV_NORM_TEXT; break;
-    case KV_LEV1_GRADE:    return KV_LEV1_TEXT; break;
-    case KV_LEV2_GRADE:    return KV_LEV2_TEXT; break;
-    case KV_LEV3_GRADE:    return KV_LEV3_TEXT; break;
-    case KV_LEV4_GRADE:    return KV_LEV4_TEXT; break;
-    case KV_LEV5_GRADE:    return KV_LEV5_TEXT; break;
-    case KV_LEV6_GRADE:    return KV_LEV6_TEXT; break;
-    case KV_LEV7_GRADE:    return KV_LEV7_TEXT; break;
-    default:               return KV_LEV1_TEXT; break;
+    case KV_NORM_GRADE:    return i18n(KV_NORM_TEXT); break;
+    case KV_LEV1_GRADE:    return i18n(KV_LEV1_TEXT); break;
+    case KV_LEV2_GRADE:    return i18n(KV_LEV2_TEXT); break;
+    case KV_LEV3_GRADE:    return i18n(KV_LEV3_TEXT); break;
+    case KV_LEV4_GRADE:    return i18n(KV_LEV4_TEXT); break;
+    case KV_LEV5_GRADE:    return i18n(KV_LEV5_TEXT); break;
+    case KV_LEV6_GRADE:    return i18n(KV_LEV6_TEXT); break;
+    case KV_LEV7_GRADE:    return i18n(KV_LEV7_TEXT); break;
+    default:               return i18n(KV_LEV1_TEXT); break;
   }
 }
 
@@ -586,7 +549,7 @@ QString QueryManager::typeStr (const QString id)
     if (i >= 0 && i < (int) userTypes.size() )
       return userTypes[i];
     else
-      return "";
+      return QString::null;
   }
   else {
     t_type_rel *type = InternalTypeRelations;
@@ -596,7 +559,7 @@ QString QueryManager::typeStr (const QString id)
       type++;
     }
   }
-  return "";
+  return QString::null;
 }
 
 
