@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: QueryManager.h,v 1.3 2002/02/08 19:24:03 arnold Exp $
+    $Id: QueryManager.h,v 1.4 2003/07/17 12:48:21 binner Exp $
 
                             manage queries
 
@@ -15,17 +15,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: QueryManager.h,v $
-    Revision 1.3  2002/02/08 19:24:03  arnold
-    fixed sleeping dialog, applied patches for Tru64 unix
-
-    Revision 1.2  2001/11/09 14:19:13  arnold
-    fixed and improved some dialog pages
-
-    Revision 1.1  2001/10/05 15:42:01  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************/
 
 /***************************************************************************
