@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvd_rh_kvtml.cpp,v 1.10 2002/02/08 19:24:03 arnold Exp $
+    $Id: kvd_rh_kvtml.cpp,v 1.14 2003/09/20 16:47:35 binner Exp $
 
                    read header parts of a kvtml document
 
@@ -14,39 +14,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: kvd_rh_kvtml.cpp,v $
-    Revision 1.10  2002/02/08 19:24:03  arnold
-    fixed sleeping dialog, applied patches for Tru64 unix
-
-    Revision 1.9  2002/01/18 04:40:09  waba
-    Remove linbreaks from messageboxes.
-    Use KMessageBox.
-
-    Revision 1.8  2001/12/26 15:11:53  mueller
-    CVSSILINT: fixincludes
-
-    Revision 1.7  2001/11/25 11:11:23  arnold
-    switch for inline edit, splitted kv_resource.h
-
-    Revision 1.6  2001/11/20 01:38:26  jsinger
-    Proofreading changes for grammar and spelling. No functional changes.
-
-    Revision 1.5  2001/11/10 22:28:46  arnold
-    removed compatibility for kde1
-
-    Revision 1.4  2001/11/09 15:52:20  arnold
-    fixed error messages for correct i18n use
-
-    Revision 1.3  2001/10/21 16:19:32  arnold
-    fixed detecting for latin1 or utf8
-
-    Revision 1.2  2001/10/21 15:29:27  arnold
-    removed all the 'charset' stuff
-
-    Revision 1.1  2001/10/05 15:42:01  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************/
 
 /***************************************************************************
@@ -54,7 +21,7 @@
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
+ *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
 
@@ -308,7 +275,7 @@ bool kvoctrainDoc::loadArticleKvtMl (XmlElement elem, XmlReader& xml)
     if (elem.tag () == KV_ARTICLE_GRP) {
       if (inEntry) {
         errorKvtMl (xml.lineNumber(),
-                    i18n("unallowed occurence of tag <%1>").arg(KV_ARTICLE_GRP));
+                    i18n("disallowed occurrence of tag <%1>").arg(KV_ARTICLE_GRP));
         return false;
       }
       if (! elem.isEndTag ()) {
@@ -323,7 +290,7 @@ bool kvoctrainDoc::loadArticleKvtMl (XmlElement elem, XmlReader& xml)
       if (! elem.isEndTag ()) {
         if (inEntry) {
           errorKvtMl (xml.lineNumber(),
-                      i18n("unallowed occurence of tag <%1>").arg(KV_ART_ENTRY));
+                      i18n("disallowed occurrence of tag <%1>").arg(KV_ART_ENTRY));
           return false;
         }
         inEntry = true;
@@ -332,12 +299,12 @@ bool kvoctrainDoc::loadArticleKvtMl (XmlElement elem, XmlReader& xml)
           return false;
 
         if ((int)langs.size() <= count) {      // first entry
-          if (lang == "")                      // no definition in first entry
+          if (lang.isEmpty())                      // no definition in first entry
             lang = "original";
           langs.push_back(lang);
         }
         else {
-          if (lang != langs[count] && lang != "") {  // different originals ?
+          if (lang != langs[count] && !lang.isEmpty()) {  // different originals ?
             errorKvtMl (xml.lineNumber(),
                         i18n("ambiguous definition of language code"));
             return false;
@@ -361,7 +328,7 @@ bool kvoctrainDoc::loadArticleKvtMl (XmlElement elem, XmlReader& xml)
     else if (elem.tag () == KV_ART_FD && !elem.isEndTag() ) {
       if (!inEntry) {
         errorKvtMl (xml.lineNumber(),
-                    i18n("unallowed occurence of tag <%1>").arg(KV_ART_FD));
+                    i18n("disallowed occurrence of tag <%1>").arg(KV_ART_FD));
         return false;
       }
       if (!extract_simple_tag (KV_ART_FD, xml, elem, fem_def))
@@ -370,7 +337,7 @@ bool kvoctrainDoc::loadArticleKvtMl (XmlElement elem, XmlReader& xml)
     else if (elem.tag () == KV_ART_FI && !elem.isEndTag() ) {
       if (!inEntry) {
         errorKvtMl (xml.lineNumber(),
-                    i18n("unallowed occurence of tag <%1>").arg(KV_ART_FI));
+                    i18n("disallowed occurrence of tag <%1>").arg(KV_ART_FI));
         return false;
       }
       if (!extract_simple_tag (KV_ART_FI, xml, elem, fem_indef))
@@ -379,7 +346,7 @@ bool kvoctrainDoc::loadArticleKvtMl (XmlElement elem, XmlReader& xml)
     else if (elem.tag () == KV_ART_MD && !elem.isEndTag() ) {
       if (!inEntry) {
         errorKvtMl (xml.lineNumber(),
-                    i18n("unallowed occurence of tag <%1>").arg(KV_ART_MD));
+                    i18n("disallowed occurrence of tag <%1>").arg(KV_ART_MD));
         return false;
       }
       if (!extract_simple_tag (KV_ART_MD, xml, elem, mal_def))
@@ -388,7 +355,7 @@ bool kvoctrainDoc::loadArticleKvtMl (XmlElement elem, XmlReader& xml)
     else if (elem.tag () == KV_ART_MI && !elem.isEndTag() ) {
       if (!inEntry) {
         errorKvtMl (xml.lineNumber(),
-                    i18n("unallowed occurence of tag <%1>").arg(KV_ART_MI));
+                    i18n("disallowed occurrence of tag <%1>").arg(KV_ART_MI));
         return false;
       }
       if (!extract_simple_tag (KV_ART_MI, xml, elem, mal_indef))
@@ -397,7 +364,7 @@ bool kvoctrainDoc::loadArticleKvtMl (XmlElement elem, XmlReader& xml)
     else if (elem.tag () == KV_ART_ND && !elem.isEndTag() ) {
       if (!inEntry) {
         errorKvtMl (xml.lineNumber(),
-                    i18n("unallowed occurence of tag <%1>").arg(KV_ART_ND));
+                    i18n("disallowed occurrence of tag <%1>").arg(KV_ART_ND));
         return false;
       }
       if (!extract_simple_tag (KV_ART_ND, xml, elem, nat_def))
@@ -406,7 +373,7 @@ bool kvoctrainDoc::loadArticleKvtMl (XmlElement elem, XmlReader& xml)
     else if (elem.tag () == KV_ART_NI && !elem.isEndTag() ) {
       if (!inEntry) {
         errorKvtMl (xml.lineNumber(),
-                    i18n("unallowed occurence of tag <%1>").arg(KV_ART_NI));
+                    i18n("disallowed occurrence of tag <%1>").arg(KV_ART_NI));
         return false;
       }
       if (!extract_simple_tag (KV_ART_NI, xml, elem, nat_indef))
@@ -542,7 +509,7 @@ bool kvoctrainDoc::loadConjugKvtMl (vector<Conjugation> &curr_conjug,
     if (elem.tag () == KV_CONJUG_GRP) {
       if (inEntry) {
         errorKvtMl (xml.lineNumber(),
-                    i18n("unallowed occurence of tag <%1>").arg(KV_CONJUG_GRP));
+                    i18n("disallowed occurrence of tag <%1>").arg(KV_CONJUG_GRP));
         return false;
       }
       if (! elem.isEndTag ()) {
@@ -557,7 +524,7 @@ bool kvoctrainDoc::loadConjugKvtMl (vector<Conjugation> &curr_conjug,
       if (! elem.isEndTag ()) {
         if (inEntry) {
           errorKvtMl (xml.lineNumber(),
-                      i18n("unallowed occurence of tag <%1>").arg(entry_tag));
+                      i18n("disallowed occurrence of tag <%1>").arg(entry_tag));
           return false;
         }
         inEntry = true;
@@ -568,12 +535,12 @@ bool kvoctrainDoc::loadConjugKvtMl (vector<Conjugation> &curr_conjug,
             return false;
 
           if ((int)langs.size() <= count) { // first entry
-            if (lang == "")                 // no definition in first entry
+            if (lang.isEmpty())                 // no definition in first entry
               lang = "original";
             langs.push_back(lang);
           }
           else {
-            if (lang != langs[count] && lang != "") {  // different originals ?
+            if (lang != langs[count] && !lang.isEmpty()) {  // different originals ?
               errorKvtMl (xml.lineNumber(),
                           i18n("ambiguous definition of language code"));
               return false;
@@ -635,7 +602,7 @@ bool kvoctrainDoc::loadConjugKvtMl (vector<Conjugation> &curr_conjug,
     else if (elem.tag () == KV_CON_P1S && !elem.isEndTag() ) {
       if (!inEntry) {
         errorKvtMl (xml.lineNumber(),
-                    i18n("unallowed occurence of tag <%1>").arg(KV_CON_P1S));
+                    i18n("disallowed occurrence of tag <%1>").arg(KV_CON_P1S));
         return false;
       }
       if (!extract_simple_tag (KV_CON_P1S, xml, elem, pers1_sing) )
@@ -644,7 +611,7 @@ bool kvoctrainDoc::loadConjugKvtMl (vector<Conjugation> &curr_conjug,
     else if (elem.tag () == KV_CON_P2S && !elem.isEndTag() ) {
       if (!inEntry) {
         errorKvtMl (xml.lineNumber(),
-                    i18n("unallowed occurence of tag <%1>").arg(KV_CON_P2S));
+                    i18n("disallowed occurrence of tag <%1>").arg(KV_CON_P2S));
         return false;
       }
       if (!extract_simple_tag (KV_CON_P2S, xml, elem, pers2_sing))
@@ -653,7 +620,7 @@ bool kvoctrainDoc::loadConjugKvtMl (vector<Conjugation> &curr_conjug,
     else if (elem.tag () == KV_CON_P3SF && !elem.isEndTag() ) {
       if (!inEntry) {
         errorKvtMl (xml.lineNumber(),
-                    i18n("unallowed occurence of tag <%1>").arg(KV_CON_P3SF));
+                    i18n("disallowed occurrence of tag <%1>").arg(KV_CON_P3SF));
         return false;
       }
 
@@ -667,7 +634,7 @@ bool kvoctrainDoc::loadConjugKvtMl (vector<Conjugation> &curr_conjug,
     else if (elem.tag () == KV_CON_P3SM && !elem.isEndTag() ) {
       if (!inEntry) {
         errorKvtMl (xml.lineNumber(),
-                    i18n("unallowed occurence of tag <%1>").arg(KV_CON_P3SM));
+                    i18n("disallowed occurrence of tag <%1>").arg(KV_CON_P3SM));
         return false;
       }
       if (!extract_simple_tag (KV_CON_P3SM, xml, elem, pers3_m_sing))
@@ -676,7 +643,7 @@ bool kvoctrainDoc::loadConjugKvtMl (vector<Conjugation> &curr_conjug,
     else if (elem.tag () == KV_CON_P3SN && !elem.isEndTag() ) {
       if (!inEntry) {
         errorKvtMl (xml.lineNumber(),
-                    i18n("unallowed occurence of tag <%1>").arg(KV_CON_P3SN));
+                    i18n("disallowed occurrence of tag <%1>").arg(KV_CON_P3SN));
         return false;
       }
       if (!extract_simple_tag (KV_CON_P3SN, xml, elem, pers3_n_sing))
@@ -685,7 +652,7 @@ bool kvoctrainDoc::loadConjugKvtMl (vector<Conjugation> &curr_conjug,
     else if (elem.tag () == KV_CON_P1P && !elem.isEndTag() ) {
       if (!inEntry) {
         errorKvtMl (xml.lineNumber(),
-                    i18n("unallowed occurence of tag <%1>").arg(KV_CON_P1P));
+                    i18n("disallowed occurrence of tag <%1>").arg(KV_CON_P1P));
         return false;
       }
       if (!extract_simple_tag (KV_CON_P1P, xml, elem, pers1_plur) )
@@ -694,7 +661,7 @@ bool kvoctrainDoc::loadConjugKvtMl (vector<Conjugation> &curr_conjug,
     else if (elem.tag () == KV_CON_P2P && !elem.isEndTag() ) {
       if (!inEntry) {
         errorKvtMl (xml.lineNumber(),
-                    i18n("unallowed occurence of tag <%1>").arg(KV_CON_P2P));
+                    i18n("disallowed occurrence of tag <%1>").arg(KV_CON_P2P));
         return false;
       }
       if (!extract_simple_tag (KV_CON_P2P, xml, elem, pers2_plur))
@@ -703,7 +670,7 @@ bool kvoctrainDoc::loadConjugKvtMl (vector<Conjugation> &curr_conjug,
     else if (elem.tag () == KV_CON_P3PF && !elem.isEndTag() ) {
       if (!inEntry) {
         errorKvtMl (xml.lineNumber(),
-                    i18n("unallowed occurence of tag <%1>").arg(KV_CON_P3PF));
+                    i18n("disallowed occurrence of tag <%1>").arg(KV_CON_P3PF));
         return false;
       }
 
@@ -717,7 +684,7 @@ bool kvoctrainDoc::loadConjugKvtMl (vector<Conjugation> &curr_conjug,
     else if (elem.tag () == KV_CON_P3PM && !elem.isEndTag() ) {
       if (!inEntry) {
         errorKvtMl (xml.lineNumber(),
-                    i18n("unallowed occurence of tag <%1>").arg(KV_CON_P3PM));
+                    i18n("disallowed occurrence of tag <%1>").arg(KV_CON_P3PM));
         return false;
       }
       if (!extract_simple_tag (KV_CON_P3PM, xml, elem, pers3_m_plur))
@@ -726,7 +693,7 @@ bool kvoctrainDoc::loadConjugKvtMl (vector<Conjugation> &curr_conjug,
     else if (elem.tag () == KV_CON_P3PN && !elem.isEndTag() ) {
       if (!inEntry) {
         errorKvtMl (xml.lineNumber(),
-                    i18n("unallowed occurence of tag <%1>").arg(KV_CON_P3PN));
+                    i18n("disallowed occurrence of tag <%1>").arg(KV_CON_P3PN));
         return false;
       }
       if (!extract_simple_tag (KV_CON_P3PN, xml, elem, pers3_n_plur))
