@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvoctraincore.h,v 1.6 2002/04/19 09:12:11 arnold Exp $
+    $Id: kvoctraincore.h,v 1.7 2003/07/17 12:48:21 binner Exp $
 
                      common #defines for kvoctrain core
 
@@ -15,22 +15,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: kvoctraincore.h,v $
-    Revision 1.6  2002/04/19 09:12:11  arnold
-    xml structure now more conforming
-
-    Revision 1.5  2002/01/19 10:33:10  arnold
-    made entry dialog modeless
-
-    Revision 1.4  2001/12/22 09:01:46  arnold
-    fixed version string handling
-
-    Revision 1.3  2001/12/13 18:39:52  arnold
-    added phonetic alphabet stuff
-
-    Revision 1.2  2001/11/25 11:11:23  arnold
-    switch for inline edit, splitted kv_resource.h
-
  ***************************************************************************/
 
 /***************************************************************************
