@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvoctraindoc.cpp,v 1.24 2002/05/09 09:20:10 arnold Exp $
+    $Id: kvoctraindoc.cpp,v 1.25 2003/06/21 14:31:23 deller Exp $
 
                    maintain a kvoctrain document
 
@@ -15,88 +15,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: kvoctraindoc.cpp,v $
-    Revision 1.24  2002/05/09 09:20:10  arnold
-    fixed problem with filename handling
-
-    Revision 1.23  2002/04/22 19:12:15  binner
-    CVS_SILENT Capitalisation fixes.
-
-    Revision 1.22  2002/04/12 10:09:56  coolo
-    replacing tons of these (for gcc 3):
-    -      queryList.erase(&queryList[i], &queryList[i+1]);
-    +      queryList.erase(queryList.begin() + i);
-
-    Revision 1.21  2002/04/10 12:26:19  mueller
-    we aint need no values.h here
-
-    Revision 1.20  2002/03/20 23:00:03  mueller
-    it seems to compile fine without strstream.h
-
-    Revision 1.19  2002/02/24 09:35:31  arnold
-    fixed crash when saving without perms
-
-    Revision 1.18  2002/02/18 15:41:03  arnold
-    fixed crash when loading non-existent file
-
-    Revision 1.17  2002/02/08 19:24:03  arnold
-    fixed sleeping dialog, applied patches for Tru64 unix
-
-    Revision 1.16  2002/01/19 11:24:52  mhunter
-    CVS_SILENT Corrected typographical errors
-
-    Revision 1.15  2002/01/18 04:40:09  waba
-    Remove linbreaks from messageboxes.
-    Use KMessageBox.
-
-    Revision 1.14  2001/12/26 15:11:53  mueller
-    CVSSILINT: fixincludes
-
-    Revision 1.13  2001/12/22 09:02:55  arnold
-    fixed version string handling
-
-    Revision 1.12  2001/12/16 16:11:55  howells
-    Don't break
-
-    Revision 1.11  2001/11/25 11:11:23  arnold
-    switch for inline edit, splitted kv_resource.h
-
-    Revision 1.10  2001/11/24 11:45:03  arnold
-    added std prefix for clean namespace
-
-    Revision 1.9  2001/11/19 20:05:39  arnold
-    fixed warning message
-
-    Revision 1.8  2001/11/19 19:43:24  arnold
-    fixed crash while sorting (though I dont understand it)
-
-    Revision 1.7  2001/11/17 17:59:20  arnold
-    added inline editing of all columns
-
-    Revision 1.6  2001/11/10 22:28:46  arnold
-    removed compatibility for kde1
-
-    Revision 1.5  2001/11/02 17:50:44  arnold
-    fixed sorting basically
-
-    Revision 1.4  2001/10/21 15:29:27  arnold
-    removed all the 'charset' stuff
-
-    Revision 1.3  2001/10/17 21:41:15  waba
-    Cleanup & port to Qt3, QTableView -> QTable
-    TODO:
-    * Fix actions that work on selections
-    * Fix sorting
-    * Fix language-menu
-
-    Revision 1.2  2001/10/13 11:45:29  coolo
-    includemocs and other smaller cleanups. I tried to fix it, but as it's still
-    qt2 I can't test :(
-
-    Revision 1.1  2001/10/05 15:42:01  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************/
 
 /***************************************************************************
