@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvoctraindoc.h,v 1.9 2002/03/14 02:00:53 waba Exp $
+    $Id: kvoctraindoc.h,v 1.10 2003/07/17 12:48:21 binner Exp $
 
                          maintain a kvoctrain document
 
@@ -15,41 +15,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: kvoctraindoc.h,v $
-    Revision 1.9  2002/03/14 02:00:53  waba
-    * A bunch of fixes for saving files on exit.
-    * Use saveAs-dialog to save modified examples
-    * Don't add examples to list of recent document.
-
-    Revision 1.8  2002/02/08 19:24:03  arnold
-    fixed sleeping dialog, applied patches for Tru64 unix
-
-    Revision 1.7  2001/12/13 18:39:52  arnold
-    added phonetic alphabet stuff
-
-    Revision 1.6  2001/11/16 18:53:21  arnold
-    added possibility to disacble expressions
-
-    Revision 1.5  2001/11/02 17:50:44  arnold
-    fixed sorting basically
-
-    Revision 1.4  2001/10/30 14:10:53  arnold
-    added property 'multiple choice'
-
-    Revision 1.3  2001/10/21 15:29:27  arnold
-    removed all the 'charset' stuff
-
-    Revision 1.2  2001/10/17 21:41:15  waba
-    Cleanup & port to Qt3, QTableView -> QTable
-    TODO:
-    * Fix actions that work on selections
-    * Fix sorting
-    * Fix language-menu
-
-    Revision 1.1  2001/10/05 15:42:01  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************
 
  ***************************************************************************
@@ -57,7 +22,7 @@
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
+ *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
 
