@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvoctrainexpr.cpp,v 1.12 2002/04/12 10:09:56 coolo Exp $
+    $Id: kvoctrainexpr.cpp,v 1.13 2003/07/17 12:48:21 binner Exp $
 
                    maintain a kvoctrain expression
 
@@ -16,51 +16,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: kvoctrainexpr.cpp,v $
-    Revision 1.12  2002/04/12 10:09:56  coolo
-    replacing tons of these (for gcc 3):
-    -      queryList.erase(&queryList[i], &queryList[i+1]);
-    +      queryList.erase(queryList.begin() + i);
-
-    Revision 1.11  2002/02/08 19:24:03  arnold
-    fixed sleeping dialog, applied patches for Tru64 unix
-
-    Revision 1.10  2001/12/26 15:11:53  mueller
-    CVSSILINT: fixincludes
-
-    Revision 1.9  2001/11/25 11:11:23  arnold
-    switch for inline edit, splitted kv_resource.h
-
-    Revision 1.8  2001/11/16 18:53:21  arnold
-    added possibility to disable expressions
-
-    Revision 1.7  2001/11/10 22:28:46  arnold
-    removed compatibility for kde1
-
-    Revision 1.6  2001/11/09 10:40:25  arnold
-    removed ability to display a different font for each column
-
-    Revision 1.5  2001/11/02 10:18:31  arnold
-    fixed colum resizing and diplaying of grade colors
-
-    Revision 1.4  2001/10/30 14:10:53  arnold
-    added property 'multiple choice'
-
-    Revision 1.3  2001/10/22 06:39:21  waba
-    Show a cute little marker to indicate marked entries.
-    (Instead of using a bold type-face)
-
-    Revision 1.2  2001/10/17 21:41:15  waba
-    Cleanup & port to Qt3, QTableView -> QTable
-    TODO:
-    * Fix actions that work on selections
-    * Fix sorting
-    * Fix language-menu
-
-    Revision 1.1  2001/10/05 15:42:01  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************/
 
 /***************************************************************************
@@ -68,7 +23,7 @@
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
+ *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
 
