@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvoctrainexpr.h,v 1.10 2002/07/21 04:27:09 binner Exp $
+    $Id: kvoctrainexpr.h,v 1.13 2003/07/17 12:48:21 binner Exp $
 
                          maintain a kvoctrain expression
 
@@ -14,43 +14,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: kvoctrainexpr.h,v $
-    Revision 1.10  2002/07/21 04:27:09  binner
-    CVS_SILENT Style guide fixes
-
-    Revision 1.9  2002/02/08 19:24:03  arnold
-    fixed sleeping dialog, applied patches for Tru64 unix
-
-    Revision 1.8  2001/11/16 18:53:21  arnold
-    added possibility to disable expressions
-
-    Revision 1.7  2001/11/10 22:59:41  arnold
-    fixed some bugs
-
-    Revision 1.6  2001/11/10 22:28:46  arnold
-    removed compatibility for kde1
-
-    Revision 1.5  2001/11/09 10:40:26  arnold
-    removed ability to display a different font for each column
-
-    Revision 1.4  2001/10/30 14:10:53  arnold
-    added property 'multiple choice'
-
-    Revision 1.3  2001/10/22 06:39:21  waba
-    Show a cute little marker to indicate marked entries.
-    (Instead of using a bold type-face)
-
-    Revision 1.2  2001/10/17 21:41:15  waba
-    Cleanup & port to Qt3, QTableView -> QTable
-    TODO:
-    * Fix actions that work on selections
-    * Fix sorting
-    * Fix language-menu
-
-    Revision 1.1  2001/10/05 15:42:01  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************
 
  ***************************************************************************
@@ -70,46 +33,35 @@
 
 #define KV_NORM_GRADE      0       // not queried yet
 #define KV_NORM_COLOR      Qt::black
-#define KV_NORM_TEXT       i18n("Not Queried Yet")
+#define KV_NORM_TEXT       I18N_NOOP("Not Queried Yet")
 
 #define KV_LEV1_GRADE      1
 #define KV_LEV1_COLOR      Qt::red
-#define KV_LEV1_TEXT       i18n("Level 1")
+#define KV_LEV1_TEXT       I18N_NOOP("Level 1")
 
 #define KV_LEV2_GRADE      2
 #define KV_LEV2_COLOR      Qt::red
-#define KV_LEV2_TEXT       i18n("Level 2")
+#define KV_LEV2_TEXT       I18N_NOOP("Level 2")
 
 #define KV_LEV3_GRADE      3
 #define KV_LEV3_COLOR      Qt::red
-#define KV_LEV3_TEXT       i18n("Level 3")
+#define KV_LEV3_TEXT       I18N_NOOP("Level 3")
 
 #define KV_LEV4_GRADE      4
 #define KV_LEV4_COLOR      Qt::red
-#define KV_LEV4_TEXT       i18n("Level 4")
+#define KV_LEV4_TEXT       I18N_NOOP("Level 4")
 
 #define KV_LEV5_GRADE      5
 #define KV_LEV5_COLOR      Qt::green
-#define KV_LEV5_TEXT       i18n("Level 5")
+#define KV_LEV5_TEXT       I18N_NOOP("Level 5")
 
 #define KV_LEV6_GRADE      6
 #define KV_LEV6_COLOR      Qt::green
-#define KV_LEV6_TEXT       i18n("Level 6")
+#define KV_LEV6_TEXT       I18N_NOOP("Level 6")
 
 #define KV_LEV7_GRADE      7
 #define KV_LEV7_COLOR      Qt::green
-#define KV_LEV7_TEXT       i18n("Level 7")
-
-#ifdef __ONLY_TO_BE_SEEN_BY_XGETTEXT
-  KV_NORM_TEXT
-  KV_LEV1_TEXT
-  KV_LEV2_TEXT
-  KV_LEV3_TEXT
-  KV_LEV4_TEXT
-  KV_LEV5_TEXT
-  KV_LEV6_TEXT
-  KV_LEV7_TEXT
-#else
+#define KV_LEV7_TEXT       I18N_NOOP("Level 7")
 
 #include "langset.h"
 
@@ -124,8 +76,8 @@
 #include <qpixmap.h>
 # include <qnamespace.h>
 
-#include <GrammerManager.h>
-#include <MultipleChoice.h>
+#include "GrammerManager.h"
+#include "MultipleChoice.h"
 
 struct GradeCols {
    bool   use;
@@ -550,7 +502,5 @@ class kvoctrainExpr
   static QPixmap   *s_pm_inactive;
 };
 
-#endif  // ONLY XGETTEXT
-
 #endif // KVOCTRAINEXPR_H
 
