@@ -1,26 +1,12 @@
 /* -*- C++ -*-
 
-  $Id: XmlElement.h,v 1.2 2002/04/12 10:09:56 coolo Exp $
+  $Id: XmlElement.h,v 1.3 2003/07/17 12:48:22 binner Exp $
 
   This file is part of KIllustrator.
   Copyright (C) 1998 Kai-Uwe Sattler (kus@iti.cs.uni-magdeburg.de)
 
   modified for kvoctrain by Ewald Arnold kvoctrain@ewald-arnold.dein April 99
 
-  -----------------------------------------------------------------------
-
-  $Log: XmlElement.h,v $
-  Revision 1.2  2002/04/12 10:09:56  coolo
-  replacing tons of these (for gcc 3):
-  -      queryList.erase(&queryList[i], &queryList[i+1]);
-  +      queryList.erase(queryList.begin() + i);
-
-  Revision 1.1  2001/10/05 15:43:20  arnold
-  import of version 0.7.0pre8 to kde-edu
-
-
-  -----------------------------------------------------------------------
-
 */
 
 #ifndef XmlElement_h_
