@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: main.cpp,v 1.21 2002/11/14 22:52:35 mueller Exp $
+    $Id: main.cpp,v 1.24 2003/09/25 14:02:26 mlaurent Exp $
 
                         entry gate to kvoctrain
 
@@ -38,21 +38,19 @@ int main(int argc, char* argv[]) {
 static KCmdLineOptions options[] =
 {
   { I18N_NOOP("+[file]"),   I18N_NOOP("Document file to open."), 0 },
-  { 0, 0, 0}
+  KCmdLineLastOption
 };
 
-static const char *description =
-	I18N_NOOP("Vocabulary Trainer");
-
-static const char *version = KVOCTRAIN_VERSION_STRING;
+static const char description[] = I18N_NOOP("Vocabulary Trainer");
+static const char version[]     = KVOCTRAIN_VERSION_STRING;
 
   KAboutData aboutData("kvoctrain",
-                       "KVocTrain",
+                       I18N_NOOP("KVocTrain"),
                        version,
                        description,
                        KAboutData::License_GPL,
-                       "(c) 1999-2002\tEwald Arnold\n"
-                       "(c) 2001-2002\tThe KDE team\n",
+                       I18N_NOOP("(c) 1999-2002\tEwald Arnold\n"
+                       "(c) 2001-2002\tThe KDE team\n"),
                        I18N_NOOP("Helps you train your vocabulary"),
 		      "http://kvoctrain.sourceforge.net/",
                       "submit@bugs.kde.org");
@@ -108,5 +106,5 @@ static const char *version = KVOCTRAIN_VERSION_STRING;
     kva->show();
   }
   return app.exec();
-}  
- 
+}
+
