@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: MCQueryDlg.cpp,v 1.17 2002/11/14 22:52:35 mueller Exp $
+    $Id: MCQueryDlg.cpp,v 1.20 2003/11/18 23:39:48 kniederk Exp $
 
                     multiple choice query dialog
 
@@ -14,63 +14,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: MCQueryDlg.cpp,v $
-    Revision 1.17  2002/11/14 22:52:35  mueller
-    compiler warning fixes
-
-    Revision 1.16  2002/02/08 19:24:03  arnold
-    fixed sleeping dialog, applied patches for Tru64 unix
-
-    Revision 1.15  2002/01/20 11:41:02  arnold
-    fixed issues with modeless dialogs
-
-    Revision 1.14  2002/01/04 21:09:16  binner
-    CVS_SILENT Fixed capitalisation.
-
-    Revision 1.13  2001/12/26 15:12:38  mueller
-    CVSSILINT: fixincludes
-
-    Revision 1.12  2001/12/07 19:21:36  arnold
-    included multiple choice fields and false friend into query
-
-    Revision 1.11  2001/12/01 11:28:54  arnold
-    fixed flickering in query dialogs
-
-    Revision 1.10  2001/11/24 17:16:08  arnold
-    fixes for table view and query
-
-    Revision 1.9  2001/11/16 16:26:23  arnold
-    improved dialogs
-
-    Revision 1.8  2001/11/10 22:29:40  arnold
-    removed compatibility for kde1
-
-    Revision 1.7  2001/11/10 21:14:30  arnold
-    removed icons and compatibilty for kde1
-
-    Revision 1.6  2001/11/09 10:41:18  arnold
-    removed ability to display a different font for each column
-
-    Revision 1.5  2001/10/28 10:16:31  arnold
-    quick 'n dirty fixes for new query dialogs
-
-    Revision 1.4  2001/10/28 09:17:06  arnold
-    replaced qtarch dialog files with qtdesigner
-
-    Revision 1.3  2001/10/17 21:41:15  waba
-    Cleanup & port to Qt3, QTableView -> QTable
-    TODO:
-    * Fix actions that work on selections
-    * Fix sorting
-    * Fix language-menu
-
-    Revision 1.2  2001/10/13 11:45:29  coolo
-    includemocs and other smaller cleanups. I tried to fix it, but as it's still
-    qt2 I can't test :(
-
-    Revision 1.1  2001/10/05 15:45:05  arnold
-    import of version 0.7.0pre8 to kde-edu
-
  ***************************************************************************
 
  ***************************************************************************
@@ -115,6 +58,7 @@ MCQueryDlg::MCQueryDlg(
                    int q_cycle,
                    int q_num,
                    int q_start,
+		   QFont &font,
                    kvoctrainExpr *exp,
                    kvoctrainDoc  *doc,
                    int mqtime,
@@ -123,7 +67,7 @@ MCQueryDlg::MCQueryDlg(
                    QWidget *parent,
                    char *name)
 	: MCQueryDlgForm(parent, name, false),
-	  QueryDlgBase()
+	  QueryDlgBase(font)
 {
    transgroup->insert(rb_trans1);
    transgroup->insert(rb_trans2);
@@ -175,6 +119,7 @@ void MCQueryDlg::setQuery(QString org,
    showCounter = _show,
    timebar->setEnabled(showCounter);
    timelabel->setEnabled(showCounter);
+   orgField->setFont(word_font);
    orgField->setText (org);
    show_all->setDefault(true);
    QString s;
@@ -300,10 +245,15 @@ void MCQueryDlg::setQuery(QString org,
    button_ref[4].label->setEnabled(!strings[4].isEmpty() );
 
    button_ref[0].label->setText(strings[0]);
+   button_ref[0].label->setFont(word_font);
    button_ref[1].label->setText(strings[1]);
+   button_ref[1].label->setFont(word_font);
    button_ref[2].label->setText(strings[2]);
+   button_ref[2].label->setFont(word_font);
    button_ref[3].label->setText(strings[3]);
+   button_ref[3].label->setFont(word_font);
    button_ref[4].label->setText(strings[4]);
+   button_ref[4].label->setFont(word_font);
 
    rb_trans1->setChecked (false);
    rb_trans2->setChecked (false);
