@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: QueryDlgBase.cpp,v 1.7 2002/11/14 22:52:35 mueller Exp $
+    $Id: QueryDlgBase.cpp,v 1.10 2003/11/18 23:39:48 kniederk Exp $
 
                     base class for query dialogs
 
@@ -15,34 +15,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: QueryDlgBase.cpp,v $
-    Revision 1.7  2002/11/14 22:52:35  mueller
-    compiler warning fixes
-
-    Revision 1.6  2001/12/07 19:21:36  arnold
-    included multiple choice fields and false friend into query
-
-    Revision 1.5  2001/12/01 11:28:54  arnold
-    fixed flickering in query dialogs
-
-    Revision 1.4  2001/10/28 09:17:06  arnold
-    replaced qtarch dialog files with qtdesigner
-
-    Revision 1.3  2001/10/17 21:41:16  waba
-    Cleanup & port to Qt3, QTableView -> QTable
-    TODO:
-    * Fix actions that work on selections
-    * Fix sorting
-    * Fix language-menu
-
-    Revision 1.2  2001/10/13 11:45:29  coolo
-    includemocs and other smaller cleanups. I tried to fix it, but as it's still
-    qt2 I can't test :(
-
-    Revision 1.1  2001/10/05 15:45:05  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************
 
  ***************************************************************************
@@ -65,8 +37,9 @@
 
 #include <klocale.h>
 
-QueryDlgBase::QueryDlgBase ()
+QueryDlgBase::QueryDlgBase (QFont &font)
 {
+  word_font = font;
   kv_doc = 0;
   kv_exp = 0;
   type_timeout = kvq_notimeout;
@@ -113,22 +86,18 @@ bool QueryDlgBase::verifyField(QLineEdit *field, const QString &really)
   bool ret = false;
   if (smartCompare(really, field->text(), 0) ) {
     ret = true;
-    if (   known_pal.normal() != k_normal
-        || known_pal.inactive() != k_normal
+    if ( known_pal.inactive() != k_normal
         || known_pal.active() != k_normal) {
       // replace text colors
-      known_pal.setNormal(k_normal);
       known_pal.setActive(k_normal);
       known_pal.setInactive(k_normal);
       field->setPalette( known_pal );
     }
   }
   else
-    if (   unknown_pal.normal() != u_normal
-        || unknown_pal.inactive() != u_normal
+    if ( unknown_pal.inactive() != u_normal
         || unknown_pal.active() != u_normal) {
       // replace text colors
-      unknown_pal.setNormal(u_normal);
       unknown_pal.setActive(u_normal);
       unknown_pal.setInactive(u_normal);
       field->setPalette( unknown_pal );
@@ -147,10 +116,8 @@ void QueryDlgBase::resetField(QLineEdit *field)
   QPalette pal( field->palette());
   // replace text colors
 
-  if (   pal.normal() != normal
-      || pal.inactive() != normal
+  if ( pal.inactive() != normal
       || pal.active() != normal) {
-    pal.setNormal(normal);
     pal.setActive(normal);
     pal.setInactive(normal);
     field->setPalette( pal );
@@ -208,22 +175,18 @@ bool QueryDlgBase::verifyField(QMultiLineEdit *field, const QString &really,
 
   if (equal) {
     ret = true;
-    if (   known_pal.normal() != k_normal
-        || known_pal.inactive() != k_normal
+    if (known_pal.inactive() != k_normal
         || known_pal.active() != k_normal) {
       // replace text colors
-      known_pal.setNormal(k_normal);
       known_pal.setActive(k_normal);
       known_pal.setInactive(k_normal);
       field->setPalette( known_pal );
     }
   }
   else
-    if (   unknown_pal.normal() != u_normal
-        || unknown_pal.inactive() != u_normal
+    if ( unknown_pal.inactive() != u_normal
         || unknown_pal.active() != u_normal) {
       // replace text colors
-      unknown_pal.setNormal(u_normal);
       unknown_pal.setActive(u_normal);
       unknown_pal.setInactive(u_normal);
       field->setPalette( unknown_pal );
@@ -242,10 +205,8 @@ void QueryDlgBase::resetField(QMultiLineEdit *field)
   QPalette pal( field->palette());
   // replace text colors
 
-  if (   pal.normal() != normal
-      || pal.inactive() != normal
+  if ( pal.inactive() != normal
       || pal.active() != normal) {
-    pal.setNormal(normal);
     pal.setActive(normal);
     pal.setInactive(normal);
     field->setPalette( pal );
@@ -289,10 +250,8 @@ void QueryDlgBase::verifyButton(QRadioButton *radio, bool is_ok, QWidget *widget
   }
 
   if (is_ok) {
-    if (   known_pal.normal() != k_normal
-        || known_pal.inactive() != k_normal
+    if ( known_pal.inactive() != k_normal
         || known_pal.active() != k_normal) {
-      known_pal.setNormal(k_normal);
       known_pal.setActive(k_normal);
       known_pal.setInactive(k_normal);
       radio->setPalette( known_pal );
@@ -301,10 +260,8 @@ void QueryDlgBase::verifyButton(QRadioButton *radio, bool is_ok, QWidget *widget
     }
   }
   else {
-    if (   unknown_pal.normal() != u_normal
-        || unknown_pal.inactive() != u_normal
+    if ( unknown_pal.inactive() != u_normal
         || unknown_pal.active() != u_normal) {
-      unknown_pal.setNormal(u_normal);
       unknown_pal.setActive(u_normal);
       unknown_pal.setInactive(u_normal);
       radio->setPalette( unknown_pal );
@@ -325,10 +282,8 @@ void QueryDlgBase::resetButton(QRadioButton *radio, QWidget *widget2)
 
   QPalette pal(radio->palette());
   // replace text colors, avoid flickering
-  if (   pal.normal() != normal
-      || pal.inactive() != normal
+  if ( pal.inactive() != normal
       || pal.active() != normal) {
-    pal.setNormal(normal);
     pal.setActive(normal);
     pal.setInactive(normal);
     radio->setPalette( pal );
