@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: RandomQueryDlg.cpp,v 1.12 2002/11/14 22:52:35 mueller Exp $
+    $Id: RandomQueryDlg.cpp,v 1.16 2003/11/18 23:39:48 kniederk Exp $
 
                     dialog when in query mode
 
@@ -15,58 +15,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: RandomQueryDlg.cpp,v $
-    Revision 1.12  2002/11/14 22:52:35  mueller
-    compiler warning fixes
-
-    Revision 1.11  2002/01/20 11:41:02  arnold
-    fixed issues with modeless dialogs
-
-    Revision 1.10  2002/01/04 21:09:16  binner
-    CVS_SILENT Fixed capitalisation.
-
-    Revision 1.9  2001/12/26 15:12:38  mueller
-    CVSSILINT: fixincludes
-
-    Revision 1.8  2001/12/07 19:21:36  arnold
-    included multiple choice fields and false friend into query
-
-    Revision 1.7  2001/12/01 11:28:54  arnold
-    fixed flickering in query dialogs
-
-    Revision 1.6  2001/11/24 17:16:08  arnold
-    fixes for table view and query
-
-    Revision 1.5  2001/11/10 22:29:40  arnold
-    removed compatibility for kde1
-
-    Revision 1.4  2001/11/10 21:14:30  arnold
-    removed icons and compatibilty for kde1
-
-    Revision 1.3  2001/11/09 10:41:18  arnold
-    removed ability to display a different font for each column
-
-    Revision 1.2  2001/10/28 10:16:31  arnold
-    quick 'n dirty fixes for new query dialogs
-
-    Revision 1.1  2001/10/28 09:17:06  arnold
-    replaced qtarch dialog files with qtdesigner
-
-    Revision 1.3  2001/10/17 21:41:16  waba
-    Cleanup & port to Qt3, QTableView -> QTable
-    TODO:
-    * Fix actions that work on selections
-    * Fix sorting
-    * Fix language-menu
-
-    Revision 1.2  2001/10/13 11:45:29  coolo
-    includemocs and other smaller cleanups. I tried to fix it, but as it's still
-    qt2 I can't test :(
-
-    Revision 1.1  2001/10/05 15:45:05  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************
 
  ***************************************************************************
@@ -110,6 +58,7 @@ RandomQueryDlg::RandomQueryDlg(
                    int q_cycle,
                    int q_num,
                    int q_start,
+		   QFont & font,
                    kvoctrainExpr *exp,
                    kvoctrainDoc  *doc,
                    int mqtime,
@@ -118,7 +67,7 @@ RandomQueryDlg::RandomQueryDlg(
                    QWidget *parent,
                    char *name)
 	: QueryDlgForm(parent, name, false),
-	  QueryDlgBase()
+	  QueryDlgBase(font)
 {
    connect( c_type, SIGNAL(clicked()), SLOT(slotTypeClicked()) );
    connect( c_remark, SIGNAL(clicked()), SLOT(slotRemClicked()) );
@@ -165,7 +114,9 @@ void RandomQueryDlg::setQuery(QString org,
    showCounter = _show,
    timebar->setEnabled(showCounter);
    timelabel->setEnabled(showCounter);
+   transField->setFont(word_font);
    transField->setText ("");
+   orgField->setFont(word_font);
    orgField->setText (org);
    show_all->setDefault(true);
    QString s;
