@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: SimpleQueryDlg.cpp,v 1.15 2002/11/14 22:52:35 mueller Exp $
+    $Id: SimpleQueryDlg.cpp,v 1.18 2003/11/18 23:39:48 kniederk Exp $
 
                        query dialog for properties
 
@@ -14,58 +14,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: SimpleQueryDlg.cpp,v $
-    Revision 1.15  2002/11/14 22:52:35  mueller
-    compiler warning fixes
-
-    Revision 1.14  2002/09/24 15:07:40  binner
-    CVS_SILENT Style guide text fix, use "cvslastchange" or X-WebCVS header to view
-
-    Revision 1.13  2002/01/20 11:41:02  arnold
-    fixed issues with modeless dialogs
-
-    Revision 1.12  2001/12/26 15:12:38  mueller
-    CVSSILINT: fixincludes
-
-    Revision 1.11  2001/12/13 18:37:28  arnold
-    fixed and improved query dialogs
-
-    Revision 1.10  2001/12/01 11:28:54  arnold
-    fixed flickering in query dialogs
-
-    Revision 1.9  2001/11/16 16:26:23  arnold
-    improved dialogs
-
-    Revision 1.8  2001/11/10 22:29:40  arnold
-    removed compatibility for kde1
-
-    Revision 1.7  2001/11/10 21:14:30  arnold
-    removed icons and compatibilty for kde1
-
-    Revision 1.6  2001/11/09 10:41:18  arnold
-    removed ability to display a different font for each column
-
-    Revision 1.5  2001/10/28 10:16:31  arnold
-    quick 'n dirty fixes for new query dialogs
-
-    Revision 1.4  2001/10/28 09:17:06  arnold
-    replaced qtarch dialog files with qtdesigner
-
-    Revision 1.3  2001/10/17 21:41:16  waba
-    Cleanup & port to Qt3, QTableView -> QTable
-    TODO:
-    * Fix actions that work on selections
-    * Fix sorting
-    * Fix language-menu
-
-    Revision 1.2  2001/10/13 11:45:29  coolo
-    includemocs and other smaller cleanups. I tried to fix it, but as it's still
-    qt2 I can't test :(
-
-    Revision 1.1  2001/10/05 15:45:05  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************
 
  ***************************************************************************
@@ -100,6 +48,7 @@ SimpleQueryDlg::SimpleQueryDlg(
         int q_cycle,
         int q_num,
         int q_start,
+	QFont &font,
         kvoctrainExpr *exp,
         kvoctrainDoc  *doc,
         int mqtime,
@@ -110,7 +59,7 @@ SimpleQueryDlg::SimpleQueryDlg(
 )
 	:
 	SimpleQueryDlgForm( parent, name, false),
-        QueryDlgBase()
+        QueryDlgBase(font)
 {
    connect( b_edit, SIGNAL(clicked()), SLOT(editClicked()) );
    connect( stop_it, SIGNAL(clicked()), SLOT(stopItClicked()) );
@@ -157,6 +106,8 @@ void SimpleQueryDlg::setQuery(QueryType _querytype,
    showCounter = _show,
    timebar->setEnabled(showCounter);
    timelabel->setEnabled(showCounter);
+   queryField->setFont(word_font);
+   answerField->setFont(word_font);
    answerField->setText ("");
 
    QString s;
