@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: VerbQueryDlg.cpp,v 1.16 2002/11/14 22:52:35 mueller Exp $
+    $Id: VerbQueryDlg.cpp,v 1.20 2003/11/18 23:39:48 kniederk Exp $
 
                     query dialog for verbs
 
@@ -14,60 +14,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: VerbQueryDlg.cpp,v $
-    Revision 1.16  2002/11/14 22:52:35  mueller
-    compiler warning fixes
-
-    Revision 1.15  2002/01/20 11:41:02  arnold
-    fixed issues with modeless dialogs
-
-    Revision 1.14  2002/01/07 18:36:50  arnold
-    fixed query
-
-    Revision 1.13  2002/01/04 21:09:16  binner
-    CVS_SILENT Fixed capitalisation.
-
-    Revision 1.12  2001/12/26 15:12:38  mueller
-    CVSSILINT: fixincludes
-
-    Revision 1.11  2001/12/08 10:29:16  arnold
-    fixed timeout behaviour
-
-    Revision 1.10  2001/12/01 11:28:54  arnold
-    fixed flickering in query dialogs
-
-    Revision 1.9  2001/11/16 16:26:23  arnold
-    improved dialogs
-
-    Revision 1.8  2001/11/10 22:29:40  arnold
-    removed compatibility for kde1
-
-    Revision 1.7  2001/11/10 21:14:30  arnold
-    removed icons and compatibilty for kde1
-
-    Revision 1.6  2001/11/09 10:41:18  arnold
-    removed ability to display a different font for each column
-
-    Revision 1.5  2001/10/28 10:16:31  arnold
-    quick 'n dirty fixes for new query dialogs
-
-    Revision 1.4  2001/10/28 09:17:09  arnold
-    replaced qtarch dialog files with qtdesigner
-
-    Revision 1.3  2001/10/17 21:41:16  waba
-    Cleanup & port to Qt3, QTableView -> QTable
-    TODO:
-    * Fix actions that work on selections
-    * Fix sorting
-    * Fix language-menu
-
-    Revision 1.2  2001/10/13 11:45:29  coolo
-    includemocs and other smaller cleanups. I tried to fix it, but as it's still
-    qt2 I can't test :(
-
-    Revision 1.1  2001/10/05 15:45:05  arnold
-    import of version 0.7.0pre8 to kde-edu
-
  ***************************************************************************
 
  ***************************************************************************
@@ -106,6 +52,7 @@ VerbQueryDlg::VerbQueryDlg
         int query_cycle,
         int query_num,
         int query_startnum,
+	QFont &font,
         kvoctrainExpr *exp,
         kvoctrainDoc  *doc,
         const Conjugation &prefix,
@@ -117,7 +64,7 @@ VerbQueryDlg::VerbQueryDlg
         char *name)
 	:
 	VerbQueryDlgForm( parent, name, false),
-        QueryDlgBase()
+        QueryDlgBase(font)
 {
 	connect( stop_it, SIGNAL(clicked()), SLOT(stopItClicked()) );
         connect( b_edit, SIGNAL(clicked()), SLOT(editClicked()) );
@@ -149,7 +96,7 @@ VerbQueryDlg::VerbQueryDlg
 	connect( p1sField, SIGNAL(textChanged(const QString&)), SLOT(slotP1sChanged(const QString&)) );
 
    qtimer = 0;
-   setCaption (kapp->makeStdCaption(i18n("Training With Verbs")));
+   setCaption (kapp->makeStdCaption(i18n("Training with Verbs")));
    setQuery (type, entry, col,
              query_cycle, query_num, query_startnum,
              exp, doc, prefix, conjug, mqtime, _show, type_to);
