@@ -1,99 +1,18 @@
 /***************************************************************************
 
-    $Id: rowtable.cpp,v 1.23.4.1 2003/08/03 11:06:10 domi Exp $
+    $Id: rowtable.cpp,v 1.27 2003/10/27 10:01:33 binner Exp $
 
                  table view to kvoctrain document
 
     -----------------------------------------------------------------------
 
     begin                : Thu Mar 11 20:50:53 MET 1999
-                                           
+
     copyright            : taken from klpq and modified as needed
     email                : kvoctrain@ewald-arnold.de
 
     -----------------------------------------------------------------------
 
-    $Log: rowtable.cpp,v $
-    Revision 1.23.4.1  2003/08/03 11:06:10  domi
-    backport: fix a crash on setting 'Inline Editing'
-
-    Revision 1.23  2002/03/13 09:25:42  staikos
-    Don't crash on exit
-
-    Initialise the KMainWindow constructor
-
-    Revision 1.22  2002/01/19 10:33:08  arnold
-    made entry dialog modeless
-
-    Revision 1.21  2002/01/06 16:10:15  arnold
-    fixed crash when loading a second doc
-
-    Revision 1.20  2001/12/26 15:10:25  mueller
-    CVSSILINT: fixincludes
-
-    Revision 1.19  2001/12/26 13:15:21  arnold
-    fixed header buttons and kbd handling
-
-    Revision 1.18  2001/12/24 13:37:46  arnold
-    fixed misbehaviour with inline editing
-
-    Revision 1.17  2001/12/16 16:51:25  arnold
-    fixed keyboard handling in main view
-
-    Revision 1.16  2001/12/14 16:05:49  arnold
-    fixed handling of table font
-
-    Revision 1.15  2001/11/25 11:11:03  arnold
-    switch for inline edit, splitted kv_resource.h
-
-    Revision 1.14  2001/11/24 17:15:45  arnold
-    fixes for table view and query
-
-    Revision 1.13  2001/11/19 20:05:16  arnold
-    fixed warning message
-
-    Revision 1.12  2001/11/18 12:28:25  arnold
-    provided menu entry for example files
-
-    Revision 1.11  2001/11/17 17:58:22  arnold
-    added inline editing of all columns
-
-    Revision 1.10  2001/11/16 18:52:59  arnold
-    added possibility to disable expressions
-
-    Revision 1.9  2001/11/09 11:06:40  arnold
-    removed ability to display a different font for each column
-
-    Revision 1.8  2001/11/09 10:39:25  arnold
-    removed ability to display a different font for each column
-
-    Revision 1.7  2001/11/02 17:50:23  arnold
-    fixed sorting basically
-
-    Revision 1.6  2001/11/02 10:17:48  arnold
-    fixed colum resizing and diplaying of grade colors
-
-    Revision 1.5  2001/11/01 11:26:12  arnold
-    fixed some editing actions
-
-    Revision 1.4  2001/10/20 00:58:26  waba
-    * Selection fixes
-    * Compile fixes
-
-    Revision 1.3  2001/10/17 21:41:15  waba
-    Cleanup & port to Qt3, QTableView -> QTable
-    TODO:
-    * Fix actions that work on selections
-    * Fix sorting
-    * Fix language-menu
-
-    Revision 1.2  2001/10/13 11:45:29  coolo
-    includemocs and other smaller cleanups. I tried to fix it, but as it's still
-    qt2 I can't test :(
-
-    Revision 1.1  2001/10/05 15:36:34  arnold
-    import of version 0.7.0pre8 to kde-edu
-
  ***************************************************************************/
 
 #include <qkeycode.h>
@@ -109,7 +28,7 @@
 #include <klocale.h>
 #include <kdebug.h>
 
-#include <iostream.h>
+#include <iostream>
 
 #include "kvoctraindoc.h"
 #include "rowtable.h"
@@ -180,9 +99,9 @@ QWidget *KvoctrainItem::createEditor() const
 
        case KV_COL_MARK: {
          QComboBox *statebox = new QComboBox(table()->viewport() );
-         statebox->insertItem (i18n("state of a row", "active, not in query"));
-         statebox->insertItem (i18n("state of a row", "in query"));
-         statebox->insertItem (i18n("state of a row", "inactive"));
+         statebox->insertItem (i18n("state of a row", "Active, Not in Query"));
+         statebox->insertItem (i18n("state of a row", "In Query"));
+         statebox->insertItem (i18n("state of a row", "Inactive"));
          QSize sz = statebox->sizeHint();
          sz.setHeight(table()->rowHeight(row()));
          statebox->setMinimumSize(sz);
@@ -443,8 +362,8 @@ void RowTable::paintCell( QPainter *p, int row, int col, const QRect &cr, bool s
         return;
 
    QColorGroup cg = colorGroup();
-  
-#if 0  
+
+#if 0
    if ( /*(focusStl == SpreadSheet) && */ selected &&
 	 (row == currentRow()) &&
 	 (col == currentColumn()) && ( hasFocus() || viewport()->hasFocus() ) )
@@ -496,7 +415,7 @@ void RowTable::setCurrentRow( int row, int col )
 
 void RowTable::setSelectColumn( int col )
 {
-        setCurrentRow(currentRow(), col);;
+        setCurrentRow(currentRow(), col);
 }
 
 
