@@ -18,10 +18,3 @@ class KEduSimpleEntryDlg : public KEduSimpleEntryDlgForm
 };
 
 #endif // kedusimpleentrydlg_included
-
-/*
-   $Log: kedusimpleentrydlg.h,v $
-   Revision 1.1  2002/06/02 15:45:58  arnold
-   *** empty log message ***
-
-*/
